// ACL
// IDA_Secondary_Study_Variables_ACL.do
// This Do file must be called from the Primary Do File (IDA_Primary_Control_Script.do)

clear
set more off
set maxvar 20000

// All master dataset variables are pulled from a single ACL dataset
use "$acl\\$facl", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename v1 id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}

***********************************************************
**                          SES                          **
***********************************************************
preserve
// Keep only necessary variables
keep id v5533 v5532 v5531 v10468 v12599 v16539 v10471 v12602 v16542 v10469 v12600 ///
	v16540 v10472 v12603 v16543 v10470 v12601 v16541 v10467 v12598 v16538 v1720 ///
	v5711 v12597 v16537 v2046 v2049 v2050 v2008 v2047 v2048 v1646 v12610 v16551 ///
	v1119 v1730 v5722 v10483 v1119 v1117 v1118 v5712 v10473 v2064
// Rename existing or construct new variables
rename v5533 childses_1
rename v5532 p1_educ_2
rename v5531 p2_educ_2
rename v10468 rassets_100k_3
rename v12599 rassets_100k_4
rename v16539 rassets_100k_5
rename v10471 rassets_10k_3
rename v12602 rassets_10k_4
rename v16542 rassets_10k_5
rename v10469 rassets_200k_3
rename v12600 rassets_200k_4
rename v16540 rassets_200k_5
rename v10472 rassets_20k_3
rename v12603 rassets_20k_4
rename v16543 rassets_20k_5
rename v10470 rassets_500k_3
rename v12601 rassets_500k_4
rename v16541 rassets_500k_5
rename v10467 rassets_50k_3
rename v12598 rassets_50k_4
rename v16538 rassets_50k_5
rename v1720 rassets_total_1
rename v5711 rassets_total_2
rename v12597 rassets_total_4
rename v16537 rassets_total_5
rename v2046 reduc_8yr_1
rename v2049 reduc_AA_1
rename v2050 reduc_BA_1
rename v2008 reduc_cat_1
rename v2047 reduc_GED_1
rename v2048 reduc_HS_1
rename v1646 reduc_year_1
rename v12610 rincome_hh_4
rename v16551 rincome_hh_5
gen rincome_period_1 = v1119
rename v1119 rincome_wagefreq_1
rename v1730 rincome_total_1
rename v5722 rincome_total_2
rename v10483 rincome_total_3
gen rincome_wages_1 = (v1117 + (v1118/100)) * rincome_wagefreq if rincome_wagefreq > 0
rename v5712 rincome_wages_2
rename v10473 rincome_wages_3
rename v2064 rses_4cat_1
// Reshape long
reshape long childses_ p1_educ_ p2_educ_ rassets_100k_ rassets_10k_ rassets_200k_ ///
	rassets_20k_ rassets_500k_ rassets_50k_ rassets_total_ reduc_8yr_ reduc_AA_ ///
	reduc_BA_ reduc_cat_ reduc_GED_ reduc_HS_ reduc_year_ rincome_hh_ rincome_period_ ///
	rincome_total_ rincome_wagefreq_ rincome_wages_ rses_4cat_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "ACL"
// Reduce variable set further
keep id study wave childses p1_educ p2_educ rassets_100k rassets_10k rassets_200k ///
	rassets_20k rassets_500k rassets_50k rassets_total reduc_8yr reduc_AA reduc_BA ///
	reduc_cat reduc_GED reduc_HS reduc_year rincome_hh rincome_period rincome_total ///
	rincome_wagefreq rincome_wages rses_4cat
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var childses "Childhood SES score"
la var p1_educ "Parent 1's education"
la var p2_educ "Parent 2's education"
la var rassets_100k "Respondent assets above $100k"
la var rassets_10k "Respondent assets above $10k"
la var rassets_200k "Respondent assets above $200k"
la var rassets_20k "Respondent assets above $20k"
la var rassets_500k "Respondent assets above $500k"
la var rassets_50k "Respondent assets above $50k"
la var rassets_total "Respondent - total assets"
la var reduc_8yr "Respondent Education - 8 years or less"
la var reduc_AA "Respondent Education - Associate's"
la var reduc_BA "Respondent education - Bachelor's"
la var reduc_cat "Respondent: Educational attainment category"
la var reduc_GED "Respondent Education - GED"
la var reduc_HS "Respondent Education - HS / equivalent"
la var reduc_year "Respondent: Highest year of education"
la var rincome_hh "Repondent & Spouse/Partner Income together"
la var rincome_period "Respondent income - period of earning"
la var rincome_total "Respondent income - total (wages + other)"
la var rincome_wagefreq "R income - frequency"
la var rincome_wages "Respondent earnings"
la var rses_4cat "4-category SES"
// Save as a temp file
tempfile _SES_w12345
save `_SES_w12345'
restore

***********************************************************
**                 SOCIAL RELATIONSHIPS                  **
***********************************************************
preserve
// Keep only necessary variables
keep id v222 v1613 v1309 v1310 v1311 v1312 v1313 v1315 v220 v221 v535 v536 v537 ///
	v538 v2017 v436 v433 v431 v432 v434 v509 v522 v501 v514 v401 v402 v407 v405 ///
	v406 v408 v4312 v5608 v5214 v5215 v5216 v5217 v5218 v5220 v4310 v4311 v4446 ///
	v4447 v4448 v4449 v6017 v4420 v4416 v4414 v4415 v4417 v4428 v4439 v4424 v4435 ///
	v5614 v4404 v4409 v4407 v4408 v4410 v10100 v10449 v10360 v10361 v10362 v10363 ///
	v10364 v10366 v10098 v10099 v10147 v10148 v11406 v10137 v10138 v10135 v10134 ///
	v10142 v10143 v10119 v10122 v10130 v10129 v12131 v12551 v12408 v12409 v12410 ///
	v12411 v12412 v12414 v12129 v12130 v12172 v12173 v12159 v12168 v12167 v12477 ///
	v12479 v12147 v12149 v12154 v12153 v15196 v16401 v16201 v15193 v15195 v15510 ///
	v15511 v15512 v15513 v17604 v17605 v15505 v15503 v15504 v15506 v16311 v16312 ///
	v16313 v15401 v15403 v15412 v15410 v15411 v15413
// Rename variables
rename v222 meeting_all_1
rename v1613 religious_attend_1
rename v1309 volunteer_religion_1
rename v1310 volunteer_edu_1
rename v1311 volunteer_politics_1
rename v1312 volunteer_seniors_1
rename v1313 volunteer_other_1
rename v1315 volunteerhrs_1
rename v220 close_other_talk_1
rename v221 close_other_inperson_1
rename v535 close_other_loved_1
rename v536 close_other_demand_1
rename v537 close_other_listen_1
rename v538 close_other_critical_1
rename v2017 child_num_1
rename v436 child_contact_1
rename v433 child_listen_1
rename v431 child_feel_loved_1
rename v432 child_demand_1
rename v434 child_critic_1
rename v509 mom_contact_1
rename v522 dad_contact_1
rename v501 biomom_alive_1
rename v514 biodad_alive_1
rename v401 marital_status_1
rename v402 cohabitating_1
rename v407 sppn_listen_1
rename v405 sppn_loved_1
rename v406 sppn_demand_1
rename v408 sppn_critic_1
rename v4312 meeting_all_2
rename v5608 religious_attend_2
rename v5214 volunteer_religion_2
rename v5215 volunteer_edu_2
rename v5216 volunteer_politics_2
rename v5217 volunteer_seniors_2
rename v5218 volunteer_other_2
rename v5220 volunteerhrs_2
rename v4310 close_other_talk_2
rename v4311 close_other_inperson_2
rename v4446 close_other_loved_2
rename v4447 close_other_demand_2
rename v4448 close_other_listen_2
rename v4449 close_other_critical_2
rename v6017 child_num_2
rename v4420 child_contact_2
rename v4416 child_listen_2
rename v4414 child_feel_loved_2
rename v4415 child_demand_2
rename v4417 child_critic_2
rename v4428 mom_contact_2
rename v4439 dad_contact_2
rename v4424 biomom_alive_2
rename v4435 biodad_alive_2
rename v5614 marital_status_2
rename v4404 cohabitating_2
rename v4409 sppn_listen_2
rename v4407 sppn_loved_2
rename v4408 sppn_demand_2
rename v4410 sppn_critic_2
rename v10100 meeting_all_3
rename v10449 religious_attend_3
rename v10360 volunteer_religion_3
rename v10361 volunteer_edu_3
rename v10362 volunteer_politics_3
rename v10363 volunteer_seniors_3
rename v10364 volunteer_other_3
rename v10366 volunteerhrs_3
rename v10098 close_other_talk_3
rename v10099 close_other_inperson_3
rename v10147 close_other_loved_3
rename v10148 close_other_listen_3
rename v11406 child_num_3
rename v10137 child_contact1_3
rename v10138 child_contact2_3
rename v10135 child_listen_3
rename v10134 child_feel_loved_3
rename v10142 biomom_alive_3
rename v10143 biodad_alive_3
rename v10119 marital_status_3
rename v10122 cohabitating_3
rename v10130 sppn_listen_3
rename v10129 sppn_loved_3
rename v12131 meeting_all_4
rename v12551 religious_attend_4
rename v12408 volunteer_religion_4
rename v12409 volunteer_edu_4
rename v12410 volunteer_politics_4
rename v12411 volunteer_seniors_4
rename v12412 volunteer_other_4
rename v12414 volunteerhrs_4
rename v12129 close_other_talk_4
rename v12130 close_other_inperson_4
rename v12172 close_other_loved_4
rename v12173 close_other_listen_4
rename v12159 child_num_4
rename v12168 child_listen_4
rename v12167 child_feel_loved_4
rename v12477 biomom_died_4
rename v12479 biodad_died_4
rename v12147 marital_status_4
rename v12149 cohabitating_4
rename v12154 sppn_listen_4
rename v12153 sppn_loved_4
rename v15196 meeting_all_5
rename v16401 religious_attend_5
rename v16201 volunteerhrs_5
rename v15193 close_other_talk_5
rename v15195 close_other_inperson_5
rename v15510 close_other_loved_5
rename v15511 close_other_demand_5
rename v15512 close_other_listen_5
rename v15513 close_other_critical_5
rename v17604 child_nonhh_5
rename v17605 child_hh_5
rename v15505 child_listen_5
rename v15503 child_feel_loved_5
rename v15504 child_demand_5
rename v15506 child_critic_5
rename v16311 par_died1_5
rename v16312 par_died2_5
rename v16313 par_died3_5
rename v15401 marital_status_5
rename v15403 cohabitating_5
rename v15412 sppn_listen_5
rename v15410 sppn_loved_5
rename v15411 sppn_demand_5
rename v15413 sppn_critic_5
// Reshape long
reshape long meeting_all_ religious_attend_ volunteer_religion_ volunteer_edu_ ///
	volunteer_politics_ volunteer_seniors_ volunteer_other_ volunteerhrs_ ///
	close_other_talk_ close_other_inperson_ close_other_loved_ close_other_demand_ ///
	close_other_listen_ close_other_critical_ child_num_ child_contact_ ///
	child_listen_ child_feel_loved_ child_demand_ child_critic_ mom_contact_ ///
	dad_contact_ biomom_alive_ biodad_alive_ marital_status_ cohabitating_ ///
	sppn_listen_ sppn_loved_ sppn_demand_ sppn_critic_ child_contact1_ ///
	child_contact2_ biomom_died_ biodad_died_ child_nonhh_ child_hh_ par_died1_ ///
	par_died2_ par_died3_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "ACL"
// Reduce variable set further
keep id study wave meeting_all religious_attend volunteer_religion volunteer_edu ///
	volunteer_politics volunteer_seniors volunteer_other volunteerhrs ///
	close_other_talk close_other_inperson close_other_loved close_other_demand ///
	close_other_listen close_other_critical child_num child_contact child_listen ///
	child_feel_loved child_demand child_critic mom_contact dad_contact ///
	biomom_alive biodad_alive marital_status cohabitating sppn_listen sppn_loved ///
	sppn_demand sppn_critic child_contact1 child_contact2 biomom_died biodad_died ///
	child_nonhh child_hh par_died1 par_died2 par_died3
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var meeting_all "Frequency attend any group meetings"
la var religious_attend "Frequency attend religious services"
la var volunteer_religion "Volunteer for religious organizations"
la var volunteer_edu "Volunteer for an educational organization"
la var volunteer_politics "Volunteer for political organizations"
la var volunteer_seniors "Volunteer for senior citizen group"
la var volunteer_other "Volunteer for other organizations"
la var volunteerhrs "Volunteer hours"
la var close_other_talk "Talk on the phone with friends, family, or neighbors"
la var close_other_inperson "Get together with friends, family, or neighbors"
la var close_other_loved "Friends and relatives make you feel loved"
la var close_other_demand "Friends and relatives makes too many demands"
la var close_other_listen "Friends and relatives willing to listen about worries"
la var close_other_critical "Friends and relatives critical of you"
la var child_num "Number of children"
la var child_contact "Contact with children"
la var child_listen "Your children listen to your worries"
la var child_feel_loved "Your children make you feel loved"
la var child_demand "Your children make too many demands"
la var child_critic "Your children are critical of you"
la var mom_contact "Contact with mother"
la var dad_contact "Contact with father"
la var biomom_alive "Biological mother still living"
la var biodad_alive "Biological father still living"
la var marital_status "Current marital status"
la var cohabitating "Cohabitating with partner"
la var sppn_listen "Spouse/partner listens when you need to talk"
la var sppn_loved "Spouse make you feel loved"
la var sppn_demand "Spouse/partner make too many demands"
la var sppn_critic "Spouse/partner criticize you"
la var child_contact1 "Contact with one child who lives elsewhere"
la var child_contact2 "Contact with two or more children who live elsewhere"
la var biomom_died "Mother died since last interview"
la var biodad_died "Father died since last interview"
la var child_nonhh "Number of children not living with the respondent"
la var child_hh "Number of chilren living with the respondent"
la var par_died1 "Parent or step-parent died since last interview - 1st mention"
la var par_died2 "Parent or step-parent died since last interview - 2st mention"
la var par_died3 "Parent or step-parent died since last interview - 3st mention"
// Save as a temp file
tempfile _SR_w12345
save `_SR_w12345'
restore

***********************************************************
**                      BIOMARKERS                       **
***********************************************************
preserve
// Keep only necessary variables
keep id v2623 v6623 v10923 v13023 v17023 v6625 v10925 v13025 v17025
// Rename variables
rename v2623 bmi_1
rename v6623 bmi_2
rename v10923 bmi_3
rename v13023 bmi_4
rename v17023 bmi_5
rename v6625 bmi_class_2
rename v10925 bmi_class_3
rename v13025 bmi_class_4
rename v17025 bmi_class_5
// Reshape long
reshape long bmi_ bmi_class_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "ACL"
// Reduce variable set further
keep id study wave bmi bmi_class
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var bmi "Body mass index (kg/m2)"
la var bmi_class "BMI category"
// Save as a temp file
tempfile _Bio_w12345
save `_Bio_w12345'
restore

***********************************************************
**                       COGNITION                       **
***********************************************************
preserve
// Keep only necessary variables
keep id v6 v7 v1401 v1402 v1403 v1404 v1405 v1406 v1407 v1408 v1409 v1410 v1411 ///
	v1412 v1413 v5313 v5315 v5310 v5311 v5312 v5314 v5316 v5317 v5318 v5319 v5320 ///
	v5321 v5322 v5323 v5324 v1414 v1415 v1416 v1417 v1418 v1419 v5326 v5327 v5328 ///
	v5329 v5330 v5331 v10378 v10379 v10380 v10381 v10382 v10383 v10384 v10385 ///
	v10386 v10387 v10388 v12424 v12426 v12428 v12429 v12437 v12438 v12439 v12440 ///
	v12441 v12442 v12436 v5325 v10389 v12425 v12427 v12430 v12431 v12432 v12433 ///
	v12434 v12435 v12443 v12444 v12445 v12446 v12447 v12448 v12449 v12450 v12451 ///
	v12452 v12453 v15617 v15618 v15621 v15622 v15623 v15624 v15625 v15626 v15619 ///
	v15601 v15602 v15603 v15604 v15605 v15606 v15607 v15608 v15609 v15610 v15634 ///
	v15635 v15636 v15637 v15638 v15639 v15640 v15641 v15642 v15643 v15654 v15611 ///
	v15613 v15615 v15616 v3409 v7409 v10934 v10917 v13202 v17202
// Rename variables
rename v6 rmem_datec_1
rename v7 rmem_dwkc_1
rename v1401 rmem_month_1
rename v1402 rmem_day_1
rename v1403 rmem_yr_1
rename v1404 rmem_dwk_1
rename v1405 rmem_mmn_1
rename v1406 rmem_currp_1
rename v1407 rmem_prevp_1
rename v1408 rmem_1_1
rename v1409 rmem2_1
rename v1410 rmem3_1
rename v1411 rmem4_1
rename v1412 rmem5_1
rename v1413 rmem6_1
rename v5313 rmem_datec_2
rename v5315 rmem_dwkc_2
rename v5310 rmem_month_2
rename v5311 rmem_day_2
rename v5312 rmem_yr_2
rename v5314 rmem_dwk_2
rename v5316 rmem_mmn_2
rename v5317 rmem_currp_2
rename v5318 rmem_prevp_2
rename v5319 rmem_1_2
rename v5320 rmem2_2
rename v5321 rmem3_2
rename v5322 rmem4_2
rename v5323 rmem5_2
rename v5324 rmem6_2
rename v1414 r_vf1_1
rename v1415 r_vf2_1
rename v1416 r_vf3_1
rename v1417 r_vf4_1
rename v1418 r_vf5_1
rename v1419 r_vf6_1
rename v5326 r_vf1_2
rename v5327 r_vf2_2
rename v5328 r_vf3_2
rename v5329 r_vf4_2
rename v5330 r_vf5_2
rename v5331 r_vf6_2
rename v10378 rmem_datec_3
rename v10379 rmem_dwkc_3
rename v10380 rmem_mmn_3
rename v10381 rmem_currp_3
rename v10382 rmem_prevp_3
rename v10383 rmem_1_3
rename v10384 rmem2_3
rename v10385 rmem3_3
rename v10386 rmem4_3
rename v10387 rmem5_3
rename v10388 rmem6_3
rename v12424 rmem_date_4
rename v12426 rmem_dwk_4
rename v12428 rmem_currp_4
rename v12429 rmem_prevp_4
rename v12437 rmem_1_4
rename v12438 rmem2_4
rename v12439 rmem3_4
rename v12440 rmem4_4
rename v12441 rmem5_4
rename v12442 rmem6_4
rename v12436 rmem_correct_4
rename v5325 rmem_sum_2
rename v10389 rmem_correct_3
rename v12425 rmem_datec_4
rename v12427 rmem_dwkc_4
rename v12430 rmem_ser3a_4
rename v12431 rmem_ser3b_4
rename v12432 rmem_ser3c_4
rename v12433 rmem_ser3d_4
rename v12434 rmem_ser3e_4
rename v12435 rmem_ser3f_4
rename v12443 rmem_ser3sum_4
rename v12444 rmem_proxy1_4
rename v12445 rmem_proxy2_4
rename v12446 rmem_proxy3_4
rename v12447 rmem_proxy4_4
rename v12448 rmem_proxy5a_4
rename v12449 rmem_proxy5b_4
rename v12450 rmem_proxy5c_4
rename v12451 rmem_proxy5d_4
rename v12452 rmem_proxy5e_4
rename v12453 rmem_proxy5f_4
rename v15617 rmem_currp_5
rename v15618 rmem_prevp_5
rename v15621 rmem_1_5
rename v15622 rmem2_5
rename v15623 rmem3_5
rename v15624 rmem4_5
rename v15625 rmem5_5
rename v15626 rmem6_5
rename v15619 rmem_correct_5
rename v15601 rmem_proxy1_5
rename v15602 rmem_proxy2_5
rename v15603 rmem_proxy3_5
rename v15604 rmem_proxy4_5
rename v15605 rmem_proxy5a_5
rename v15606 rmem_proxy5b_5
rename v15607 rmem_proxy5c_5
rename v15608 rmem_proxy5d_5
rename v15609 rmem_proxy5e_5
rename v15610 rmem_proxy5f_5
rename v15634 rmem_recall1_5
rename v15635 rmem_recall2_5
rename v15636 rmem_recall3_5
rename v15637 rmem_recall4_5
rename v15638 rmem_recall5_5
rename v15639 rmem_recall6_5
rename v15640 rmem_recall7_5
rename v15641 rmem_recall8_5
rename v15642 rmem_recall9_5
rename v15643 rmem_recall10_5
rename v15654 rmem_recallassist_5
rename v15611 rmem_date_5
rename v15613 rmem_datec_5
rename v15615 rmem_dwk_5
rename v15616 rmem_dwkc_5
rename v3409 rcog_5item_1
rename v7409 rcog_5item_2
rename v10934 rcog_5item_3
rename v10917 rcog_6item_3
rename v13202 rcog_5item_4
rename v17202 rcog_5item_5
// Reshape long
reshape long rmem_datec_ rmem_dwkc_ rmem_month_ rmem_day_ rmem_yr_ rmem_dwk_ ///
	rmem_mmn_ rmem_currp_ rmem_prevp_ rmem_1_ rmem2_ rmem3_ rmem4_ rmem5_ rmem6_ ///
	r_vf1_ r_vf2_ r_vf3_ r_vf4_ r_vf5_ r_vf6_ rmem_date_ rmem_correct_ rmem_sum_ ///
	rmem_ser3a_ rmem_ser3b_ rmem_ser3c_ rmem_ser3d_ rmem_ser3e_ rmem_ser3f_ ///
	rmem_ser3sum_ rmem_proxy1_ rmem_proxy2_ rmem_proxy3_ rmem_proxy4_ ///
	rmem_proxy5a_ rmem_proxy5b_ rmem_proxy5c_ rmem_proxy5d_ rmem_proxy5e_ ///
	rmem_proxy5f_ rmem_recall1_ rmem_recall2_ rmem_recall3_ rmem_recall4_ ///
	rmem_recall5_ rmem_recall6_ rmem_recall7_ rmem_recall8_ rmem_recall9_ ///
	rmem_recall10_ rmem_recallassist_ rcog_5item_ rcog_6item_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "ACL"
// Reduce variable set further
keep id study wave rmem_datec rmem_dwkc rmem_month rmem_day rmem_yr rmem_dwk ///
	rmem_mmn rmem_currp rmem_prevp rmem_1 rmem2 rmem3 rmem4 rmem5 rmem6 r_vf1 ///
	r_vf2 r_vf3 r_vf4 r_vf5 r_vf6 rmem_date rmem_correct rmem_sum rmem_ser3a ///
	rmem_ser3b rmem_ser3c rmem_ser3d rmem_ser3e rmem_ser3f rmem_ser3sum ///
	rmem_proxy1 rmem_proxy2 rmem_proxy3 rmem_proxy4 rmem_proxy5a rmem_proxy5b ///
	rmem_proxy5c rmem_proxy5d rmem_proxy5e rmem_proxy5f rmem_recall1 rmem_recall2 ///
	rmem_recall3 rmem_recall4 rmem_recall5 rmem_recall6 rmem_recall7 rmem_recall8 ///
	rmem_recall9 rmem_recall10 rmem_recallassist rcog_5item rcog_6item
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var rmem_datec "Memory: Date correct"
la var rmem_dwkc "Memory: Day of Week correct"
la var rmem_month "Memory: Current Month"
la var rmem_day "Memory: Current Day"
la var rmem_yr "Memory: Current Year"
la var rmem_dwk "Memory: Day of Week"
la var rmem_mmn "Memory: Mother's Maiden Name"
la var rmem_currp "Memory: Current President"
la var rmem_prevp "Memory: Previous President"
la var rmem_1 "Memory: # Recall 1"
la var rmem2 "Memory: # Recall 2"
la var rmem3 "Memory: # Recall 3"
la var rmem4 "Memory: # Recall 4"
la var rmem5 "Memory: # Recall 5"
la var rmem6 "Memory: # Recall 6"
la var r_vf1 "Verbal Facility - Rain"
la var r_vf2 "VF - Trees"
la var r_vf3 "VF - Learn"
la var r_vf4 "VF - Escape"
la var r_vf5 "VF - Decide"
la var r_vf6 "VF - Safe"
la var rmem_date "Memory: Date"
la var rmem_correct "Memory: # incorrect"
la var rmem_sum "Memory: IWER MARK SUM"
la var rmem_ser3a "Memory: Backward Serial 3s 1"
la var rmem_ser3b "Memory: Backward Serial 3s 2"
la var rmem_ser3c "Memory: Backward Serial 3s 3"
la var rmem_ser3d "Memory: Backward Serial 3s 4"
la var rmem_ser3e "Memory: Backward Serial 3s 5"
la var rmem_ser3f "Memory: Backward Serial 3s 6"
la var rmem_ser3sum "Memory: Sum of Backward Serial 3s (0 to 6)"
la var rmem_proxy1 "Memory: Proxy 1"
la var rmem_proxy2 "Memory: Proxy 2"
la var rmem_proxy3 "Memory: Proxy 3"
la var rmem_proxy4 "Memory: Proxy 4"
la var rmem_proxy5a "Memory: Proxy 5a"
la var rmem_proxy5b "Memory: Proxy 5b"
la var rmem_proxy5c "Memory: Proxy 5c"
la var rmem_proxy5d "Memory: Proxy 5d"
la var rmem_proxy5e "Memory: Proxy 5e"
la var rmem_proxy5f "Memory: Proxy 5f"
la var rmem_recall1 "Memory: Word Recall 1"
la var rmem_recall2 "Memory: Word Recall 2"
la var rmem_recall3 "Memory: Word Recall 3"
la var rmem_recall4 "Memory: Word Recall 4"
la var rmem_recall5 "Memory: Word Recall 5"
la var rmem_recall6 "Memory: Word Recall 6"
la var rmem_recall7 "Memory: Word Recall 7"
la var rmem_recall8 "Memory: Word Recall 8"
la var rmem_recall9 "Memory: Word Recall 9"
la var rmem_recall10 "Memory: Word Recall 10"
la var rmem_recallassist "Memory: Word Recall # of times assisted"
la var rcog_5item "Respondent cog impairment - 5 item"
la var rcog_6item "Respondent cog impairment - 6 item"
// Save as a temp file
tempfile _Cognition_w12345
save `_Cognition_w12345'
restore

***********************************************************
**                 COVARIATES: BEHAVIORS                 **
***********************************************************
preserve
// Keep only necessary variables
keep id v2203 v224 v2670 v6203 v6670 v4317 v4318 v10903 v11170 v10103 v13214 ///
	v13250 v12134 v17501 v17550 v15199 v946 v4944 v10272 v12243 v15846 v947 ///
	v4945 v10273 v12244 v15847 v948 v4946 v10275 v10276 v10277 v12245 v15848 ///
	v2637 v6637 v10937 v13037 v15835
// Rename variables
rename v2203 physactivity_1
rename v224 pa_vig_1
rename v2670 physactivity_quartile_1
rename v6203 physactivity_2
rename v6670 physactivity_quartile_2
rename v4317 pa_vig_2
rename v4318 hrsexercise_2
rename v10903 physactivity_3
rename v11170 physactivity_quartile_3
rename v10103 pa_vig_3
rename v13214 physactivity_4
rename v13250 physactivity_quartile_4
rename v12134 pa_vig_4
rename v17501 physactivity_5
rename v17550 physactivity_quartile_5
rename v15199 pa_vig_5
rename v946 everdrink_1
rename v4944 everdrink_2
rename v10272 everdrink_3
rename v12243 everdrink_4
rename v15846 everdrink_5
rename v947 daysdrinkpermonth_1
rename v4945 daysdrinkpermonth_2
rename v10273 daysdrinkpermonth_3
rename v12244 daysdrinkpermonth_4
rename v15847 daysdrinkpermonth_5
rename v948 num_drinksday_1
rename v4946 num_drinksday_2
rename v10275 lownum_drinks_3
rename v10276 highnum_drinks_3
rename v10277 mednum_drinks_3
rename v12245 num_drinksday_4
rename v15848 num_drinksday_5
rename v2637 smoker_1
rename v6637 smoker_2
rename v10937 smoker_3
rename v13037 smoker_4
rename v15835 smoker_5
// Reshape long
reshape long physactivity_ pa_vig_ physactivity_quartile_ hrsexercise_ everdrink_ ///
	daysdrinkpermonth_ num_drinksday_ lownum_drinks_ highnum_drinks_ ///
	mednum_drinks_ smoker_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "ACL"
// Reduce variable set further
keep id study wave physactivity pa_vig physactivity_quartile hrsexercise ///
	everdrink daysdrinkpermonth num_drinksday lownum_drinks highnum_drinks ///
	mednum_drinks smoker
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var physactivity "total physical activity index"
la var pa_vig "frequency of vigorous/active sports or exercise"
la var physactivity_quartile "ACL physical activity index quartiles"
la var hrsexercise "hours vigorous/active sports or exercise per week"
la var everdrink "Drink alcohol ever in past year - yes or no"
la var daysdrinkpermonth "Number of days drank alcohol in past month"
la var num_drinksday "Number of drinks consumed per occassion/days when drink"
la var lownum_drinks "medium - dummy variable for number of drinks/day when drank"
la var highnum_drinks "high - dummy variable for number of drinks/day when drank"
la var mednum_drinks "medium - dummy variable for number of drinks/day when drank"
la var smoker "Current smoker - yes or no"
// Save as a temp file
tempfile _Cov_Behav_w12345
save `_Cov_Behav_w12345'
restore

***********************************************************
**                 COVARIATES: ATTRITION                 **
***********************************************************
preserve
// Keep only necessary variables
keep id v9002 v11036 v11647 v11705 v11704
// Rename variables
rename v9002 attrition_2
rename v11036 attrition_3
rename v11647 attrition_4
rename v11705 attrition_5
rename v11704 year_died_5
// Reshape long
reshape long attrition_ year_died_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "ACL"
// Reduce variable set further
keep id study wave attrition year_died
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var attrition "participant attrition status"
la var year_died "Year of death"
// Save as a temp file
tempfile _Cov_Attrition_w12345
save `_Cov_Attrition_w12345'
restore

***********************************************************
**                COVARIATES: DEMOGRAPHIC                **
***********************************************************
preserve
// Keep only necessary variables
keep id v2001 v2000 v2000 v4005 v2000 v11403 v2000 v12005 v15102 v1801 v2102 ///
	v2107 v1640 v3200 v1876 v10800 v12007 v15014
// Rename existing or construct new variables
rename v2001 birthyear_1
gen age_1 = v2000
gen age_2 = v2000 + 3 if v4005 != -99
gen age_3 = v2000 + 8 if v11403 != -99
gen age_4 = v2000 + (v12005 - 1986) if v12005 != -99
gen age_5 = v15102 if v15102 != -99
rename v1801 female_1
rename v2102 race_1
rename v2107 hispanic_1
rename v1640 immigrant_1
rename v3200 religion_1
rename v1876 region_1
rename v10800 proxy_3
rename v12007 proxy_4
rename v15014 proxy_5
// Reshape long
reshape long birthyear_ age_ female_ race_ hispanic_ immigrant_ religion_ ///
	region_ proxy_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "ACL"
// Reduce variable set further
keep id study wave birthyear age female race hispanic immigrant religion region proxy
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var birthyear "respondent birth year"
la var age "respondent age"
la var female "respondent gender"
la var race "respondent race/ethnicity"
la var hispanic "respondent Hispanic ethnicity"
la var immigrant "immigrant status"
la var religion "respondent religion"
la var region "respondent geographic census region"
la var proxy "whether proxy interview"
// Save as a temp file
tempfile _Cov_Demog_w12345
save `_Cov_Demog_w12345'
restore

***********************************************************
**                COVARIATES: INTELLIGENCE               **
***********************************************************
preserve
// Keep only necessary variables
keep id v3401 v7401
// Rename variables
rename v3401 verbal_iq_1
rename v7401 verbal_iq_2
// Reshape long
reshape long verbal_iq_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "ACL"
// Reduce variable set further
keep id study wave verbal_iq
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var verbal_iq "verbal IQ index"
// Save as a temp file
tempfile _Cov_Intell_w12345
save `_Cov_Intell_w12345'
restore

***********************************************************
**                  COVARIATES: LBELIG                   **
***********************************************************
// !!! NO LBELIG VARIABLES FOR ACL !!!

***********************************************************
**                   COVARIATES: MEDS                    **
***********************************************************
// !!! NO MEDS VARIABLES FOR ACL !!!

***********************************************************
**              COVARIATES: PHYSICAL HEALTH              **
***********************************************************
preserve
// Keep only necessary variables
keep id v902 v906 v908 v911 v4915 v4918 v4920 v4923 v10236 v10239 v10241 v10244 ///
	v12226 v12229 v12231 v12234 v15802 v15804 v15806 v15808 v2681 v6681 v11181 ///
	v13031 v17002
// Rename variables
rename v902 limit_bathing_1
rename v906 limit_stairs_1
rename v908 limit_walk_block_1
rename v911 limit_housework_1
rename v4915 limit_bathing_2
rename v4918 limit_stairs_2
rename v4920 limit_walk_block_2
rename v4923 limit_housework_2
rename v10236 limit_bathing_3
rename v10239 limit_stairs_3
rename v10241 limit_walk_block_3
rename v10244 limit_housework_3
rename v12226 limit_bathing_4
rename v12229 limit_stairs_4
rename v12231 limit_walk_block_4
rename v12234 limit_housework_4
rename v15802 limit_bathing_5
rename v15804 limit_stairs_5
rename v15806 limit_walk_block_5
rename v15808 limit_housework_5
rename v2681 comorbidities_1
rename v6681 comorbidities_2
rename v11181 comorbidities_3
rename v13031 comorbidities_4
rename v17002 comorbidities_5
// Reshape long
reshape long limit_bathing_ limit_stairs_ limit_walk_block_ limit_housework_ ///
	comorbidities_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "ACL"
// Reduce variable set further
keep id study wave limit_bathing limit_stairs limit_walk_block limit_housework ///
	comorbidities
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var limit_bathing "Heath limits bathing"
la var limit_stairs "Health limits climbing stairs"
la var limit_walk_block "Health limits walking several blocks"
la var limit_housework "Health limits heavy housework"
la var comorbidities "Sum of comorbidites"
// Save as a temp file
tempfile _Cov_PhysH_w12345
save `_Cov_PhysH_w12345'
restore

***********************************************************
**            COVARIATES: PSYCHOSOCIAL HEALTH            **
***********************************************************
preserve
// Keep only necessary variables
keep id v915 v4925 v10246 v13002 v15822 v12246 v15854 v15855 v15856 v15857 v15858 ///
	v15859 v15860 v1002 v5001 v10283 v12325 v16001
// Rename variables
rename v915 adult_srh_1
rename v4925 adult_srh_2
rename v10246 adult_srh_3
rename v13002 adult_srh_4
rename v15822 adult_srh_5
rename v12246 healthins_4
rename v15854 healthins_medicarepta_5
rename v15855 healthins_medicareptb_5
rename v15856 healthins_medicareptd_5
rename v15857 healthins_medicaid_5
rename v15858 healthins_va_5
rename v15859 healthins_employer_5
rename v15860 healthins_self_5
rename v1002 depressed_cesd_1
rename v5001 depressed_cesd_2
rename v10283 depressed_cesd_3
rename v12325 depressed_cesd_4
rename v16001 depressed_cesd_5
// Reshape long
reshape long adult_srh_ healthins_ healthins_medicarepta_ healthins_medicareptb_ ///
	healthins_medicareptd_ healthins_medicaid_ healthins_va_ healthins_employer_ ///
	healthins_self_ depressed_cesd_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "ACL"
// Reduce variable set further
keep id study wave adult_srh healthins healthins_medicarepta healthins_medicareptb ///
	healthins_medicareptd healthins_medicaid healthins_va healthins_employer ///
	healthins_self depressed_cesd
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var adult_srh "respondent self-rated health"
la var healthins "current health insurance status"
la var healthins_medicarepta "has Medicare Part A healthcare coverage"
la var healthins_medicareptb "has Medicare Part B healthcare coverage"
la var healthins_medicareptd "has Medicare Part D healthcare coverage"
la var healthins_medicaid "has Medicaid healthcare coverage"
la var healthins_va "has VA or military healthcare coverage"
la var healthins_employer "has healthcare coverage through self or spouse employer"
la var healthins_self "has self-arranged healthcare coverage"
la var depressed_cesd "self-reported depression; CES-D"
// Save as a temp file
tempfile _Cov_PsychH_w12345
save `_Cov_PsychH_w12345'
restore

***********************************************************
**                  COVARIATES: WEIGHTS                  **
***********************************************************
preserve
// Keep only necessary variables
keep id v1860 v10822 v12966 v16901 v5860 v10819 v12968 v16902
// Rename variables
rename v1860 acl_xsectionweight_1
rename v10822 acl_xsectionweight_3
rename v12966 acl_xsectionweight_4
rename v16901 acl_xsectionweight_5
rename v5860 acl_panelweight_2
rename v10819 acl_panelweight_3
rename v12968 acl_panelweight_4
rename v16902 acl_panelweight_5
// Reshape long
reshape long acl_xsectionweight_ acl_panelweight_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "ACL"
// Reduce variable set further
keep id study wave acl_xsectionweight acl_panelweight
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var acl_xsectionweight "ACL cross-section weight"
la var acl_panelweight "ACL panel weight"
// Save as a temp file
tempfile _Cov_Wts_w12345
save `_Cov_Wts_w12345'
restore

***********************************************************
**          COMBINE INTO SINGLE PROJECT DATASET          **
***********************************************************
// Merge them all together
use `_SR_w12345', clear
merge 1:1 id study wave using `_SES_w12345'
drop _merge
merge 1:1 id study wave using `_Bio_w12345'
drop _merge
merge 1:1 id study wave using `_Cognition_w12345'
drop _merge
merge 1:1 id study wave using `_Cov_Attrition_w12345'
drop _merge
merge 1:1 id study wave using `_Cov_Behav_w12345'
drop _merge
merge 1:1 id study wave using `_Cov_Demog_w12345'
drop _merge
merge 1:1 id study wave using `_Cov_Intell_w12345'
drop _merge
merge 1:1 id study wave using `_Cov_PhysH_w12345'
drop _merge
merge 1:1 id study wave using `_Cov_PsychH_w12345'
drop _merge
merge 1:1 id study wave using `_Cov_Wts_w12345'
drop _merge
ds, has(type numeric)
la val `r(varlist)' .

***********************************************************
**             FINAL INTERIM DATASET CLEANUP             **
***********************************************************

// Convert wave to numeric
destring wave, replace

// Destring the ID variable and sort the data by study, ID and wave
destring id, replace
format %12.0g id
sort id wave

// Remove value labels
ds, has(type numeric)
la val `r(varlist)' .

// Rename the cross-sectional weight variable to be consistent across studies
rename acl_xsectionweight xsectionweight
la var xsectionweight "Study-specific cross-section weights"

// Compress
compress

// Update formats
ds, has(type byte)
format %8.0g `r(varlist)'

ds, has(type int)
format %8.0g `r(varlist)'

ds, has(type float)
format %12.2g `r(varlist)'

// Reorder the variables
order id study wave ///
	attrition year_died ///--------------------------------------------ATTRITION
	p1_educ p2_educ childses ///---------------------------------------------SES
	rassets_10k rassets_20k rassets_50k rassets_100k rassets_200k rassets_500k ///
	rassets_total reduc_year reduc_8yr reduc_cat reduc_GED reduc_HS reduc_AA ///
	reduc_BA rincome_hh rincome_period rincome_total rincome_wagefreq ///
	rincome_wages rses_4cat ///
	meeting_all religious_attend volunteer_religion volunteer_edu ///---------SR
	volunteer_politics volunteer_seniors volunteer_other volunteerhrs ///
	close_other_talk close_other_inperson close_other_loved close_other_demand ///
	close_other_listen close_other_critical child_contact child_listen ///
	child_feel_loved child_demand child_critic mom_contact dad_contact ///
	biomom_alive biodad_alive marital_status sppn_listen sppn_loved sppn_demand ///
	sppn_critic child_num child_contact1 child_contact2 biomom_died biodad_died ///
	child_nonhh child_hh par_died1 par_died2 par_died3 cohabitating ///
	bmi bmi_class ///-------------------------------------------------BIOMARKERS
	rmem_datec rmem_dwkc rmem_month rmem_day rmem_yr rmem_dwk ///------COGNITION
	rmem_mmn rmem_currp rmem_prevp rmem_1 rmem2 rmem3 rmem4 rmem5 rmem6 r_vf1 ///
	r_vf2 r_vf3 r_vf4 r_vf5 r_vf6 rmem_date rmem_sum rmem_ser3a rmem_ser3b ///
	rmem_ser3c rmem_ser3d rmem_ser3e rmem_ser3f rmem_ser3sum rmem_proxy1 ///
	rmem_proxy2 rmem_proxy3 rmem_proxy4 rmem_proxy5a rmem_proxy5b rmem_proxy5c ///
	rmem_proxy5d rmem_proxy5e rmem_proxy5f rmem_correct rmem_recall1 ///
	rmem_recall2 rmem_recall3 rmem_recall4 rmem_recall5 rmem_recall6 ///
	rmem_recall7 rmem_recall8 rmem_recall9 rmem_recall10 rmem_recallassist ///
	rcog_5item rcog_6item ///
	physactivity physactivity_quartile hrsexercise pa_vig  ///---------BEHAVIORS
	everdrink num_drinksday daysdrinkpermonth lownum_drinks highnum_drinks ///
	mednum_drinks smoker ///
	age birthyear female race hispanic immigrant religion ///-------DEMOGRAPHICS
	region proxy ///
	verbal_iq ///---------------------------------------------------INTELLIGENCE
	adult_srh healthins depressed_cesd  ///------------------PSYCHOSOCIAL HEALTH
	healthins_medicarepta healthins_medicareptb healthins_medicareptd ///
	healthins_medicaid healthins_va healthins_employer healthins_self ///
	comorbidities limit_stairs limit_walk_block ///--------------PHYSICAL HEALTH
	limit_bathing limit_housework ///
	xsectionweight acl_panelweight //------------------------------------WEIGHTS

// Save
save "$tmpd\ida_study_vars_acl.dta", replace

set more on