// Add Health
// IDA_Secondary_Study_Variables_AddHealth.do
// This Do file must be called from the Primary Do File (IDA_Primary_Control_Script.do)

clear
set more off
set maxvar 20000

// Master dataset variables are pulled from multiple datasets

***********************************************************
**                          SES                          **
***********************************************************
// CONSTRUCTED SES VARIABLES
import sasxport5 "$adhx\\$fahses", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id sespc_al
// Rename variable
rename sespc_al childses
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave childses
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var childses "Childhood SES score"
// Save as a temp file
tempfile _SES_conses
save `_SES_conses'

****************************************

// PARENTS (2015-2017) WAVE I PARENT DATA
import sasxport5 "$adhp\\$fahpar", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id p2ec114 p2ec18
// Rename variables
rename p2ec114 phhincome
rename p2ec18 pincome
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave phhincome pincome
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var phhincome "Childhood household income (annual)"
la var pincome "Parent income during childhood (annual)"
// Save as a temp file
tempfile _SES_parent2
save `_SES_parent2'

****************************************

// WAVE I SURVEY
import sasxport5 "$adh1\\$fah1", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id pa17 pa12 pb8 pa13 pa21
// Rename variables
rename pa17 p_empl_ft
rename pa12 p1_educ
rename pb8 p2_educ
rename pa13 pempl
rename pa21 pwelfare
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave p_empl_ft p1_educ p2_educ pempl pwelfare
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var p_empl_ft "Parent currently employed fulltime"
la var p1_educ "Parent 1's education"
la var p2_educ "Parent 2's education"
la var pempl "Parent works outside the home"
la var pwelfare "Parent received welfare during childhood"
// Save as a temp file
tempfile _SES_allwave1
save `_SES_allwave1'

****************************************

// WAVE III SURVEY
import sasxport5 "$adh3\\$fah3", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h3ed4 h3ed5 h3ed1 h3ed23 h3ed2 h3ed3 h3ed6 h3ed7 h3ed8 h3ed27 h3ec3 ///
	h3ec4 h3ec2 h3lm24 h3ec5
// Rename variables
rename h3ed4 reduc_AA
rename h3ed5 reduc_BA
rename h3ed1 reduc_cat
rename h3ed23 reduc_current
rename h3ed2 reduc_GED
rename h3ed3 reduc_HS
rename h3ed6 reduc_MA
rename h3ed7 reduc_PhD
rename h3ed8 reduc_prof
rename h3ed27 reduc_year
rename h3ec3 rincome_cat
rename h3ec4 rincome_hh
rename h3ec2 rincome_total
rename h3lm24 rincome_wages
rename h3ec5 rincome_wagescat
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave reduc_AA reduc_BA reduc_cat reduc_current reduc_GED ///
	reduc_HS reduc_MA reduc_PhD reduc_prof reduc_year rincome_cat rincome_hh ///
	rincome_total rincome_wages rincome_wagescat
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var reduc_AA "Respondent Education - Associate's"
la var reduc_BA "Respondent education - Bachelor's"
la var reduc_cat "Respondent: Educational attainment category"
la var reduc_current "Respondent currently attending school"
la var reduc_GED "Respondent Education - GED"
la var reduc_HS "Respondent Education - HS / equivalent"
la var reduc_MA "Respondent education - Master's"
la var reduc_PhD "Respondent Education - Doctorate"
la var reduc_prof "Respondent Education - professional degree"
la var reduc_year "Respondent: Highest year of education"
la var rincome_cat "Total personal income, categories"
la var rincome_hh "Repondent & Spouse/Partner Income together"
la var rincome_total "Respondent income - total (wages + other)"
la var rincome_wages "Respondent earnings"
la var rincome_wagescat "Respondent income - earnings, categorized"
// Save as a temp file
tempfile _SES_wave3
save `_SES_wave3'

****************************************

// WAVE IV SURVEY
import sasxport5 "$adh4\\$fah4", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h4ec16 h4ec9 h4ed3a h4ed6 h4ed1 h4ed2 h4ec1 h4ec2 h4ec19
// Rename variables
rename h4ec16 pwelfare
rename h4ec9 rassets_status
rename h4ed3a reduc_cat
rename h4ed6 reduc_current
rename h4ed1 reduc_HS
rename h4ed2 reduc_year
rename h4ec1 rincome_hh
rename h4ec2 rincome_wages
rename h4ec19 rses_4cat
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave pwelfare rassets_status reduc_cat reduc_current reduc_HS ///
	reduc_year rincome_hh rincome_wages rses_4cat
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var pwelfare "Parent received welfare during childhood"
la var rassets_status "Respondent - debts, even, or assets if liquirified"
la var reduc_cat "Respondent: Educational attainment category"
la var reduc_current "Respondent currently attending school"
la var reduc_HS "Respondent Education - HS / equivalent"
la var reduc_year "Respondent: Highest year of education"
la var rincome_hh "Repondent & Spouse/Partner Income together"
la var rincome_wages "Respondent earnings"
la var rses_4cat "4-category SES"
// Save as a temp file
tempfile _SES_wave4
save `_SES_wave4'

****************************************

// WAVE V SURVEY
import sasxport5 "$adh5\\$fah5", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h5ec6 h5od11 h5ec2 h5ec1 h5ec9
// Rename variables
rename h5ec6 rassets_owe
rename h5od11 reduc_year
rename h5ec2 rincome_hh
rename h5ec1 rincome_wages
rename h5ec9 rses_4cat
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave rassets_owe reduc_year rincome_hh rincome_wages rses_4cat
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var rassets_owe "Respondent - total you would owe"
la var reduc_year "Respondent: Highest year of education"
la var rincome_hh "Repondent & Spouse/Partner Income together"
la var rincome_wages "Respondent earnings"
la var rses_4cat "4-category SES"
// Save as a temp file
tempfile _SES_wave5
save `_SES_wave5'

***********************************************************
**                 SOCIAL RELATIONSHIPS                  **
***********************************************************
// WAVE IV CONSTRUCTED CURRENT RELATIONSHIP STATUS
import sasxport5 "$adhx\\$fahcrl", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id c4var049
// Rename variables
rename c4var049 marital_status
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave marital_status
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var marital_status "Current marital status"
// Save as a temp file
tempfile _SR_currel_4
save `_SR_currel_4'

****************************************

// IN SCHOOL SURVEY
import sasxport5 "$adhs\\$fahsch", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id s44a1 s44a2 s44a3 s44a4 s44a5 s44a6 s44a7 s44a8 s44a9 s44a10 s44a11 ///
	s44a12 s44a13 s44a14 s44a15 s44a16 s44a17 s44a18 s44a19 s44a20 s44a21 ///
	s44a22 s44a23 s44a24 s44a25 s44a26 s44a27 s44a28 s44a29 s44a30 s44a31 ///
	s44a32 s44a33 s44
// Rename variables
rename s44a1 sch_activity1
rename s44a2 sch_activity2
rename s44a3 sch_activity3
rename s44a4 sch_activity4
rename s44a5 sch_activity5
rename s44a6 sch_activity6
rename s44a7 sch_activity7
rename s44a8 sch_activity8
rename s44a9 sch_activity9
rename s44a10 sch_activity10
rename s44a11 sch_activity11
rename s44a12 sch_activity12
rename s44a13 sch_activity13
rename s44a14 sch_activity14
rename s44a15 sch_activity15
rename s44a16 sch_activity16
rename s44a17 sch_activity17
rename s44a18 sch_activity18
rename s44a19 sch_activity19
rename s44a20 sch_activity20
rename s44a21 sch_activity21
rename s44a22 sch_activity22
rename s44a23 sch_activity23
rename s44a24 sch_activity24
rename s44a25 sch_activity25
rename s44a26 sch_activity26
rename s44a27 sch_activity27
rename s44a28 sch_activity28
rename s44a29 sch_activity29
rename s44a30 sch_activity30
rename s44a31 sch_activity31
rename s44a32 sch_activity32
rename s44a33 sch_activity33
rename s44 sch_activity_none
// Create wave and study variables
gen str6 wave = "School"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave sch_activity1 sch_activity2 sch_activity3 sch_activity4 ///
	sch_activity5 sch_activity6 sch_activity7 sch_activity8 sch_activity9 ///
	sch_activity10 sch_activity11 sch_activity12 sch_activity13 ///
	sch_activity14 sch_activity15 sch_activity16 sch_activity17 ///
	sch_activity18 sch_activity19 sch_activity20 sch_activity21 ///
	sch_activity22 sch_activity23 sch_activity24 sch_activity25 ///
	sch_activity26 sch_activity27 sch_activity28 sch_activity29 ///
	sch_activity30 sch_activity31 sch_activity32 sch_activity33 ///
	sch_activity_none
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var sch_activity1 "Participating in French club"
la var sch_activity2 "Participating in German club"
la var sch_activity3 "Participating in Latin club"
la var sch_activity4 "Participating in Spanish club"
la var sch_activity5 "Participating in Book club"
la var sch_activity6 "Participating in Computer club"
la var sch_activity7 "Participating in Debate team"
la var sch_activity8 "Participating in Drama club"
la var sch_activity9 "Participating in Future Farmers of America"
la var sch_activity10 "Participating in History club"
la var sch_activity11 "Participating in Math club"
la var sch_activity12 "Participating in Science club"
la var sch_activity13 "Participating in Band"
la var sch_activity14 "Participating in Cheerleading/dance team"
la var sch_activity15 "Participating in Chorus or choir"
la var sch_activity16 "Participating in Orchestra"
la var sch_activity17 "Participating in Other club or organization"
la var sch_activity18 "Participating in Baseball/softball"
la var sch_activity19 "Participating in Basketball"
la var sch_activity20 "Participating in Field hockey"
la var sch_activity21 "Participating in Football"
la var sch_activity22 "Participating in Ice Hockey"
la var sch_activity23 "Participating in Soccer"
la var sch_activity24 "Participating in Swimming"
la var sch_activity25 "Participating in Tennis"
la var sch_activity26 "Participating in Track"
la var sch_activity27 "Participating in Volleyball"
la var sch_activity28 "Participating in Wrestling"
la var sch_activity29 "Participating in Other sport"
la var sch_activity30 "Participating in Newspaper"
la var sch_activity31 "Participating in Honor society"
la var sch_activity32 "Participating in Student council"
la var sch_activity33 "Participating in Yearbook"
la var sch_activity_none "Do not participate in any activities"
// Save as a temp file
tempfile _SR_Inschool
save `_SR_Inschool'

****************************************

// WAVE I SCHOOL NETWORK DATA
import sasxport5 "$adhs\\$fahnet", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id idgx2 odgx2
// Rename variables
rename idgx2 fri_indegree
rename odgx2 fri_outdegree
// Create wave and study variables
gen str6 wave = "School"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave fri_indegree fri_outdegree
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var fri_indegree "Number of people who nominated the respondent"
la var fri_outdegree "Number of friends the respondent nominated"
// Save as a temp file
tempfile _SR_network
save `_SR_network'

****************************************

// WAVE I SURVEY
import sasxport5 "$adh1\\$fah1", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h1ed19 h1ed20 h1ed22 h1re3 h1pr5 h1pr8 h1pr7 h1wp17a h1wp17b h1wp17c ///
	h1wp17d h1wp17e h1wp17f h1wp17g h1wp17h h1wp17i h1wp17j h1wp17k h1wp18a ///
	h1wp18b h1wp18c h1wp18d h1wp18e h1wp18f h1wp18g h1wp18h h1wp18i h1wp18j ///
	h1wp18k h1nm2 h1nf2 h1pf1 h1pf23 h1wp9 h1wp13 h1pf5 h1pf25 h1pf4 h1pf24 ///
	h1pr3 h1da7 h1pr4
// Rename variables
rename h1ed19 sch_close
rename h1ed20 sch_feel_part
rename h1ed22 sch_happy
rename h1re3 religious_attend
rename h1pr5 fam_understand
rename h1pr8 fam_attention
rename h1pr7 fam_fun
rename h1wp17a resmom_activities_shop
rename h1wp17b resmom_activities_sport
rename h1wp17c resmom_activities_religion
rename h1wp17d resmom_activities_dating
rename h1wp17e resmom_activities_movie
rename h1wp17f resmom_activities_problem
rename h1wp17g resmom_activities_argument
rename h1wp17h resmom_activities_grades
rename h1wp17i resmom_activities_project
rename h1wp17j resmom_activities_sch
rename h1wp17k resmom_activities_none
rename h1wp18a resdad_activities_shop
rename h1wp18b resdad_activities_sport
rename h1wp18c resdad_activities_religion
rename h1wp18d resdad_activities_dating
rename h1wp18e resdad_activities_movie
rename h1wp18f resdad_activities_problem
rename h1wp18g resdad_activities_argument
rename h1wp18h resdad_activities_grades
rename h1wp18i resdad_activities_project
rename h1wp18j resdad_activities_sch
rename h1wp18k resdad_activities_none
rename h1nm2 biomom_alive
rename h1nf2 biodad_alive
rename h1pf1 mom_warm
rename h1pf23 dad_warm
rename h1wp9 mom_close
rename h1wp13 dad_close
rename h1pf5 mom_relationship
rename h1pf25 dad_relationship
rename h1pf4 mom_comm
rename h1pf24 dad_comm
rename h1pr3 par_care
rename h1da7 fri_contact
rename h1pr4 fri_care
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave sch_close sch_feel_part sch_happy religious_attend ///
	fam_understand fam_attention fam_fun resmom_activities_shop ///
	resmom_activities_sport resmom_activities_religion ///
	resmom_activities_dating resmom_activities_movie ///
	resmom_activities_problem resmom_activities_argument ///
	resmom_activities_grades resmom_activities_project resmom_activities_sch ///
	resmom_activities_none resdad_activities_shop resdad_activities_sport ///
	resdad_activities_religion resdad_activities_dating ///
	resdad_activities_movie resdad_activities_problem ///
	resdad_activities_argument resdad_activities_grades ///
	resdad_activities_project resdad_activities_sch resdad_activities_none ///
	biomom_alive biodad_alive mom_warm dad_warm mom_close dad_close ///
	mom_relationship dad_relationship mom_comm dad_comm par_care ///
	fri_contact fri_care
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var sch_close "You feel close to people at your school"
la var sch_feel_part "You feel like a part of your school"
la var sch_happy "You are happy at your school"
la var religious_attend "Frequency attend religious services"
la var fam_understand "Family understands you"
la var fam_attention "Family pays attention to you"
la var fam_fun "Have fun with family"
la var resmom_activities_shop "Gone shopping with your mom"
la var resmom_activities_sport "Played a sport with your mom"
la var resmom_activities_religion "Gone to a church-related event with your mom"
la var resmom_activities_dating "Talked to your mom about someone you're dating or a party you went to"
la var resmom_activities_movie "Gone to a movie, play, museum, concert, or sports event with your mom"
la var resmom_activities_problem "Talked with your mom about a person problem"
la var resmom_activities_argument "Have had a serious argument about your behavior with your mom"
la var resmom_activities_grades "Have talked about your school work or grades with your mom"
la var resmom_activities_project "Worked on a project for school with your mom"
la var resmom_activities_sch "Have talked about other things you're doing in school with your mom"
la var resmom_activities_none "Haven't done any of these activities with your mom"
la var resdad_activities_shop "Gone shopping with your dad"
la var resdad_activities_sport "Played a sport with your dad"
la var resdad_activities_religion "Gone to a church-related event with your dad"
la var resdad_activities_dating "Talked to your dad about someone you're dating or a party you went to"
la var resdad_activities_movie "Gone to a movie, play, museum, concert, or sports event with your dad"
la var resdad_activities_problem "Talked with your dad about a person problem"
la var resdad_activities_argument "Have had a serious argument about your behavior with your dad"
la var resdad_activities_grades "Have talked about your school work or grades with your dad"
la var resdad_activities_project "Worked on a project for school with your dad"
la var resdad_activities_sch "Have talked about other things you're doing in school with your dad"
la var resdad_activities_none "Haven't done any of these activities with your dad"
la var biomom_alive "Biological mother still living"
la var biodad_alive "Biological father still living"
la var mom_warm "Mother is warm and loving"
la var dad_warm "Father is warm and loving"
la var mom_close "How close do you feel to your mother"
la var dad_close "How close do you feel to your father"
la var mom_relationship "Satisfied with relationship with your mother"
la var dad_relationship "Satisfied with relationship with your father"
la var mom_comm "Satisfied with relationship with your communication with your mother"
la var dad_comm "Satisfied with relationship with your communication with your father"
la var par_care "Parents care about you"
la var fri_contact "Frequency of contact with friends"
la var fri_care "Friends care about you"
// Save as a temp file
tempfile _SR_allwave1
save `_SR_allwave1'

****************************************

// WAVE II SURVEY
import sasxport5 "$adh2\\$fah2", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h2ed15 h2ed16 h2ed18 h2re3 h2pr5 h2pr8 h2pr7 h2wp17a h2wp17b h2wp17c ///
	h2wp17d h2wp17e h2wp17f h2wp17g h2wp17h h2wp17i h2wp17j h2wp17k h2wp18a ///
	h2wp18b h2wp18c h2wp18d h2wp18e h2wp18f h2wp18g h2wp18h h2wp18i h2wp18j ///
	h2wp18k h2nm4 h2nf4 h2pf1 h2pf8 h2wp9 h2wp13 h2pf5 h2pf10 h2pf4 h2pf9 ///
	h2pr3 h2gi5 h2da7 h2pr4
// Rename variables
rename h2ed15 sch_close
rename h2ed16 sch_feel_part
rename h2ed18 sch_happy
rename h2re3 religious_attend
rename h2pr5 fam_understand
rename h2pr8 fam_attention
rename h2pr7 fam_fun
rename h2wp17a resmom_activities_shop
rename h2wp17b resmom_activities_sport
rename h2wp17c resmom_activities_religion
rename h2wp17d resmom_activities_dating
rename h2wp17e resmom_activities_movie
rename h2wp17f resmom_activities_problem
rename h2wp17g resmom_activities_argument
rename h2wp17h resmom_activities_grades
rename h2wp17i resmom_activities_project
rename h2wp17j resmom_activities_sch
rename h2wp17k resmom_activities_none
rename h2wp18a resdad_activities_shop
rename h2wp18b resdad_activities_sport
rename h2wp18c resdad_activities_religion
rename h2wp18d resdad_activities_dating
rename h2wp18e resdad_activities_movie
rename h2wp18f resdad_activities_problem
rename h2wp18g resdad_activities_argument
rename h2wp18h resdad_activities_grades
rename h2wp18i resdad_activities_project
rename h2wp18j resdad_activities_sch
rename h2wp18k resdad_activities_none
rename h2nm4 biomom_alive
rename h2nf4 biodad_alive
rename h2pf1 mom_warm
rename h2pf8 dad_warm
rename h2wp9 mom_close
rename h2wp13 dad_close
rename h2pf5 mom_relationship
rename h2pf10 dad_relationship
rename h2pf4 mom_comm
rename h2pf9 dad_comm
rename h2pr3 par_care
rename h2gi5 marital_status
rename h2da7 fri_contact
rename h2pr4 fri_care
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave sch_close sch_feel_part sch_happy religious_attend ///
	fam_understand fam_attention fam_fun resmom_activities_shop ///
	resmom_activities_sport resmom_activities_religion ///
	resmom_activities_dating resmom_activities_movie ///
	resmom_activities_problem resmom_activities_argument ///
	resmom_activities_grades resmom_activities_project resmom_activities_sch ///
	resmom_activities_none resdad_activities_shop resdad_activities_sport ///
	resdad_activities_religion resdad_activities_dating ///
	resdad_activities_movie resdad_activities_problem ///
	resdad_activities_argument resdad_activities_grades ///
	resdad_activities_project resdad_activities_sch resdad_activities_none ///
	biomom_alive biodad_alive mom_warm dad_warm mom_close dad_close ///
	mom_relationship dad_relationship mom_comm dad_comm par_care ///
	marital_status fri_contact fri_care
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var sch_close "You feel close to people at your school"
la var sch_feel_part "You feel like a part of your school"
la var sch_happy "You are happy at your school"
la var religious_attend "Frequency attend religious services"
la var fam_understand "Family understands you"
la var fam_attention "Family pays attention to you"
la var fam_fun "Have fun with family"
la var resmom_activities_shop "Gone shopping with your mom"
la var resmom_activities_sport "Played a sport with your mom"
la var resmom_activities_religion "Gone to a church-related event with your mom"
la var resmom_activities_dating "Talked to your mom about someone you're dating or a party you went to"
la var resmom_activities_movie "Gone to a movie, play, museum, concert, or sports event with your mom"
la var resmom_activities_problem "Talked with your mom about a person problem"
la var resmom_activities_argument "Have had a serious argument about your behavior with your mom"
la var resmom_activities_grades "Have talked about your school work or grades with your mom"
la var resmom_activities_project "Worked on a project for school with your mom"
la var resmom_activities_sch "Have talked about other things you're doing in school with your mom"
la var resmom_activities_none "Haven't done any of these activities with your mom"
la var resdad_activities_shop "Gone shopping with your dad"
la var resdad_activities_sport "Played a sport with your dad"
la var resdad_activities_religion "Gone to a church-related event with your dad"
la var resdad_activities_dating "Talked to your dad about someone you're dating or a party you went to"
la var resdad_activities_movie "Gone to a movie, play, museum, concert, or sports event with your dad"
la var resdad_activities_problem "Talked with your dad about a person problem"
la var resdad_activities_argument "Have had a serious argument about your behavior with your dad"
la var resdad_activities_grades "Have talked about your school work or grades with your dad"
la var resdad_activities_project "Worked on a project for school with your dad"
la var resdad_activities_sch "Have talked about other things you're doing in school with your dad"
la var resdad_activities_none "Haven't done any of these activities with your dad"
la var biomom_alive "Biological mother still living"
la var biodad_alive "Biological father still living"
la var mom_warm "Mother is warm and loving"
la var dad_warm "Father is warm and loving"
la var mom_close "How close do you feel to your mother"
la var dad_close "How close do you feel to your father"
la var mom_relationship "Satisfied with relationship with your mother"
la var dad_relationship "Satisfied with relationship with your father"
la var mom_comm "Satisfied with relationship with your communication with your mother"
la var dad_comm "Satisfied with relationship with your communication with your father"
la var par_care "Parents care about you"
la var marital_status "Current marital status"
la var fri_contact "Frequency of contact with friends"
la var fri_care "Friends care about you"
// Save as a temp file
tempfile _SR_wave2
save `_SR_wave2'

****************************************

// WAVE III SURVEY - SECTIONS 17 AND 19
*** The following code section creates Wave III relationship status

// Derive variable of single status
import sasxport5 "$adh3\\$fah3s17", clear
// Recode refused don't know, missing, and N/A to missing
recode h3tr1 (6 8 9=.), gen (rel_clean)
// Create variable to indicate whether the respondent is in a current relationship
sort aid
bysort aid: egen relationship_current = max(rel_clean)
// Create 'single' variable
gen single = 1 if relationship_current==0
// Keep one observation per person, then save
bysort aid: keep if _n == 1
keep aid single
// Save as a temp file
tempfile single
save `single'

// Get data for relationship start date from Section 19
import sasxport5 "$adh3\\$fah3s19", clear
// Combine aid and rrelno so have unique ids for everyone
egen rel_aid = concat(aid rrelno)
keep rel_aid h3rd6m h3rd6y
// Save as a temp file
tempfile time
save `time'

// Get data for interview date
import sasxport5 "$adh3\\$fah3", clear
keep aid imonth3 iyear3 iday3
// Save as a temp file
tempfile interview_date
save `interview_date'

// Generate variables cohabitating, married, and dating
import sasxport5 "$adh3\\$fah3s17"	, clear
egen rel_aid = concat(aid rrelno)
// Merge in relationship start date
merge 1:1 rel_aid using `time', nogen
// Merge in interview_date
merge m:1 aid using `interview_date'
// Drop if not in sect17 dataset
drop if _merge == 2
drop _merge
// Clean data timing variables
recode h3rd6y (9995/9999 =.)
recode h3rd6m (95/99=.)
// Put month, day, and year together in one variable
gen rel_start_date = mdy(h3rd6m, 15, h3rd6y)
format rel_start_date %d
gen idate = mdy(imonth3, imonth3, iyear3)
format idate %d
// Generate variable for time dating in months
gen date_time_clean = int((idate - rel_start_date)/31)
// Drop if dating start date after interview date
drop if date_time_clean <0
sort aid
// Make the dating in months the maximum amount of time
bysort aid: egen date_time = max(date_time_clean)
// Rename variable
rename h3tr1 relationship_current
// Only keep the relationships that are current
keep if relationship_current == 1
// Recode refused don't know, missing, and N/A to missing
// Recode in the past, but not now as 0
// Now coded as 0 = not cohabitating, 1 = cohabitating
recode h3tr11 (6 8 9 =.) (2=0), gen (cohab_clean)
recode h3tr12 (6 8 9 =.) (2=0), gen (marital_clean)
// Recode refused don't know, missing, and N/A to missing
recode h3tr2 (6 8 9 =.), gen (dating_clean)
sort aid
// Make values consistent across respondents
// If responded they are cohabitating then make that the value
bysort aid: egen cohabitating = max(cohab_clean)
*do the same for married and dating
bysort aid: egen marital_status = max(marital_clean)
bysort aid: egen dating_3months = max(dating_clean)
// Keep one observation per person
bys aid: keep if _n == 1
// Merge in the single dataset
merge 1:1 aid using `single'
// Recode cohabitating, married, and dating = 0 if respondent is single
replace cohabitating = 0 if single == 1
replace marital_status = 0 if single == 1
replace dating_3months = 0 if single == 1
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "Add Health"
// Rename the ID variable and convert to string if numeric
rename aid id
// Reduce variable set
keep id study wave marital_status relationship_current cohabitating ///
	dating_3months rel_start_date
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var marital_status "Marital status"
la var relationship_current "Current relationship"
la var cohabitating "Cohabitating with partner"
la var dating_3months "Dating for at least three months"
la var rel_start_date "Date relationship started"
// Save as a temp file
tempfile ah_w3_sects17_19
save `ah_w3_sects17_19'

****************************************

// WAVE III SURVEY
import sasxport5 "$adh3\\$fah3", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h3re24 h3cc3 h3wp8 h3wp12 h3wp45 h3wp52 h3wp20 h3wp25 imonth3 iday3 iyear3 h3da15
// Rename existing or construct new variables
rename h3re24 religious_attend
rename h3cc3 volunteer
rename h3wp8 biomom_alive
rename h3wp12 biodad_alive
rename h3wp45 mom_warm
rename h3wp52 dad_warm
rename h3wp20 mom_close
rename h3wp25 dad_close
gen interview_date = mdy(imonth3, iday3, iyear3)
rename h3da15 fri_contact
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave religious_attend volunteer biomom_alive biodad_alive mom_warm dad_warm mom_close dad_close interview_date fri_contact
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var religious_attend "Frequency attend religious services"
la var volunteer "Volunteer: yes or no"
la var biomom_alive "Biological mother still living"
la var biodad_alive "Biological father still living"
la var mom_warm "Mother is warm and loving"
la var dad_warm "Father is warm and loving"
la var mom_close "How close do you feel to your mother"
la var dad_close "How close do you feel to your father"
la var interview_date "Interview date"
la var fri_contact "Frequency of contact with friends"
// Save as a temp file
tempfile _SR_wave3
save `_SR_wave3'

****************************************

// WAVE IV SURVEY
import sasxport5 "$adh4\\$fah4", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h4re7 h4da26 h4kk15b h4kk15d h4kk15c h4wp1 h4wp7 h4rd9 h4rd7d h4ws4
// Rename variables
rename h4re7 religious_attend
rename h4da26 volunteerhrs
rename h4kk15b child_close
rename h4kk15d child_overwhelm
rename h4kk15c child_stress
rename h4wp1 biomom_alive
rename h4wp7 biodad_alive
rename h4rd9 sppn_rel_sat
rename h4rd7d sppn_listen
rename h4ws4 fri_num
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave religious_attend volunteerhrs child_close child_overwhelm ///
	child_stress biomom_alive biodad_alive sppn_rel_sat sppn_listen fri_num
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var religious_attend "Frequency attend religious services"
la var volunteerhrs "Volunteer hours"
la var child_close "Feel close to children"
la var child_overwhelm "Feel overwhelmed by being a parent"
la var child_stress "Your children are a main source of stress"
la var biomom_alive "Biological mother still living"
la var biodad_alive "Biological father still living"
la var sppn_rel_sat "Satisfied with relationship with spouse or partner"
la var sppn_listen "Spouse/partner listens when you need to talk"
la var fri_num "Number of friends"
// Save as a temp file
tempfile _SR_wave4
save `_SR_wave4'

****************************************

// WAVE V SURVEY
import sasxport5 "$adh5\\$fah5", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h5ss2 h5re2 h5ss7 h5ss4c h5ss3c h5ss5c h5se23 h5pg32 h5ss3b h5ss4b ///
	h5ss5b h5pg34b h5pg34d h5pg34c h5wp4 h5wp18 h5hr1 h5tr5 h5tr15 h5ss3a ///
	h5ss4a h5ss5a h5ss6 h5ss1 h5ss4d h5ss3d h5ss5d
// Rename variables
rename h5ss2 neigh_contact
rename h5re2 religious_attend
rename h5ss7 volunteerhrs
rename h5ss4c fam_rely
rename h5ss3c fam_open
rename h5ss5c fam_demand_critic
rename h5se23 child_bio_num
rename h5pg32 child_nonbio_num
rename h5ss3b child_open
rename h5ss4b child_rely
rename h5ss5b child_demand_critic
rename h5pg34b child_close
rename h5pg34d child_overwhelm
rename h5pg34c child_stress
rename h5wp4 biomom_alive
rename h5wp18 biodad_alive
rename h5hr1 marital_status
rename h5tr5 cohabitation
rename h5tr15 sppn_rel_sat
rename h5ss3a sppn_open
rename h5ss4a sppn_rely
rename h5ss5a sppn_demand_critic
rename h5ss6 fri_num
rename h5ss1 fri_contact
rename h5ss4d fri_rely
rename h5ss3d fri_open
rename h5ss5d fri_demand_critic
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave neigh_contact religious_attend volunteerhrs fam_rely ///
	fam_open fam_demand_critic child_bio_num child_nonbio_num child_open ///
	child_rely child_demand_critic child_close child_overwhelm child_stress ///
	biomom_alive biodad_alive marital_status cohabitation sppn_rel_sat ///
	sppn_open sppn_rely sppn_demand_critic fri_num fri_contact fri_rely ///
	fri_open fri_demand_critic
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var neigh_contact "Frequency of contact with neighbors"
la var religious_attend "Frequency attend religious services"
la var volunteerhrs "Volunteer hours"
la var fam_rely "Can rely on your family"
la var fam_open "Open up to your family"
la var fam_demand_critic "Family members make too many demands and criticize you"
la var child_bio_num "Number of living biological children"
la var child_nonbio_num "Number of non-biological children"
la var child_open "Open up to children in need to talk"
la var child_rely "Can rely on your children"
la var child_demand_critic "Your children make too many demands"
la var child_close "Feel close to children"
la var child_overwhelm "Feel overwhelmed by being a parent"
la var child_stress "Your children are a main source of stress"
la var biomom_alive "Biological mother still living"
la var biodad_alive "Biological father still living"
la var marital_status "Current marital status"
la var cohabitation "Cohabitating with partner"
la var sppn_rel_sat "Satisfied with relationship with spouse or partner"
la var sppn_open "Open up to your spouse/partner"
la var sppn_rely "Can rely on your spouse/partner"
la var sppn_demand_critic "Spouse/partner make too many demands and criticize you"
la var fri_num "Number of friends"
la var fri_contact "Frequency of contact with friends"
la var fri_rely "Can rely on your friends"
la var fri_open "Can open up to your friends"
la var fri_demand_critic "Friends make too many demands and criticize you"
// Save as a temp file
tempfile _SR_wave5
save `_SR_wave5'

***********************************************************
**                      BIOMARKERS                       **
***********************************************************
// WAVE I SURVEY
import sasxport5 "$adh1\\$fah1", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h1gh59a h1gh59b h1gh60 h1gh60 h1gh59a  h1gh59b
// Construct new variables
gen height = ((h1gh59a*12) + h1gh59b) * 0.0254
gen weight = h1gh60 * 0.454
gen bmi = ((h1gh60*0.454) / ((((h1gh59a*12) + h1gh59b) * 0.0254)^2))
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave height weight bmi
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var height "Height (m)"
la var weight "Weight (kg)"
la var bmi "Body mass index (kg/m2)"
// Save as a temp file
tempfile _Bio_allwave1
save `_Bio_allwave1'

****************************************

// WAVE II SURVEY
import sasxport5 "$adh2\\$fah2", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h2ws16hf h2ws16hi h2ws16w h2ws16w h2ws16hf h2ws16hi
// Construct new variables
gen height = ((h2ws16hf*12) + h2ws16hi) * 0.0254
gen weight = h2ws16w * 0.454
gen bmi = ((h2ws16w*0.454) / ((((h2ws16hf*12) + h2ws16hi) * 0.0254)^2))
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave height weight bmi
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var height "Height (m)"
la var weight "Weight (kg)"
la var bmi "Body mass index (kg/m2)"
// Save as a temp file
tempfile _Bio_wave2
save `_Bio_wave2'

****************************************

// WAVE III SURVEY
import sasxport5 "$adh3\\$fah3", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h3hgt_f h3hgt_i h3wgt h3wgt h3hgt_f h3hgt_i
// Construct new variables
gen height = ((h3hgt_f*12) + h3hgt_i) * 0.0254
gen weight = h3wgt * 0.454
gen bmi = ((h3wgt*0.454) / ((((h3hgt_f*12) + h3hgt_i) * 0.0254)^2))
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave height weight bmi
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var height "Height (m)"
la var weight "Weight (kg)"
la var bmi "Body mass index (kg/m2)"
// Save as a temp file
tempfile _Bio_wave3
save `_Bio_wave3'

****************************************

// WAVE IV MEASURES OF INFLAMMATION AND IMMUNE FUNCTION
import sasxport5 "$adh4\\$fah4crp", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id crp c_crp
// Rename variables
rename crp crp
rename c_crp crp_class
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave crp crp_class
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var crp "C-reactive protein (mg/l)"
la var crp_class "crp risk classification"
// Save as a temp file
tempfile _Bio_crp_ebv_4
save `_Bio_crp_ebv_4'

****************************************

// WAVE IV MEASURES OF GLUCOSE HOMEOSTASIS
import sasxport5 "$adh4\\$fah4glu", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id hba1c c_hba1c c_fglu c_nfglu c_joint
// Rename variables
rename hba1c hba1c
rename c_hba1c hba1c_class
rename c_fglu fastgluc_class
rename c_nfglu nonfastgluc_class
rename c_joint diabetes
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave hba1c hba1c_class fastgluc_class nonfastgluc_class diabetes
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hba1c "Hemoglobin A1c (%)"
la var hba1c_class "HbA1c diabetes risk classification"
la var fastgluc_class "Classification of fasting glucose"
la var nonfastgluc_class "Classification of non-fasting glucose"
la var diabetes "dichtomous measure for evidence of diabetes"
// Save as a temp file
tempfile _Bio_glu_a1c_4
save `_Bio_glu_a1c_4'

****************************************

// WAVE IV LIPIDS
import sasxport5 "$adh4\\$fah4lpd", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id tc ldl hdl tg c_joint2
// Rename variables
rename tc totchol
rename ldl ldlchol
rename hdl hdlchol
rename tg triglyceride
rename c_joint2 highchol
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave totchol ldlchol hdlchol triglyceride highchol
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var totchol "Total Cholesterol, mg/dL"
la var ldlchol "LDL Cholesterol, mg/dL"
la var hdlchol "HDL Cholesterol, mg/dL"
la var triglyceride "Triglycerides"
la var highchol "dichtomous measure for evidence of high cholesterol or triglycerides"
// Save as a temp file
tempfile _Bio_lipids_4
save `_Bio_lipids_4'

****************************************

// WAVE IV SURVEY
import sasxport5 "$adh4\\$fah4", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h4hgt h4wgt h4bmi h4bmicls h4waist h4dbp h4sbp h4bpcls h4pr h4pp ///
	h4map h4id5c
// Rename variables
rename h4hgt height
rename h4wgt weight
rename h4bmi bmi
rename h4bmicls bmi_class
rename h4waist wc
rename h4dbp diastolicbp
rename h4sbp systolicbp
rename h4bpcls bp_class
rename h4pr pulse
rename h4pp pulsepress
rename h4map meanarterpres
rename h4id5c hypertension
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave height weight bmi bmi_class wc diastolicbp systolicbp ///
	bp_class pulse pulsepress meanarterpres hypertension
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var height "Height (m)"
la var weight "Weight (kg)"
la var bmi "Body mass index (kg/m2)"
la var bmi_class "BMI category"
la var wc "Waist circumference (cm)"
la var diastolicbp "Diastolic BP, mm/Hg"
la var systolicbp "Systolic BP, mm/Hg"
la var bp_class "blood pressure risk classification"
la var pulse "Pulse, beats/minute"
la var pulsepress "Pluse pressure, mm/Hg"
la var meanarterpres "Mean arterial pressure, mm/Hg"
la var hypertension "dichtomous measure for evidence of hypertension"
// Save as a temp file
tempfile _Bio_wave4
save `_Bio_wave4'

****************************************

// WAVE V ANTHROPOMETRICS
import sasxport5 "$adh5\\$fah5anth", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h5hgt h5wgt h5bmi h5bmicls h5waist h5wstcls
// Rename variables
rename h5hgt height
rename h5wgt weight
rename h5bmi bmi
rename h5bmicls bmi_class
rename h5waist wc
rename h5wstcls wc_class
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave height weight bmi bmi_class wc wc_class
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var height "Height (m)"
la var weight "Weight (kg)"
la var bmi "Body mass index (kg/m2)"
la var bmi_class "BMI category"
la var wc "Waist circumference (cm)"
la var wc_class "waist circumference risk classification"
// Save as a temp file
tempfile _Bio_banthro5
save `_Bio_banthro5'

****************************************

// WAVE V CARDIOVASCULAR MEASURES
import sasxport5 "$adh5\\$fah5card", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h5dbp h5sbp h5bpcls4 h5pr h5pp h5map h5htenjc
// Rename variables
rename h5dbp diastolicbp
rename h5sbp systolicbp
rename h5bpcls4 bp_class
rename h5pr pulse
rename h5pp pulsepress
rename h5map meanarterpres
rename h5htenjc hypertension
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave diastolicbp systolicbp bp_class pulse pulsepress ///
	meanarterpres hypertension
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var diastolicbp "Diastolic BP, mm/Hg"
la var systolicbp "Systolic BP, mm/Hg"
la var bp_class "blood pressure risk classification"
la var pulse "Pulse, beats/minute"
la var pulsepress "Pluse pressure, mm/Hg"
la var meanarterpres "Mean arterial pressure, mm/Hg"
la var hypertension "dichtomous measure for evidence of high blood pressure or hypertension"
// Save as a temp file
tempfile _Bio_bcardio5
save `_Bio_bcardio5'

****************************************

// WAVE V INFLAMMATION & IMMUNE FUNCTION
import sasxport5 "$adh5\\$fah5crp", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h5crp h5ccrp
// Rename variables
rename h5crp crp
rename h5ccrp crp_class
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave crp crp_class
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var crp "C-reactive protein (mg/l)"
la var crp_class "crp risk classification"
// Save as a temp file
tempfile _Bio_bcrp5
save `_Bio_bcrp5'

****************************************

// WAVE V GLUCOSE HOMEOSTASIS
import sasxport5 "$adh5\\$fah5glu", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h5hba1c h5chba1c h5cfglu h5cnfglu h5diabjc
// Rename variables
rename h5hba1c hba1c
rename h5chba1c hba1c_class
rename h5cfglu fastgluc_class
rename h5cnfglu nonfastgluc_class
rename h5diabjc diabetes
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave hba1c hba1c_class fastgluc_class nonfastgluc_class diabetes
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hba1c "Hemoglobin A1c (%)"
la var hba1c_class "HbA1c diabetes risk classification (ADA)"
la var fastgluc_class "Classification of fasting glucose (ADA)"
la var nonfastgluc_class "Classification of non-fasting glucose (ADA)"
la var diabetes "dichtomous measure for evidence of diabetes"
// Save as a temp file
tempfile _Bio_bglua1c5
save `_Bio_bglua1c5'

****************************************

// WAVE V LIPIDS
import sasxport5 "$adh5\\$fah5lpd", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h5tcdec h5ldldec h5c2ldl h5hdldec h5tgdec h5c2tg h5hlipjc
// Rename variables
rename h5tcdec totchol
rename h5ldldec ldlchol
rename h5c2ldl ldl_class
rename h5hdldec hdlchol
rename h5tgdec triglyceride
rename h5c2tg triglyceride_class
rename h5hlipjc highchol
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave totchol ldlchol ldl_class hdlchol triglyceride ///
	triglyceride_class highchol
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var totchol "Total Cholesterol, mg/dL"
la var ldlchol "LDL Cholesterol, mg/dL"
la var ldl_class "LDL-C risk classification"
la var hdlchol "HDL Cholesterol, mg/dL"
la var triglyceride "Triglycerides"
la var triglyceride_class "triglycerides risk classification"
la var highchol "dichtomous measure for evidence of high cholesterol or triglycerides"
// Save as a temp file
tempfile _Bio_blipids5
save `_Bio_blipids5'

****************************************

// WAVE V RENAL FUNCTION
import sasxport5 "$adh5\\$fah5rnl", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h5cysc h5cgfrkc
// Rename variables
rename h5cysc cystatinc
rename h5cgfrkc renalfunction
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave cystatinc renalfunction
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var cystatinc "cystatin c"
la var renalfunction "kidney disease risk classification"
// Save as a temp file
tempfile _Bio_brenal5
save `_Bio_brenal5'

***********************************************************
**                       COGNITION                       **
***********************************************************
// WAVE IV SURVEY
import sasxport5 "$adh4\\$fah4", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id c4wd90_1 c4wd60_1 c4numscr
// Rename variables
rename c4wd90_1 immedrecall
rename c4wd60_1 delayrecall
rename c4numscr digbackwards
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave immedrecall delayrecall digbackwards
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var immedrecall "immediate recall - total # of words"
la var delayrecall "delayed recall - total # of words"
la var digbackwards "digits backwards - total score"
// Save as a temp file
tempfile _Cognition_wave4
save `_Cognition_wave4'

****************************************

// WAVE V SURVEY
import sasxport5 "$adh5\\$fah5", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id c5wd90_1 c5wd60_1 c5numscr
// Rename variables
rename c5wd90_1 immedrecall
rename c5wd60_1 delayrecall
rename c5numscr digbackwards
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave immedrecall delayrecall digbackwards
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var immedrecall "immediate recall - total # of words"
la var delayrecall "delayed recall - total # of words"
la var digbackwards "digits backwards - total score"
// Save as a temp file
tempfile _Cognition_wave5
save `_Cognition_wave5'

***********************************************************
**                 COVARIATES: ATTRITION                 **
***********************************************************
// WAVES I AND II DISPOSITION DATA
import sasxport5 "$adh1\\$fahdsp12", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id w2dsp
// Rename variable
rename w2dsp attrition
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave attrition
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var attrition "participant attrition status"
// Save as a temp file
tempfile _Cov_Attrition_w1w2dsp
save `_Cov_Attrition_w1w2dsp'

****************************************

// WAVE III DISPOSITION FILE
import sasxport5 "$adh3\\$fahdsp3", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id dsp3
// Rename variable
rename dsp3 attrition
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave attrition
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var attrition "participant attrition status"
// Save as a temp file
tempfile _Cov_Attrition_dsp3
save `_Cov_Attrition_dsp3'

****************************************

// WAVE IV DISPOSITION FILE
import sasxport5 "$adh4\\$fahdsp4", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id dsp4
// Rename variable
rename dsp4 attrition
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave attrition
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var attrition "participant attrition status"
// Save as a temp file
tempfile _Cov_Attrition_dsp4
save `_Cov_Attrition_dsp4'

****************************************

// WAVE V DISPOSITION FILE
import sasxport5 "$adh5\\$fahdsp5", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id dsp5
// Rename variable
rename dsp5 attrition
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave attrition
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var attrition "participant attrition status"
// Save as a temp file
tempfile _Cov_Attrition_dsp5
save `_Cov_Attrition_dsp5'

***********************************************************
**                 COVARIATES: BEHAVIORS                 **
***********************************************************
// WAVE I SURVEY
import sasxport5 "$adh1\\$fah1", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h1da6 h1da5 h1to12 h1to15 h1to16 h1to17 h1to5 h1to3 h1to7
// Rename variables
rename h1da6 pa_mod_wk
rename h1da5 pa_vig_wk
rename h1to12 everdrink
rename h1to15 alc_drinkfreqweek
rename h1to16 num_drinksday
rename h1to17 bingedrinking
rename h1to5 smoker
rename h1to3 eversmoke_reg
rename h1to7 dailysmokefreq
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave pa_mod_wk pa_vig_wk everdrink alc_drinkfreqweek ///
	num_drinksday bingedrinking smoker eversmoke_reg dailysmokefreq
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var pa_mod_wk "weekly frequency of moderately active sports or activities"
la var pa_vig_wk "weekly frequency of vigorous/active sports or exercise"
la var everdrink "Drink alcohol ever in past year - yes or no"
la var alc_drinkfreqweek "Number of drinks per week"
la var num_drinksday "Number of drinks consumed per occassion/days when drink"
la var bingedrinking "Days drank 5+ drinks in one sitting"
la var smoker "Monthly cigarette use - regular/current smoker if report smoking 30 days"
la var eversmoke_reg "Ever smoked regularly - yes or no"
la var dailysmokefreq "Number of cigarettes smoked per day in last 30 days"
// Save as a temp file
tempfile _Cov_Behav_allwave1
save `_Cov_Behav_allwave1'

****************************************

// WAVE II SURVEY
import sasxport5 "$adh2\\$fah2", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h2da6 h2da5 h2nu77 h2to15 h2to19 h2to20 h2to21 h2to5 h2to3 h2to7
// Rename variables
rename h2da6 pa_mod_wk
rename h2da5 pa_vig_wk
rename h2nu77 fastfood
rename h2to15 everdrink
rename h2to19 alc_drinkfreqweek
rename h2to20 num_drinksday
rename h2to21 bingedrinking
rename h2to5 smoker
rename h2to3 eversmoke_reg
rename h2to7 dailysmokefreq
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave pa_mod_wk pa_vig_wk fastfood everdrink alc_drinkfreqweek ///
	num_drinksday bingedrinking smoker eversmoke_reg dailysmokefreq
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var pa_mod_wk "weekly frequency of moderately active sports or activities"
la var pa_vig_wk "weekly frequency of vigorous/active sports or exercise"
la var fastfood "fast food consumption in past week"
la var everdrink "Drink alcohol ever in past year - yes or no"
la var alc_drinkfreqweek "Number of drinks per week"
la var num_drinksday "Number of drinks consumed per occassion/days when drink"
la var bingedrinking "Days drank 5+ drinks in one sitting"
la var smoker "Monthly cigarette use - regular/current smoker if report smoking 30 days"
la var eversmoke_reg "Ever smoked regularly - yes or no"
la var dailysmokefreq "Number of cigarettes smoked per day in last 30 days"
// Save as a temp file
tempfile _Cov_Behav_wave2
save `_Cov_Behav_wave2'

****************************************

// WAVE III SURVEY
import sasxport5 "$adh3\\$fah3", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h3da8 h3da10 h3da11 h3da12 h3da14 h3gh5 h3gh18 h3to37 h3to38 h3to39 ///
	h3to40 h3to7 h3to4 h3to10
// Rename variables
rename h3da8 pa_mod_wk
rename h3da10 pa_teamsports_wk
rename h3da11 pa_indvsports_wk
rename h3da12 pa_gymtraining_wk
rename h3da14 pa_walking_wk
rename h3gh5 fitnesscenter
rename h3gh18 fastfood
rename h3to37 everdrink
rename h3to38 alc_drinkfreqweek
rename h3to39 num_drinksday
rename h3to40 bingedrinking
rename h3to7 smoker
rename h3to4 eversmoke_reg
rename h3to10 dailysmokefreq
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave pa_mod_wk pa_teamsports_wk pa_indvsports_wk ///
	pa_gymtraining_wk pa_walking_wk fitnesscenter fastfood everdrink ///
	alc_drinkfreqweek num_drinksday bingedrinking smoker eversmoke_reg ///
	dailysmokefreq
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var pa_mod_wk "weekly frequency of moderately active sports or activities"
la var pa_teamsports_wk "weekly frequency of vigorous team sports"
la var pa_indvsports_wk "weekly frequency of vigorous individual sports"
la var pa_gymtraining_wk "weekly frequency of gymnastics, weight lifting, strength training"
la var pa_walking_wk "weekly frequency of walking for exercise"
la var fitnesscenter "times per week use fitness or recreation center"
la var fastfood "fast food consumption in past week"
la var everdrink "Drink alcohol ever in past year - yes or no"
la var alc_drinkfreqweek "Number of drinks per week"
la var num_drinksday "Number of drinks consumed per occassion/days when drink"
la var bingedrinking "Days drank 5+ drinks in one sitting"
la var smoker "Monthly cigarette use - regular/current smoker if report smoking 30 days"
la var eversmoke_reg "Ever smoked regularly - yes or no"
la var dailysmokefreq "Number of cigarettes smoked per day in last 30 days"
// Save as a temp file
tempfile _Cov_Behav_wave3
save `_Cov_Behav_wave3'

****************************************

// WAVE IV SURVEY
import sasxport5 "$adh4\\$fah4", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h4da2 h4da4 h4da5 h4da6 h4da13 h4da8 h4gh8 h4gh9 h4to33 h4to35 ///
	h4to36 h4to37 h4to39 h4to5 h4to3 h4to6
// Rename variables
rename h4da2 pa_mod_wk
rename h4da4 pa_teamsports_wk
rename h4da5 pa_indvsports_wk
rename h4da6 pa_gymtraining_wk
rename h4da13 fitnesscenter
rename h4da8 pa_walking_wk
rename h4gh8 fastfood
rename h4gh9 ssb
rename h4to33 everdrink
rename h4to35 alc_drinkfreqweek
rename h4to36 num_drinksday
rename h4to37 bingedrinking
rename h4to39 daysdrinkpermonth
rename h4to5 smoker
rename h4to3 eversmoke_reg
rename h4to6 dailysmokefreq
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave pa_mod_wk pa_teamsports_wk pa_indvsports_wk ///
	pa_gymtraining_wk fitnesscenter pa_walking_wk fastfood ssb everdrink ///
	alc_drinkfreqweek num_drinksday bingedrinking daysdrinkpermonth smoker ///
	eversmoke_reg dailysmokefreq
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var pa_mod_wk "weekly frequency of moderately active sports or activities"
la var pa_teamsports_wk "weekly frequency of vigorous team sports"
la var pa_indvsports_wk "weekly frequency of vigorous individual sports"
la var pa_gymtraining_wk "weekly frequency of gymnastics, weight lifting, strength training"
la var fitnesscenter "times per week use fitness or recreation center"
la var pa_walking_wk "weekly frequency of walking for exercise"
la var fastfood "fast food consumption in past week"
la var ssb "sugar-sweetened beverage consumption in past week"
la var everdrink "Drink alcohol ever in past year - yes or no"
la var alc_drinkfreqweek "Number of drinks per week"
la var num_drinksday "Number of drinks consumed per occassion/days when drink"
la var bingedrinking "Days drank 5+ drinks in one sitting"
la var daysdrinkpermonth "Number of days drank alcohol in past month"
la var smoker "Monthly cigarette use - regular/current smoker if report smoking 30 days"
la var eversmoke_reg "Ever smoked regularly - yes or no"
la var dailysmokefreq "Number of cigarettes smoked per day in last 30 days"
// Save as a temp file
tempfile _Cov_Behav_wave4
save `_Cov_Behav_wave4'

****************************************

// WAVE V SURVEY
import sasxport5 "$adh5\\$fah5", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h5id24 h5id26 h5id27 h5id29 h5id21 h5id22 h5to11 h5to12 h5to14 ///
	h5to15 h5to13 h5to2 h5to1 h5to3
// Rename variables
rename h5id24 pa_mod_wk
rename h5id26 pa_indvsports_wk
rename h5id27 pa_gymtraining_wk
rename h5id29 pa_walking_wk
rename h5id21 fastfood
rename h5id22 ssb
rename h5to11 everdrink
rename h5to12 alc_drinkfreqweek
rename h5to14 num_drinksday
rename h5to15 bingedrinking
rename h5to13 daysdrinkpermonth
rename h5to2 smoker
rename h5to1 eversmoke_reg
rename h5to3 dailysmokefreq
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave pa_mod_wk pa_indvsports_wk pa_gymtraining_wk ///
	pa_walking_wk fastfood ssb everdrink alc_drinkfreqweek num_drinksday ///
	bingedrinking daysdrinkpermonth smoker eversmoke_reg dailysmokefreq
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var pa_mod_wk "weekly frequency of vigorous/active sports or exercise"
la var pa_indvsports_wk "weekly frequency of vigorous individual sports"
la var pa_gymtraining_wk "weekly frequency of gymnastics, weight lifting, strength training"
la var pa_walking_wk "weekly frequency of walking for exercise"
la var fastfood "fast food consumption in past week"
la var ssb "sugar-sweetened beverage consumption in past week"
la var everdrink "Drink alcohol ever in past year - yes or no"
la var alc_drinkfreqweek "Number of drinks per week"
la var num_drinksday "Number of drinks consumed per occassion/days when drink"
la var bingedrinking "Days drank 5+ drinks in one sitting"
la var daysdrinkpermonth "Number of days drank alcohol in past month"
la var smoker "Monthly cigarette use - regular/current smoker if report smoking 30 days"
la var eversmoke_reg "Ever smoked regularly - yes or no"
la var dailysmokefreq "Number of cigarettes smoked per day in last 30 days"
// Save as a temp file
tempfile _Cov_Behav_wave5
save `_Cov_Behav_wave5'

***********************************************************
**                COVARIATES: DEMOGRAPHIC                **
***********************************************************
// WAVE I IN-HOME WEIGHT COMPONENTS
import sasxport5 "$adh1\\$fah1wght", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id region
// Rename variable
rename region region
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave region
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var region "respondent geographic census region"
// Save as a temp file
tempfile _Cov_Demog_homewt1
save `_Cov_Demog_homewt1'

****************************************

// WAVE I SURVEY
import sasxport5 "$adh1\\$fah1", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h1gi1m h1gi1y iday imonth iyear h1gi1y bio_sex h1gi6a h1gi6b h1gi6c ///
	h1gi6d h1gi6e h1gi8 h1gi4 h1gi11 h1re1 h1gi10
// Rename existing or construct new variables
gen age = floor((mdy(imonth, iday, iyear + 1900) - mdy(h1gi1m, 15, h1gi1y + 1900)) / 365.25)
rename h1gi1y birthyear
rename bio_sex female
rename h1gi6a race_wh
rename h1gi6b race_aa
rename h1gi6c race_ai
rename h1gi6d race_as
rename h1gi6e race_ot
rename h1gi8 race_onecat
rename h1gi4 hispanic
rename h1gi11 immigrant
rename h1re1 religion
rename h1gi10 language
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave age birthyear female race_wh race_aa race_ai race_as ///
	race_ot race_onecat hispanic immigrant religion language
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var age "respondent age calculated from interview date and birth date"
la var birthyear "respondent birth year"
la var female "respondent gender"
la var race_wh "respondent race - White"
la var race_aa "respondent race - Black/African American"
la var race_ai "respondent race - American Indian/Native American"
la var race_as "respondent race - Asian"
la var race_ot "respondent race - Other"
la var race_onecat "respondent race - best category"
la var hispanic "respondent Hispanic ethnicity"
la var immigrant "immigrant status"
la var religion "respondent religion"
la var language "respondent primary language"
// Save as a temp file
tempfile _Cov_Demog_allwave1
save `_Cov_Demog_allwave1'

****************************************

// WAVE II IN-HOME WEIGHT COMPONENTS
// Rename variables to lower case for consistency
import sasxport5 "$adh2\\$fah2wght", clear
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id region
// Rename variable
rename region region
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave region
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var region "respondent geographic census region"
// Save as a temp file
tempfile _Cov_Demog_homewt2
save `_Cov_Demog_homewt2'

****************************************

// WAVE II SURVEY
import sasxport5 "$adh2\\$fah2", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h2gi1m h2gi1y iday2 imonth2 iyear2 h2gi1y bio_sex2 h2re1 h2gi2
// Rename existing or construct new variables
gen age = floor((mdy(imonth2, iday2, iyear2 + 1900) - mdy(h2gi1m, 15, h2gi1y + 1900)) / 365.25)
rename h2gi1y birthyear
rename bio_sex2 female
rename h2re1 religion
rename h2gi2 language
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave age birthyear female religion language
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var age "respondent age calculated from interview date and birth date"
la var birthyear "respondent birth year"
la var female "respondent gender"
la var religion "respondent religion"
la var language "respondent primary language"
// Save as a temp file
tempfile _Cov_Demog_wave2
save `_Cov_Demog_wave2'

****************************************

// WAVE III CENSUS REGION
import sasxport5 "$adh3\\$fah3reg", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id w3region
// Rename variable
rename w3region region
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave region
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var region "respondent geographic census region"
// Save as a temp file
tempfile _Cov_Demog_region3
save `_Cov_Demog_region3'

****************************************

// WAVE III SURVEY
import sasxport5 "$adh3\\$fah3", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h3od1m h3od1y iday3 imonth3 iyear3 h3od1y bio_sex3 h3od4a h3od4b ///
	h3od4c h3od4d h3od6 h3od2 h3od13 h3re1 h3od9
// Rename existing or construct new variables
gen age = floor((mdy(imonth3, iday3, iyear3 + 1900) - mdy(h3od1m, 15, h3od1y + 1900)) / 365.25)
rename h3od1y birthyear
rename bio_sex3 female
rename h3od4a race_wh
rename h3od4b race_aa
rename h3od4c race_ai
rename h3od4d race_as
rename h3od6 race_onecat
rename h3od2 hispanic
rename h3od13 immigrant
rename h3re1 religion
rename h3od9 language
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave age birthyear female race_wh race_aa race_ai race_as ///
	race_onecat hispanic immigrant religion language
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var age "respondent age calculated from interview date and birth date"
la var birthyear "respondent birth year"
la var female "respondent gender"
la var race_wh "respondent race - White"
la var race_aa "respondent race - Black/African American"
la var race_ai "respondent race - American Indian/Native American"
la var race_as "respondent race - Asian"
la var race_onecat "respondent race - best category"
la var hispanic "respondent Hispanic ethnicity"
la var immigrant "immigrant status"
la var religion "respondent religion"
la var language "respondent primary language"
// Save as a temp file
tempfile _Cov_Demog_wave3
save `_Cov_Demog_wave3'

****************************************

// WAVE IV CENSUS REGION
import sasxport5 "$adh4\\$fah4reg", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id w4region
// Rename variable
rename w4region region
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave region
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var region "respondent geographic census region"
// Save as a temp file
tempfile _Cov_Demog_region4
save `_Cov_Demog_region4'

****************************************

// WAVE IV SURVEY
import sasxport5 "$adh4\\$fah4", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h4od1m h4od1y iday4 imonth4 iyear4 h4od1y bio_sex4 h4re1 h4od3
// Rename existing or construct new variables
gen age = floor((mdy(imonth4, iday4, iyear4 + 1900) - mdy(h4od1m, 15, h4od1y + 1900)) / 365.25)
rename h4od1y birthyear
rename bio_sex4 female
rename h4re1 religion
rename h4od3 language
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave age birthyear female religion language
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var age "respondent age calculated from interview date and birth date"
la var birthyear "respondent birth year"
la var female "respondent gender"
la var religion "respondent religion"
la var language "respondent primary language"
// Save as a temp file
tempfile _Cov_Demog_wave4
save `_Cov_Demog_wave4'

****************************************

// WAVE V SURVEY
import sasxport5 "$adh5\\$fah5", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h5od1m h5od1y imonth5 iyear5 h5od1y h5od2a h5od4a h5od4b h5od4d ///
	h5od4e h5od4f h5od4g h5od8 h5od4c h5od9 h5re1 h5pg33 w5region
// Rename existing or construct new variables
gen age = floor((mdy(imonth5, 15, iyear5 + 1900) - mdy(h5od1m, 15, h5od1y + 1900)) / 365.25)
rename h5od1y birthyear
rename h5od2a female
rename h5od4a race_wh
rename h5od4b race_aa
rename h5od4d race_as
rename h5od4e race_pi
rename h5od4f race_ai
rename h5od4g race_ot
rename h5od8 race_onecat
rename h5od4c hispanic
rename h5od9 immigrant
rename h5re1 religion
rename h5pg33 language
rename w5region region
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave age birthyear female race_wh race_aa race_as race_pi ///
	race_ai race_ot race_onecat hispanic immigrant religion language region
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var age "respondent age calculated from interview date and birth date"
la var birthyear "respondent birth year"
la var female "respondent gender"
la var race_wh "respondent race - White"
la var race_aa "respondent race - Black/African American"
la var race_as "respondent race - Asian"
la var race_pi "respondent race - Pacific Islander"
la var race_ai "respondent race - American Indian/Native American"
la var race_ot "respondent race - Other"
la var race_onecat "respondent race - best category"
la var hispanic "respondent Hispanic ethnicity"
la var immigrant "immigrant status"
la var religion "respondent religion"
la var language "respondent primary language"
la var region "respondent geographic census region"
// Save as a temp file
tempfile _Cov_Demog_wave5
save `_Cov_Demog_wave5'

***********************************************************
**                COVARIATES: INTELLIGENCE               **
***********************************************************
// WAVE I SURVEY
import sasxport5 "$adh1\\$fah1", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id ah_pvt
// Rename variable
rename ah_pvt pvt
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave pvt
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var pvt "picture vocabulary test"
// Save as a temp file
tempfile _Cov_Intell_allwave1
save `_Cov_Intell_allwave1'

***********************************************************
**                   COVARIATES: MEDS                    **
***********************************************************
// WAVE III SURVEY
import sasxport5 "$adh3\\$fah3", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h3id26c h3id26i h3id26h h3id26e h3id26g
// Rename existing or construct new variables
gen inflam_med = h3id26c == 1 | h3id26i == 1
rename h3id26h lipid_med
rename h3id26e diab_med
rename h3id26g hyperten_med
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave inflam_med lipid_med diab_med hyperten_med
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var inflam_med "anti-inflammatory medication use"
la var lipid_med "anti-hyperlipidemic medication use"
la var diab_med "anti-diabetic medication use"
la var hyperten_med "anti-hypertensive medication use"
// Save as a temp file
tempfile _Cov_Meds_wave3
save `_Cov_Meds_wave3'

****************************************

// WAVE IV MEASURES OF INFLAMMATION AND IMMUNE FUNCTION
import sasxport5 "$adh4\\$fah4crp", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id crp_med8
// Rename variable
rename crp_med8 inflam_med
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave inflam_med
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var inflam_med "anti-inflammatory medication use"
// Save as a temp file
tempfile _Cov_Meds_crp_ebv
save `_Cov_Meds_crp_ebv'

****************************************

// WAVE IV MEASURES OF GLUCOSE HOMEOSTATIS
import sasxport5 "$adh4\\$fah4glu", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id c_med
// Rename variable
rename c_med diab_med
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave diab_med
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var diab_med "anti-diabetic medication use"
// Save as a temp file
tempfile _Cov_Meds_glu_a1c
save `_Cov_Meds_glu_a1c'

****************************************

// WAVE IV LIPIDS
import sasxport5 "$adh4\\$fah4lpd", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id c_med2
// Rename variable
rename c_med2 lipid_med
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave lipid_med
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var lipid_med "anti-hyperlipidemic medication use"
// Save as a temp file
tempfile _Cov_Meds_lipids
save `_Cov_Meds_lipids'

****************************************

// WAVE V CARDIOVASCULAR MEASURES
import sasxport5 "$adh5\\$fah5card", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h5aht
// Rename variable
rename h5aht hyperten_med
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave hyperten_med
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hyperten_med "anti-hypertensive medication use"
// Save as a temp file
tempfile _Cov_Meds_bcardio5
save `_Cov_Meds_bcardio5'

****************************************

// WAVE V INFLAMMATION & IMMUNE FUNCTION
import sasxport5 "$adh5\\$fah5crp", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h5crp8
// Rename variable
rename h5crp8 inflam_med
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave inflam_med
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var inflam_med "anti-inflammatory medication use"
// Save as a temp file
tempfile _Cov_Meds_bcrp5
save `_Cov_Meds_bcrp5'

****************************************

// WAVE V GLUCOSE HOMEOSTATIS
import sasxport5 "$adh5\\$fah5glu", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h5c_med
// Rename variable
rename h5c_med diab_med
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave diab_med
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var diab_med "anti-diabetic medication use"
// Save as a temp file
tempfile _Cov_Meds_bglua1c5
save `_Cov_Meds_bglua1c5'

****************************************

// WAVE V LIPIDS
import sasxport5 "$adh5\\$fah5lpd", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h5c_med2
// Rename variable
rename h5c_med2 lipid_med
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave lipid_med
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var lipid_med "anti-hyperlipidemic medication use"
// Save as a temp file
tempfile _Cov_Meds_blipids5
save `_Cov_Meds_blipids5'

***********************************************************
**              COVARIATES: PHYSICAL HEALTH              **
***********************************************************
// WAVE I SURVEY
import sasxport5 "$adh1\\$fah1", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h1pl18 h1pl14 h1pl12 h1pl16 h1pl10 h1pl8 h1pl21 h1pl22 h1pl20 h1pl23 ///
	h1pl24
// Rename variables
rename h1pl18 limit_pen
rename h1pl14 limit_reach
rename h1pl12 limit_stand
rename h1pl16 limit_grip
rename h1pl10 limit_walking
rename h1pl8 limit_steps
rename h1pl21 limit_bathing
rename h1pl22 limit_dressing
rename h1pl20 limit_eating
rename h1pl23 limit_toilet
rename h1pl24 limit_shopping
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave limit_pen limit_reach limit_stand limit_grip ///
	limit_walking limit_steps limit_bathing limit_dressing limit_eating ///
	limit_toilet limit_shopping
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var limit_pen "Difficulty holding a pen"
la var limit_reach "Difficulty reaching"
la var limit_stand "Difficulty standing"
la var limit_grip "Difficulty gripping"
la var limit_walking "Difficulty walking a quarter-mile"
la var limit_steps "Difficulty walking steps"
la var limit_bathing "Help bathing"
la var limit_dressing "Help dressing"
la var limit_eating "Help eating"
la var limit_toilet "Help with toilet"
la var limit_shopping "Help shopping"
// Save as a temp file
tempfile _Cov_PhysHlth_allwave1
save `_Cov_PhysHlth_allwave1'

****************************************

// WAVE III SURVEY
import sasxport5 "$adh3\\$fah3", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h3id1 h3id2 h3id3 h3id4 h3id5 h3id6 h3id7 h3id8 h3id9 h3id10
// Rename variables
rename h3id1 limit_vig_act
rename h3id2 limit_mod_act
rename h3id3 limit_groceries
rename h3id4 limit_sev_stairs
rename h3id5 limit_flight_stairs
rename h3id6 limit_bending
rename h3id7 limit_walking
rename h3id8 limit_sev_blocks
rename h3id9 limit_one_block
rename h3id10 limit_bath_dress
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave limit_vig_act limit_mod_act limit_groceries ///
	limit_sev_stairs limit_flight_stairs limit_bending limit_walking ///
	limit_sev_blocks limit_one_block limit_bath_dress
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var limit_vig_act "Health limits vigorous activities"
la var limit_mod_act "Health limits moderate activities"
la var limit_groceries "Health limits carrying groceries"
la var limit_sev_stairs "Health limits climbing several flights of stairs"
la var limit_flight_stairs "Health limits climbing one flight of stairs"
la var limit_bending "Health limits bending, kneeling, or stooping"
la var limit_walking "Health limits walking more than a mile"
la var limit_sev_blocks "Health limits serveral blocks"
la var limit_one_block "Health limits walking one block"
la var limit_bath_dress "Health limits bathing and dressing"
// Save as a temp file
tempfile _Cov_PhysHlth_wave3
save `_Cov_PhysHlth_wave3'

****************************************

// WAVE IV SURVEY
import sasxport5 "$adh4\\$fah4", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h4id1 h4id2
// Rename variables
rename h4id1 limit_mod_act
rename h4id2 limit_sev_stairs
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave limit_mod_act limit_sev_stairs
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var limit_mod_act "Health limits moderate activities"
la var limit_sev_stairs "Health limits climbing serveral flights of stairs"
// Save as a temp file
tempfile _Cov_PhysHlth_wave4
save `_Cov_PhysHlth_wave4'

****************************************

// WAVE V SURVEY
import sasxport5 "$adh5\\$fah5", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h5id4
// Rename variable
rename h5id4 limit_sev_stairs
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave limit_sev_stairs
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var limit_sev_stairs "Health limits climbing serveral flights of stairs"
// Save as a temp file
tempfile _Cov_PhysHlth_wave5
save `_Cov_PhysHlth_wave5'

***********************************************************
**            COVARIATES: PSYCHOSOCIAL HEALTH            **
***********************************************************
// WAVE I SURVEY
import sasxport5 "$adh1\\$fah1", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h1gh1 h1fs6 h1gh48 h1gh19
// Rename variables
rename h1gh1 adult_srh
rename h1fs6 depressed_cesd
rename h1gh48 misswork_healthprob
rename h1gh19 relaxprobs
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave adult_srh depressed_cesd misswork_healthprob relaxprobs
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var adult_srh "respondent self-rated health"
la var depressed_cesd "self-reported depression; CES-D"
la var misswork_healthprob "health caused missed work/school in last month"
la var relaxprobs "self-reported trouble relaxing"
// Save as a temp file
tempfile _Cov_PsychHlth_allwave1
save `_Cov_PsychHlth_allwave1'

****************************************

// WAVE II SURVEY
import sasxport5 "$adh2\\$fah2", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h2gh1 h2fs6 h2gh40 h2gh24
// Rename variables
rename h2gh1 adult_srh
rename h2fs6 depressed_cesd
rename h2gh40 misswork_healthprob
rename h2gh24 relaxprobs
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave adult_srh depressed_cesd misswork_healthprob relaxprobs
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var adult_srh "respondent self-rated health"
la var depressed_cesd "self-reported depression; CES-D"
la var misswork_healthprob "health caused missed work/school in last month"
la var relaxprobs "self-reported trouble relaxing"
// Save as a temp file
tempfile _Cov_PsychHlth_wave2
save `_Cov_PsychHlth_wave2'

****************************************

// WAVE III SURVEY
import sasxport5 "$adh3\\$fah3", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h3gh1 h3hs5 h3id15 h3sp9 h3gh10
// Rename variables
rename h3gh1 adult_srh
rename h3hs5 healthins
rename h3id15 depressiondx
rename h3sp9 depressed_cesd
rename h3gh10 misswork_healthprob
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave adult_srh healthins depressiondx depressed_cesd ///
	misswork_healthprob
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var adult_srh "respondent self-rated health"
la var healthins "current health insurance status"
la var depressiondx "depression diagnosis"
la var depressed_cesd "self-reported depression; CES-D"
la var misswork_healthprob "health caused missed work/school in last month"
// Save as a temp file
tempfile _Cov_PsychHlth_wave3
save `_Cov_PsychHlth_wave3'

****************************************

// WAVE IV SURVEY
import sasxport5 "$adh4\\$fah4", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h4gh1 h4hs1 h4id5j h4id5h h4mh22 h4gh2 h4mh3 h4mh4 h4mh5 h4mh6
// Rename variables
rename h4gh1 adult_srh
rename h4hs1 healthins
rename h4id5j anxiety
rename h4id5h depressiondx
rename h4mh22 depressed_cesd
rename h4gh2 misswork_healthprob
rename h4mh3 pss_1
rename h4mh4 pss_2
rename h4mh5 pss_3
rename h4mh6 pss_4
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave adult_srh healthins anxiety depressiondx depressed_cesd ///
	misswork_healthprob pss_1 pss_2 pss_3 pss_4
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var adult_srh "respondent self-rated health"
la var healthins "current health insurance status"
la var anxiety "anxiety diagnosis"
la var depressiondx "depression diagnosis"
la var depressed_cesd "self-reported depression; CES-D"
la var misswork_healthprob "health caused missed work/school in last month"
la var pss_1 "Perceived stress scale - item 1"
la var pss_2 "Perceived stress scale - item 2"
la var pss_3 "Perceived stress scale - item 3"
la var pss_4 "Perceived stress scale - item 4"
// Save as a temp file
tempfile _Cov_PsychHlth_wave4
save `_Cov_PsychHlth_wave4'

****************************************

// WAVE V SURVEY
import sasxport5 "$adh5\\$fah5", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h5id1 h5id9 h5id6i h5id6g h5ss0b h5el7 h5el5
// Rename variables
rename h5id1 adult_srh
rename h5id9 healthins
rename h5id6i anxiety
rename h5id6g depressiondx
rename h5ss0b depressed_cesd
rename h5el7 misswork_healthprob
rename h5el5 child_srh
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave adult_srh healthins anxiety depressiondx depressed_cesd ///
	misswork_healthprob child_srh
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var adult_srh "respondent self-rated health"
la var healthins "current health insurance status"
la var anxiety "anxiety diagnosis"
la var depressiondx "depression diagnosis"
la var depressed_cesd "self-reported depression; CES-D"
la var misswork_healthprob "health caused missed work/school in last month"
la var child_srh "childhood self-rated health"
// Save as a temp file
tempfile _Cov_PsychHlth_wave5
save `_Cov_PsychHlth_wave5'

***********************************************************
**                  COVARIATES: WEIGHTS                  **
***********************************************************
// CURRENT DATASET: Homewt1.xpt
import sasxport5 "$adh1\\$fah1wght", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id gswgt1 psuscid
// Rename variables
rename gswgt1 ah_xsectionweight
rename psuscid ah_psu
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave ah_xsectionweight ah_psu
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var ah_xsectionweight "Add Health cross-section weight"
la var ah_psu "Add Health sampling unit/cluster variable"
// Save as a temp file
tempfile _Cov_Weights_Homewt1
save `_Cov_Weights_Homewt1'

****************************************

// CURRENT DATASET: Homewt2.xpt
import sasxport5 "$adh2\\$fah2wght", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id gswgt2 psuscid
// Rename variables
rename gswgt2 ah_xsectionweight
rename psuscid ah_psu
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave ah_xsectionweight ah_psu
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var ah_xsectionweight "Add Health cross-section weight"
la var ah_psu "Add Health sampling unit/cluster variable"
// Save as a temp file
tempfile _Cov_Weights_Homewt2
save `_Cov_Weights_Homewt2'

****************************************

// CURRENT DATASET: weights3.xpt
import sasxport5 "$adh3\\$fah3wght", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id gswgt3_2 gswgt3 psuscid
// Rename variables
rename gswgt3_2 ah_xsectionweight
rename gswgt3 ah_longweight
rename psuscid ah_psu
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave ah_xsectionweight ah_longweight ah_psu
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var ah_xsectionweight "Add Health cross-section weight"
la var ah_longweight "Add Health longitudinal weight"
la var ah_psu "Add Health sampling unit/cluster variable"
// Save as a temp file
tempfile _Cov_Weights_weights3
save `_Cov_Weights_weights3'

****************************************

// CURRENT DATASET: weights4.xpt
import sasxport5 "$adh4\\$fah4wght", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id gswgt4_2 gswgt4 gswgt134 psuscid
// Rename variables
rename gswgt4_2 ah_xsectionweight
rename gswgt4 ah_longweight
rename gswgt134 ah_longweight34
rename psuscid ah_psu
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave ah_xsectionweight ah_longweight ah_longweight34 ah_psu
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var ah_xsectionweight "Add Health cross-section weight"
la var ah_longweight "Add Health longitudinal weight"
la var ah_longweight34 "Add Health longitudinal weight (waves 3 and 4)"
la var ah_psu "Add Health sampling unit/cluster variable"
// Save as a temp file
tempfile _Cov_Weights_weights4
save `_Cov_Weights_weights4'

****************************************

// CURRENT DATASET: weights5.xpt
import sasxport5 "$adh5\\$fah5wght", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename aid id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id gsw5 gsw12345 gsw1345 gsw145 psuscid
// Rename variables
rename gsw5 ah_xsectionweight
rename gsw12345 ah_longweight
rename gsw1345 ah_longweight345
rename gsw145 ah_longweight45
rename psuscid ah_psu
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "Add Health"
// Reduce variable set further
keep id study wave ah_xsectionweight ah_longweight ah_longweight345 ///
	ah_longweight45 ah_psu
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var ah_xsectionweight "Add Health cross-section weight"
la var ah_longweight "Add Health longitudinal weight"
la var ah_longweight345 "Add Health longitudinal weight (waves 3, 4 and 5)"
la var ah_longweight45 "Add Health longitudinal weight (waves 4 and 5)"
la var ah_psu "Add Health sampling unit/cluster variable"
// Save as a temp file
tempfile _Cov_Weights_weights5
save `_Cov_Weights_weights5'

***********************************************************
**          COMBINE INTO SINGLE PROJECT DATASET          **
***********************************************************
// School
use `_SR_Inschool', clear
merge m:1 id study wave using `_SR_network'
replace wave = "0" if wave == "School"
drop if missing(id)
drop _merge
// Drop those not in Wave I
merge 1:1 id study using `_SR_allwave1', ///
	keepusing(sch_close)
keep if _merge == 3
drop _merge sch_close
// Save as a temp file
tempfile ah_school
save `ah_school'

// Wave I
use `_SR_allwave1', clear
merge 1:1 id study wave using `_SES_allwave1'
drop _merge
merge 1:1 id study wave using `_SES_conses'
drop _merge
merge 1:1 id study wave using `_SES_parent2'
drop _merge
merge 1:1 id study wave using `_Bio_allwave1'
drop _merge
merge 1:1 id study wave using `_Cov_Behav_allwave1'
drop _merge
merge 1:1 id study wave using `_Cov_Demog_allwave1'
drop _merge
merge 1:1 id study wave using `_Cov_Demog_homewt1'
drop _merge
merge 1:1 id study wave using `_Cov_Intell_allwave1'
drop _merge
merge 1:1 id study wave using `_Cov_PhysHlth_allwave1'
drop _merge
merge 1:1 id study wave using `_Cov_PsychHlth_allwave1'
drop _merge
merge 1:1 id study wave using `_Cov_Weights_Homewt1'
drop _merge
// Save as a temp file
tempfile ah_w1
save `ah_w1'

// Wave II
use `_SR_wave2', clear
merge 1:1 id study wave using `_Bio_wave2'
drop _merge
merge 1:1 id study wave using `_Cov_Attrition_w1w2dsp'
drop _merge
merge 1:1 id study wave using `_Cov_Behav_wave2'
drop _merge
merge 1:1 id study wave using `_Cov_Demog_wave2'
drop _merge
merge 1:1 id study wave using `_Cov_Demog_homewt2'
drop _merge
merge 1:1 id study wave using `_Cov_PsychHlth_wave2'
drop _merge
merge 1:1 id study wave using `_Cov_Weights_Homewt2'
drop _merge
// Save as a temp file
tempfile ah_w2
save `ah_w2'

// Wave III
use `_SR_wave3', clear
merge 1:1 id study wave using `ah_w3_sects17_19'
drop _merge
merge 1:1 id study wave using `_SES_wave3'
drop _merge
merge 1:1 id study wave using `_Bio_wave3'
drop _merge
merge 1:1 id study wave using `_Cov_Attrition_dsp3'
drop _merge
merge 1:1 id study wave using `_Cov_Behav_wave3'
drop _merge
merge 1:1 id study wave using `_Cov_Demog_wave3'
drop _merge
merge 1:1 id study wave using `_Cov_Demog_region3'
drop _merge
merge 1:1 id study wave using `_Cov_Meds_wave3'
drop _merge
merge 1:1 id study wave using `_Cov_PhysHlth_wave3'
drop _merge
merge 1:1 id study wave using `_Cov_PsychHlth_wave3'
drop _merge
merge 1:1 id study wave using `_Cov_Weights_weights3'
drop _merge
// Save as a temp file
tempfile ah_w3
save `ah_w3'

// Wave IV
use `_SR_wave4', clear
merge 1:1 id study wave using `_SR_currel_4'
drop _merge
merge 1:1 id study wave using `_SES_wave4'
drop _merge
merge 1:1 id study wave using `_Bio_wave4'
drop _merge
merge 1:1 id study wave using `_Bio_crp_ebv_4'
drop _merge
merge 1:1 id study wave using `_Bio_glu_a1c_4'
drop _merge
merge 1:1 id study wave using `_Bio_lipids_4'
drop _merge
merge 1:1 id study wave using `_Cognition_wave4'
drop _merge
merge 1:1 id study wave using `_Cov_Attrition_dsp4'
drop _merge
merge 1:1 id study wave using `_Cov_Behav_wave4'
drop _merge
merge 1:1 id study wave using `_Cov_Demog_wave4'
drop _merge
merge 1:1 id study wave using `_Cov_Demog_region4'
drop _merge
merge 1:1 id study wave using `_Cov_Meds_crp_ebv'
drop _merge
merge 1:1 id study wave using `_Cov_Meds_glu_a1c'
drop _merge
merge 1:1 id study wave using `_Cov_Meds_lipids'
drop _merge
merge 1:1 id study wave using `_Cov_PhysHlth_wave4'
drop _merge
merge 1:1 id study wave using `_Cov_PsychHlth_wave4'
drop _merge
merge 1:1 id study wave using `_Cov_Weights_weights4'
drop _merge
// Save as a temp file
tempfile ah_w4
save `ah_w4'

// Wave V
use `_SR_wave5', clear
merge 1:1 id study wave using `_SES_wave5'
drop _merge
merge 1:1 id study wave using `_Bio_banthro5'
drop _merge
merge 1:1 id study wave using `_Bio_bcardio5'
drop _merge
merge 1:1 id study wave using `_Bio_bcrp5'
drop _merge
merge 1:1 id study wave using `_Bio_bglua1c5'
drop _merge
merge 1:1 id study wave using `_Bio_blipids5'
drop _merge
merge 1:1 id study wave using `_Bio_brenal5'
drop _merge
merge 1:1 id study wave using `_Cognition_wave5'
drop _merge
merge 1:1 id study wave using `_Cov_Attrition_dsp5'
drop _merge
merge 1:1 id study wave using `_Cov_Behav_wave5'
drop _merge
merge 1:1 id study wave using `_Cov_Demog_wave5'
drop _merge
merge 1:1 id study wave using `_Cov_Meds_bcardio5'
drop _merge
merge 1:1 id study wave using `_Cov_Meds_bcrp5'
drop _merge
merge 1:1 id study wave using `_Cov_Meds_bglua1c5'
drop _merge
merge 1:1 id study wave using `_Cov_Meds_blipids5'
drop _merge
merge 1:1 id study wave using `_Cov_PhysHlth_wave5'
drop _merge
merge 1:1 id study wave using `_Cov_PsychHlth_wave5'
drop _merge
merge 1:1 id study wave using `_Cov_Weights_weights5'
drop _merge
// Save as a temp file
tempfile ah_w5
save `ah_w5'

// Append all Add Health together
use `ah_school'
append using `ah_w1'
append using `ah_w2'
append using `ah_w3'
append using `ah_w4'
append using `ah_w5'
sort id wave

// Remove respondents who are not in wave 1
preserve
keep if wave == "1"
keep id
gen wave1 = 1
// Save as a temp file
tempfile w1flag
save `w1flag'
restore
merge m:1 id using `w1flag'
keep if _merge == 3
drop wave1 _merge

***********************************************************
**             FINAL INTERIM DATASET CLEANUP             **
***********************************************************

// Convert wave to numeric
destring wave, replace

// Destring the ID variable and sort the data by study, ID and wave
destring id, replace
format %12.0g id
sort id wave

// Remove value labels
ds, has(type numeric)
la val `r(varlist)' .

// Rename the cross-sectional weight variable to be consistent across studies
rename ah_xsectionweight xsectionweight
la var xsectionweight "Study-specific cross-section weights"

// Compress
compress

// Update formats
ds, has(type byte)
format %8.0g `r(varlist)'

ds, has(type int)
format %8.0g `r(varlist)'

// ds, has(type float)
// format %12.2g `r(varlist)'

// Reorder the variables
order id study wave ///
	attrition ///------------------------------------------------------ATTRITION
	pempl p_empl_ft p1_educ p2_educ childses phhincome pincome ///-----------SES
	pwelfare rassets_status rassets_owe reduc_year reduc_cat reduc_GED ///
	reduc_HS reduc_AA reduc_BA reduc_MA reduc_PhD reduc_prof reduc_current ///
	rincome_cat rincome_hh rincome_total rincome_wages rincome_wagescat rses_4cat ///
	religious_attend volunteerhrs biomom_alive biodad_alive ///---------------SR
	marital_status sppn_listen sch_close sch_feel_part sch_happy ///
	fam_understand fam_attention fam_fun resmom_activities_shop ///
	resmom_activities_sport resmom_activities_religion ///
	resmom_activities_dating resmom_activities_movie ///
	resmom_activities_problem resmom_activities_argument ///
	resmom_activities_grades resmom_activities_project resmom_activities_sch ///
	resmom_activities_none resdad_activities_shop resdad_activities_sport ///
	resdad_activities_religion resdad_activities_dating ///
	resdad_activities_movie resdad_activities_problem ///
	resdad_activities_argument resdad_activities_grades ///
	resdad_activities_project resdad_activities_sch resdad_activities_none ///
	mom_warm dad_warm mom_close dad_close mom_relationship dad_relationship ///
	mom_comm dad_comm par_care fri_contact fri_care volunteer ///
	relationship_current dating_3months rel_start_date interview_date ///
	child_close child_overwhelm child_stress sppn_rel_sat fri_num fam_rely ///
	fam_open fam_demand_critic child_bio_num child_nonbio_num child_open ///
	child_rely child_demand_critic sppn_open sppn_rely sppn_demand_critic ///
	fri_rely fri_open fri_demand_critic sch_activity1 sch_activity2 ///
	sch_activity3 sch_activity4 sch_activity5 sch_activity6 sch_activity7 ///
	sch_activity8 sch_activity9 sch_activity10 sch_activity11 sch_activity12 ///
	sch_activity13 sch_activity14 sch_activity15 sch_activity16 ///
	sch_activity17 sch_activity18 sch_activity19 sch_activity20 ///
	sch_activity21 sch_activity22 sch_activity23 sch_activity24 ///
	sch_activity25 sch_activity26 sch_activity27 sch_activity28 ///
	sch_activity29 sch_activity30 sch_activity31 sch_activity32 ///
	sch_activity33 sch_activity_none fri_indegree fri_outdegree ///
	cohabitation cohabitating neigh_contact ///
	height weight bmi bmi_class wc wc_class bp_class ///--------------BIOMARKERS
	systolicbp diastolicbp hypertension meanarterpres totchol highchol ///
	hdlchol ldlchol ldl_class diabetes fastgluc_class nonfastgluc_class ///
	hba1c hba1c_class pulse pulsepress crp crp_class cystatinc renalfunction ///
	triglyceride triglyceride_class ///
	inflam_med lipid_med diab_med hyperten_med ///-------------------MEDICATIONS
	immedrecall delayrecall digbackwards ///---------------------------COGNITION
	pa_mod_wk pa_vig_wk pa_teamsports_wk pa_indvsports_wk ///----------BEHAVIORS
	pa_gymtraining_wk pa_walking_wk fitnesscenter fastfood ssb everdrink ///
	alc_drinkfreqweek num_drinksday bingedrinking daysdrinkpermonth smoker ///
	eversmoke_reg dailysmokefreq ///
	age birthyear female race_onecat race_wh race_aa race_as ///----DEMOGRAPHICS
	race_ai race_pi race_ot hispanic immigrant religion language region ///
	pvt ///---------------------------------------------------------INTELLIGENCE
	adult_srh child_srh healthins anxiety depressiondx ///---PSYCHOSOCIAL HEALTH
	depressed_cesd misswork_healthprob relaxprobs pss_1 pss_2 pss_3 pss_4 ///
	limit_pen limit_reach limit_stand limit_grip ///-------------PHYSICAL HEALTH
	limit_steps limit_dressing limit_eating limit_toilet limit_shopping ///
	limit_mod_act limit_vig_act limit_sev_stairs limit_flight_stairs ///
	limit_bending limit_walking limit_sev_blocks limit_one_block ///
	limit_groceries limit_bath_dress limit_bathing ///
	xsectionweight ah_longweight ah_longweight34 ah_longweight345 ///----WEIGHTS
	ah_longweight45 ah_psu

// Save
save "$tmpd\ida_study_vars_addhealth.dta", replace
