// HRS
// IDA_Secondary_Study_Variables_HRS.do
// This Do file must be called from the Primary Do File (IDA_Primary_Control_Script.do)

clear
set more off
set maxvar 20000

// Master dataset variables are pulled from multiple datasets

***********************************************************
**                          SES                          **
***********************************************************
// VALIDATED MEASURES OF CHILDHOOD SOCIO-ECONOMIC STATUS
use "$hrsc\\$fhrscses", clear
// Rename variables to lower case for consistency
renvars *, lower
// Generate the ID variable and convert to string if numeric
gen id = hhid + pn
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id cses_index
// Rename variable
rename cses_index childses
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave childses
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var childses "Childhood SES score"
// Save as a temp file
tempfile _SES_cses_measures
save `_SES_cses_measures'

****************************************

// RAND HRS FAT FILE 1998
use "$hrsf\\$fhrsff98", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id f993 f996
// Rename variables
rename f993 childses
rename f996 p_empl_ft
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave childses p_empl_ft
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var childses "Childhood SES score"
la var p_empl_ft "Parent currently employed fulltime"
// Save as a temp file
tempfile _SES_fatfile_1998
save `_SES_fatfile_1998'

****************************************

// RAND HRS LONGITUDINAL FILE 1992-2018 VERSION 2
use "$hrsr\\$fhrsrlf", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id rafeduc rameduc h1atotb h2atotb h4atotb h5atotb h6atotb h7atotb ///
	h8atotb h9atotb h10atotb h11atotb h12atotb h13atotb h14atotb raeduc ///
	raedyrs h1itot h2itot h3itot h4itot h5itot h6itot h7itot h8itot h9itot ///
	h10itot h11itot h12itot h13itot h14itot r1iearn r2iearn r3iearn r4iearn ///
	r5iearn r6iearn r7iearn r8iearn r9iearn r10iearn r11iearn r12iearn ///
	r13iearn r14iearn
// Rename variables
rename rafeduc p1_educ_1
rename rameduc p2_educ_1
rename h1atotb rassets_total_1
rename h2atotb rassets_total_2
rename h4atotb rassets_total_4
rename h5atotb rassets_total_5
rename h6atotb rassets_total_6
rename h7atotb rassets_total_7
rename h8atotb rassets_total_8
rename h9atotb rassets_total_9
rename h10atotb rassets_total_10
rename h11atotb rassets_total_11
rename h12atotb rassets_total_12
rename h13atotb rassets_total_13
rename h14atotb rassets_total_14
rename raeduc reduc_cat_1
rename raedyrs reduc_year_1
rename h1itot rincome_hh_1
rename h2itot rincome_hh_2
rename h3itot rincome_hh_3
rename h4itot rincome_hh_4
rename h5itot rincome_hh_5
rename h6itot rincome_hh_6
rename h7itot rincome_hh_7
rename h8itot rincome_hh_8
rename h9itot rincome_hh_9
rename h10itot rincome_hh_10
rename h11itot rincome_hh_11
rename h12itot rincome_hh_12
rename h13itot rincome_hh_13
rename h14itot rincome_hh_14
rename r1iearn rincome_wages_1
rename r2iearn rincome_wages_2
rename r3iearn rincome_wages_3
rename r4iearn rincome_wages_4
rename r5iearn rincome_wages_5
rename r6iearn rincome_wages_6
rename r7iearn rincome_wages_7
rename r8iearn rincome_wages_8
rename r9iearn rincome_wages_9
rename r10iearn rincome_wages_10
rename r11iearn rincome_wages_11
rename r12iearn rincome_wages_12
rename r13iearn rincome_wages_13
rename r14iearn rincome_wages_14
// Reshape long
reshape long p1_educ_ p2_educ_ rassets_total_ reduc_cat_ reduc_year_ rincome_hh_ rincome_wages_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave p1_educ p2_educ rassets_total reduc_cat reduc_year rincome_hh rincome_wages
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var p1_educ "Parent 1's education"
la var p2_educ "Parent 2's education"
la var rassets_total "Respondent - total assets"
la var reduc_cat "Respondent: Educational attainment category"
la var reduc_year "Respondent: Highest year of education"
la var rincome_hh "Repondent & Spouse/Partner Income together"
la var rincome_wages "Respondent earnings"
// Save as a temp file
tempfile _SES_92_18v1
save `_SES_92_18v1'

***********************************************************
**                 SOCIAL RELATIONSHIPS                  **
***********************************************************
// RAND HRS FAT FILE 1996
use "$hrsf\\$fhrsff96", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id e1739 e1740
// Rename variables
rename e1739 neigh_contact
rename e1740 neigh_contact_per
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave neigh_contact neigh_contact_per
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var neigh_contact "Frequency of contact with neighbors"
la var neigh_contact_per "Frequency of contact per time"
// Save as a temp file
tempfile _SR_fatfile_1996
save `_SR_fatfile_1996'

****************************************

// RAND HRS FAT FILE 1998
use "$hrsf\\$fhrsff98", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id f2246 f2247 f2677
// Rename variables
rename f2246 neigh_contact
rename f2247 neigh_contact_per
rename f2677 volunteer
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave neigh_contact neigh_contact_per volunteer
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var neigh_contact "Frequency of contact with neighbors"
la var neigh_contact_per "Frequency of contact per time"
la var volunteer "Volunteer: yes or no"
// Save as a temp file
tempfile _SR_fatfile_1998
save `_SR_fatfile_1998'

****************************************

// RAND HRS FAT FILE 2000
use "$hrsf\\$fhrsff00", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id g2497 g2498 g2995
// Rename variables
rename g2497 neigh_contact
rename g2498 neigh_contact_per
rename g2995 volunteer
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave neigh_contact neigh_contact_per volunteer
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var neigh_contact "Frequency of contact with neighbors"
la var neigh_contact_per "Frequency of contact per time"
la var volunteer "Volunteer: yes or no"
// Save as a temp file
tempfile _SR_fatfile_2000
save `_SR_fatfile_2000'

****************************************

// RAND HRS FAT FILE 2002
use "$hrsf\\$fhrsff02", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id hf176 hf177 hg086
// Rename variables
rename hf176 neigh_contact
rename hf177 neigh_contact_per
rename hg086 volunteer
// Create wave and study variables
gen str6 wave = "6"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave neigh_contact neigh_contact_per volunteer
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var neigh_contact "Frequency of contact with neighbors"
la var neigh_contact_per "Frequency of contact per time"
la var volunteer "Volunteer: yes or no"
// Save as a temp file
tempfile _SR_fatfile_2002
save `_SR_fatfile_2002'

****************************************

// RAND HRS FAT FILE 2004
use "$hrsf\\$fhrsff04", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id jf176 jf177 jb082 jg086
// Rename variables
rename jf176 neigh_contact
rename jf177 neigh_contact_per
rename jb082 religious_attend
rename jg086 volunteer
// Create wave and study variables
gen str6 wave = "7"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave neigh_contact neigh_contact_per religious_attend volunteer
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var neigh_contact "Frequency of contact with neighbors"
la var neigh_contact_per "Frequency of contact per time"
la var religious_attend "Frequency attend religious services"
la var volunteer "Volunteer: yes or no"
// Save as a temp file
tempfile _SR_fatfile_2004
save `_SR_fatfile_2004'

****************************************

// RAND HRS FAT FILE 2006
use "$hrsf\\$fhrsff06", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id klb002 kf176 kf177 kb082 kg086 klb012a klb012b klb012c klb012d klb012e ///
	klb012f klb012g klb009a klb009b klb009c klb008c klb008b klb008a klb008d ///
	klb008e klb008f klb008g klb004 klb006 klb005c klb005b klb005a klb005d ///
	klb005e klb005f klb005g klb015 klb017a klb017b klb017c klb016b klb016c ///
	klb016a klb016d klb016e klb016f klb016g
// Rename variables
rename klb002 meeting_all
rename kf176 neigh_contact
rename kf177 neigh_contact_per
rename kb082 religious_attend
rename kg086 volunteer
rename klb012a fam_understand
rename klb012b fam_rely
rename klb012c fam_open
rename klb012d fam_demand
rename klb012e fam_critic
rename klb012f fam_letudown
rename klb012g fam_nerves
rename klb009a child_contact_inperson
rename klb009b child_contact_phone
rename klb009c child_contact_write
rename klb008c child_open
rename klb008b child_rely
rename klb008a child_understand
rename klb008d child_demand
rename klb008e child_critic
rename klb008f child_letudown
rename klb008g child_nerves
rename klb004 cohabitating
rename klb006 sppn_rel_close
rename klb005c sppn_open
rename klb005b sppn_rely
rename klb005a sppn_understand
rename klb005d sppn_demand
rename klb005e sppn_critic
rename klb005f sppn_letudown
rename klb005g sppn_nerves
rename klb015 fri_yesno
rename klb017a fri_contact_inperson
rename klb017b fri_contact_phone
rename klb017c fri_contact_write
rename klb016b fri_rely
rename klb016c fri_open
rename klb016a fri_understand
rename klb016d fri_demand
rename klb016e fri_critic
rename klb016f fri_letudown
rename klb016g fri_nerves
// Create wave and study variables
gen str6 wave = "8"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave meeting_all neigh_contact neigh_contact_per ///
	religious_attend volunteer fam_understand fam_rely fam_open fam_demand ///
	fam_critic fam_letudown fam_nerves child_contact_inperson ///
	child_contact_phone child_contact_write child_open child_rely ///
	child_understand child_demand child_critic child_letudown child_nerves ///
	cohabitating sppn_rel_close sppn_open sppn_rely sppn_understand ///
	sppn_demand sppn_critic sppn_letudown sppn_nerves fri_yesno ///
	fri_contact_inperson fri_contact_phone fri_contact_write fri_rely ///
	fri_open fri_understand fri_demand fri_critic fri_letudown fri_nerves
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var meeting_all "Frequency attend any group meetings"
la var neigh_contact "Frequency of contact with neighbors"
la var neigh_contact_per "Frequency of contact per time"
la var religious_attend "Frequency attend religious services"
la var volunteer "Volunteer: yes or no"
la var fam_understand "Family understands you"
la var fam_rely "Can rely on your family"
la var fam_open "Open up to your family"
la var fam_demand "Family members make too many demands"
la var fam_critic "Family members criticize you"
la var fam_letudown "Family members let you down"
la var fam_nerves "Family gets on your nerves"
la var child_contact_inperson "Contact with children in -person"
la var child_contact_phone "Contact with children on the phone"
la var child_contact_write "Contact with children in writing or email"
la var child_open "Open up to children in need to talk"
la var child_rely "Can rely on your children"
la var child_understand "Your children understand the way you feel"
la var child_demand "Your children make too many demands"
la var child_critic "Your children are critical of you"
la var child_letudown "Your children let you down"
la var child_nerves "Your children get on your nerves"
la var cohabitating "Cohabitating with spouse or partner"
la var sppn_rel_close "Closeness of relationship with spouse or partner"
la var sppn_open "Open up to your spouse/partner"
la var sppn_rely "Can rely on your spouse/partner"
la var sppn_understand "Spouse/partner understands you"
la var sppn_demand "Spouse/partner make too many demands"
la var sppn_critic "Spouse/partner criticize you"
la var sppn_letudown "Spouse/partner let you down"
la var sppn_nerves "Spouse/partner get on your nerves"
la var fri_yesno "Have friends"
la var fri_contact_inperson "Contact with friends in -person"
la var fri_contact_phone "Contact with friends on the phone"
la var fri_contact_write "Contact with friends in writing or email"
la var fri_rely "Can rely on your friends"
la var fri_open "Can open up to your friends"
la var fri_understand "Friends understands you"
la var fri_demand "Friends make too many demands"
la var fri_critic "Friends criticize you"
la var fri_letudown "Friends let you down"
la var fri_nerves "Friends get on your nerves"
tempfile _SR_fatfile_2006
// Save as a temp file
save `_SR_fatfile_2006'

****************************************

// RAND HRS FAT FILE 2008
use "$hrsf\\$fhrsff08", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id llb001e llb001f lf176 lf177 lb082 lg086 llb012a llb012b llb012c ///
	llb012d llb012e llb012f llb012g llb009a llb009b llb009c llb008c llb008b ///
	llb008a llb008d llb008e llb008f llb008g llb004 llb006 llb005c llb005b ///
	llb005a llb005d llb005e llb005f llb005g llb015 llb017a llb017b llb017c ///
	llb016b llb016c llb016a llb016d llb016e llb016f llb016g
// Rename variables
rename llb001e meeting_soc
rename llb001f meeting_other
rename lf176 neigh_contact
rename lf177 neigh_contact_per
rename lb082 religious_attend
rename lg086 volunteer
rename llb012a fam_understand
rename llb012b fam_rely
rename llb012c fam_open
rename llb012d fam_demand
rename llb012e fam_critic
rename llb012f fam_letudown
rename llb012g fam_nerves
rename llb009a child_contact_inperson
rename llb009b child_contact_phone
rename llb009c child_contact_write
rename llb008c child_open
rename llb008b child_rely
rename llb008a child_understand
rename llb008d child_demand
rename llb008e child_critic
rename llb008f child_letudown
rename llb008g child_nerves
rename llb004 cohabitating
rename llb006 sppn_rel_close
rename llb005c sppn_open
rename llb005b sppn_rely
rename llb005a sppn_understand
rename llb005d sppn_demand
rename llb005e sppn_critic
rename llb005f sppn_letudown
rename llb005g sppn_nerves
rename llb015 fri_yesno
rename llb017a fri_contact_inperson
rename llb017b fri_contact_phone
rename llb017c fri_contact_write
rename llb016b fri_rely
rename llb016c fri_open
rename llb016a fri_understand
rename llb016d fri_demand
rename llb016e fri_critic
rename llb016f fri_letudown
rename llb016g fri_nerves
// Create wave and study variables
gen str6 wave = "9"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave meeting_soc meeting_other neigh_contact neigh_contact_per ///
	religious_attend volunteer fam_understand fam_rely fam_open fam_demand ///
	fam_critic fam_letudown fam_nerves child_contact_inperson ///
	child_contact_phone child_contact_write child_open child_rely ///
	child_understand child_demand child_critic child_letudown child_nerves ///
	cohabitating sppn_rel_close sppn_open sppn_rely sppn_understand ///
	sppn_demand sppn_critic sppn_letudown sppn_nerves fri_yesno ///
	fri_contact_inperson fri_contact_phone fri_contact_write fri_rely ///
	fri_open fri_understand fri_demand fri_critic fri_letudown fri_nerves
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var meeting_soc "Frequency attend sport/social meetings"
la var meeting_other "Frequency attend other group meetings"
la var neigh_contact "Frequency of contact with neighbors"
la var neigh_contact_per "Frequency of contact per time"
la var religious_attend "Frequency attend religious services"
la var volunteer "Volunteer: yes or no"
la var fam_understand "Family understands you"
la var fam_rely "Can rely on your family"
la var fam_open "Open up to your family"
la var fam_demand "Family members make too many demands"
la var fam_critic "Family members criticize you"
la var fam_letudown "Family members let you down"
la var fam_nerves "Family gets on your nerves"
la var child_contact_inperson "Contact with children in -person"
la var child_contact_phone "Contact with children on the phone"
la var child_contact_write "Contact with children in writing or email"
la var child_open "Open up to children in need to talk"
la var child_rely "Can rely on your children"
la var child_understand "Your children understand the way you feel"
la var child_demand "Your children make too many demands"
la var child_critic "Your children are critical of you"
la var child_letudown "Your children let you down"
la var child_nerves "Your children get on your nerves"
la var cohabitating "Cohabitating with spouse or partner"
la var sppn_rel_close "Closeness of relationship with spouse or partner"
la var sppn_open "Open up to your spouse/partner"
la var sppn_rely "Can rely on your spouse/partner"
la var sppn_understand "Spouse/partner understands you"
la var sppn_demand "Spouse/partner make too many demands"
la var sppn_critic "Spouse/partner criticize you"
la var sppn_letudown "Spouse/partner let you down"
la var sppn_nerves "Spouse/partner get on your nerves"
la var fri_yesno "Have friends"
la var fri_contact_inperson "Contact with friends in -person"
la var fri_contact_phone "Contact with friends on the phone"
la var fri_contact_write "Contact with friends in writing or email"
la var fri_rely "Can rely on your friends"
la var fri_open "Can open up to your friends"
la var fri_understand "Friends understands you"
la var fri_demand "Friends make too many demands"
la var fri_critic "Friends criticize you"
la var fri_letudown "Friends let you down"
la var fri_nerves "Friends get on your nerves"
// Save as a temp file
tempfile _SR_fatfile_2008
save `_SR_fatfile_2008'

****************************************

// RAND HRS FAT FILE 2010
use "$hrsf\\$fhrsff10", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id mlb001f mlb001g mf176 mf177 mb082 mg086 mlb012a mlb012b mlb012c ///
	mlb012d mlb012e mlb012f mlb012g mlb009a mlb009b mlb009c mlb008c mlb008b ///
	mlb008a mlb008d mlb008e mlb008f mlb008g mlb004 mlb006 mlb005c mlb005b ///
	mlb005a mlb005d mlb005e mlb005f mlb005g mlb015 mlb017a mlb017b mlb017c ///
	mlb016b mlb016c mlb016a mlb016d mlb016e mlb016f mlb016g
// Rename variables
rename mlb001f meeting_soc
rename mlb001g meeting_other
rename mf176 neigh_contact
rename mf177 neigh_contact_per
rename mb082 religious_attend
rename mg086 volunteer
rename mlb012a fam_understand
rename mlb012b fam_rely
rename mlb012c fam_open
rename mlb012d fam_demand
rename mlb012e fam_critic
rename mlb012f fam_letudown
rename mlb012g fam_nerves
rename mlb009a child_contact_inperson
rename mlb009b child_contact_phone
rename mlb009c child_contact_write
rename mlb008c child_open
rename mlb008b child_rely
rename mlb008a child_understand
rename mlb008d child_demand
rename mlb008e child_critic
rename mlb008f child_letudown
rename mlb008g child_nerves
rename mlb004 cohabitating
rename mlb006 sppn_rel_close
rename mlb005c sppn_open
rename mlb005b sppn_rely
rename mlb005a sppn_understand
rename mlb005d sppn_demand
rename mlb005e sppn_critic
rename mlb005f sppn_letudown
rename mlb005g sppn_nerves
rename mlb015 fri_yesno
rename mlb017a fri_contact_inperson
rename mlb017b fri_contact_phone
rename mlb017c fri_contact_write
rename mlb016b fri_rely
rename mlb016c fri_open
rename mlb016a fri_understand
rename mlb016d fri_demand
rename mlb016e fri_critic
rename mlb016f fri_letudown
rename mlb016g fri_nerves
// Create wave and study variables
gen str6 wave = "10"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave meeting_soc meeting_other neigh_contact neigh_contact_per religious_attend volunteer fam_understand fam_rely fam_open fam_demand fam_critic fam_letudown fam_nerves child_contact_inperson child_contact_phone child_contact_write child_open child_rely child_understand child_demand child_critic child_letudown child_nerves cohabitating sppn_rel_close sppn_open sppn_rely sppn_understand sppn_demand sppn_critic sppn_letudown sppn_nerves fri_yesno fri_contact_inperson fri_contact_phone fri_contact_write fri_rely fri_open fri_understand fri_demand fri_critic fri_letudown fri_nerves
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var meeting_soc "Frequency attend sport/social meetings"
la var meeting_other "Frequency attend other group meetings"
la var neigh_contact "Frequency of contact with neighbors"
la var neigh_contact_per "Frequency of contact per time"
la var religious_attend "Frequency attend religious services"
la var volunteer "Volunteer: yes or no"
la var fam_understand "Family understands you"
la var fam_rely "Can rely on your family"
la var fam_open "Open up to your family"
la var fam_demand "Family members make too many demands"
la var fam_critic "Family members criticize you"
la var fam_letudown "Family members let you down"
la var fam_nerves "Family gets on your nerves"
la var child_contact_inperson "Contact with children in -person"
la var child_contact_phone "Contact with children on the phone"
la var child_contact_write "Contact with children in writing or email"
la var child_open "Open up to children in need to talk"
la var child_rely "Can rely on your children"
la var child_understand "Your children understand the way you feel"
la var child_demand "Your children make too many demands"
la var child_critic "Your children are critical of you"
la var child_letudown "Your children let you down"
la var child_nerves "Your children get on your nerves"
la var cohabitating "Cohabitating with spouse or partner"
la var sppn_rel_close "Closeness of relationship with spouse or partner"
la var sppn_open "Open up to your spouse/partner"
la var sppn_rely "Can rely on your spouse/partner"
la var sppn_understand "Spouse/partner understands you"
la var sppn_demand "Spouse/partner make too many demands"
la var sppn_critic "Spouse/partner criticize you"
la var sppn_letudown "Spouse/partner let you down"
la var sppn_nerves "Spouse/partner get on your nerves"
la var fri_yesno "Have friends"
la var fri_contact_inperson "Contact with friends in -person"
la var fri_contact_phone "Contact with friends on the phone"
la var fri_contact_write "Contact with friends in writing or email"
la var fri_rely "Can rely on your friends"
la var fri_open "Can open up to your friends"
la var fri_understand "Friends understands you"
la var fri_demand "Friends make too many demands"
la var fri_critic "Friends criticize you"
la var fri_letudown "Friends let you down"
la var fri_nerves "Friends get on your nerves"
// Save as a temp file
tempfile _SR_fatfile_2010
save `_SR_fatfile_2010'

****************************************

// RAND HRS FAT FILE 2012
use "$hrsf\\$fhrsff12", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id nlb001f nlb001g nf176 nf177 nb082 ng086 nlb012a nlb012b nlb012c ///
	nlb012d nlb012e nlb012f nlb012g nlb009a nlb009b nlb009c nlb008c nlb008b ///
	nlb008a nlb008d nlb008e nlb008f nlb008g nlb004 nlb006 nlb005c nlb005b ///
	nlb005a nlb005d nlb005e nlb005f nlb005g nlb015 nlb017a nlb017b nlb017c ///
	nlb016b nlb016c nlb016a nlb016d nlb016e nlb016f nlb016g
// Rename variables
rename nlb001f meeting_soc
rename nlb001g meeting_other
rename nf176 neigh_contact
rename nf177 neigh_contact_per
rename nb082 religious_attend
rename ng086 volunteer
rename nlb012a fam_understand
rename nlb012b fam_rely
rename nlb012c fam_open
rename nlb012d fam_demand
rename nlb012e fam_critic
rename nlb012f fam_letudown
rename nlb012g fam_nerves
rename nlb009a child_contact_inperson
rename nlb009b child_contact_phone
rename nlb009c child_contact_write
rename nlb008c child_open
rename nlb008b child_rely
rename nlb008a child_understand
rename nlb008d child_demand
rename nlb008e child_critic
rename nlb008f child_letudown
rename nlb008g child_nerves
rename nlb004 cohabitating
rename nlb006 sppn_rel_close
rename nlb005c sppn_open
rename nlb005b sppn_rely
rename nlb005a sppn_understand
rename nlb005d sppn_demand
rename nlb005e sppn_critic
rename nlb005f sppn_letudown
rename nlb005g sppn_nerves
rename nlb015 fri_yesno
rename nlb017a fri_contact_inperson
rename nlb017b fri_contact_phone
rename nlb017c fri_contact_write
rename nlb016b fri_rely
rename nlb016c fri_open
rename nlb016a fri_understand
rename nlb016d fri_demand
rename nlb016e fri_critic
rename nlb016f fri_letudown
rename nlb016g fri_nerves
// Create wave and study variables
gen str6 wave = "11"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave meeting_soc meeting_other neigh_contact neigh_contact_per religious_attend volunteer fam_understand fam_rely fam_open fam_demand fam_critic fam_letudown fam_nerves child_contact_inperson child_contact_phone child_contact_write child_open child_rely child_understand child_demand child_critic child_letudown child_nerves cohabitating sppn_rel_close sppn_open sppn_rely sppn_understand sppn_demand sppn_critic sppn_letudown sppn_nerves fri_yesno fri_contact_inperson fri_contact_phone fri_contact_write fri_rely fri_open fri_understand fri_demand fri_critic fri_letudown fri_nerves
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var meeting_soc "Frequency attend sport/social meetings"
la var meeting_other "Frequency attend other group meetings"
la var neigh_contact "Frequency of contact with neighbors"
la var neigh_contact_per "Frequency of contact per time"
la var religious_attend "Frequency attend religious services"
la var volunteer "Volunteer: yes or no"
la var fam_understand "Family understands you"
la var fam_rely "Can rely on your family"
la var fam_open "Open up to your family"
la var fam_demand "Family members make too many demands"
la var fam_critic "Family members criticize you"
la var fam_letudown "Family members let you down"
la var fam_nerves "Family gets on your nerves"
la var child_contact_inperson "Contact with children in -person"
la var child_contact_phone "Contact with children on the phone"
la var child_contact_write "Contact with children in writing or email"
la var child_open "Open up to children in need to talk"
la var child_rely "Can rely on your children"
la var child_understand "Your children understand the way you feel"
la var child_demand "Your children make too many demands"
la var child_critic "Your children are critical of you"
la var child_letudown "Your children let you down"
la var child_nerves "Your children get on your nerves"
la var cohabitating "Cohabitating with spouse or partner"
la var sppn_rel_close "Closeness of relationship with spouse or partner"
la var sppn_open "Open up to your spouse/partner"
la var sppn_rely "Can rely on your spouse/partner"
la var sppn_understand "Spouse/partner understands you"
la var sppn_demand "Spouse/partner make too many demands"
la var sppn_critic "Spouse/partner criticize you"
la var sppn_letudown "Spouse/partner let you down"
la var sppn_nerves "Spouse/partner get on your nerves"
la var fri_yesno "Have friends"
la var fri_contact_inperson "Contact with friends in -person"
la var fri_contact_phone "Contact with friends on the phone"
la var fri_contact_write "Contact with friends in writing or email"
la var fri_rely "Can rely on your friends"
la var fri_open "Can open up to your friends"
la var fri_understand "Friends understands you"
la var fri_demand "Friends make too many demands"
la var fri_critic "Friends criticize you"
la var fri_letudown "Friends let you down"
la var fri_nerves "Friends get on your nerves"
// Save as a temp file
tempfile _SR_fatfile_2012
save `_SR_fatfile_2012'

****************************************

// RAND HRS FAT FILE 2014
use "$hrsf\\$fhrsff14", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id olb001f olb001g of176 of177 ob082 og086 olb011a olb011b olb011c ///
	olb011d olb011e olb011f olb011g olb008a olb008b olb008c olb007c olb007b ///
	olb007a olb007d olb007e olb007f olb007g olb003 olb005 olb004c olb004b ///
	olb004a olb004d olb004e olb004f olb004g olb014 olb016a olb016b olb016c ///
	olb015b olb015c olb015a olb015d olb015e olb015f olb015g
// Rename variables
rename olb001f meeting_soc
rename olb001g meeting_other
rename of176 neigh_contact
rename of177 neigh_contact_per
rename ob082 religious_attend
rename og086 volunteer
rename olb011a fam_understand
rename olb011b fam_rely
rename olb011c fam_open
rename olb011d fam_demand
rename olb011e fam_critic
rename olb011f fam_letudown
rename olb011g fam_nerves
rename olb008a child_contact_inperson
rename olb008b child_contact_phone
rename olb008c child_contact_write
rename olb007c child_open
rename olb007b child_rely
rename olb007a child_understand
rename olb007d child_demand
rename olb007e child_critic
rename olb007f child_letudown
rename olb007g child_nerves
rename olb003 cohabitating
rename olb005 sppn_rel_close
rename olb004c sppn_open
rename olb004b sppn_rely
rename olb004a sppn_understand
rename olb004d sppn_demand
rename olb004e sppn_critic
rename olb004f sppn_letudown
rename olb004g sppn_nerves
rename olb014 fri_yesno
rename olb016a fri_contact_inperson
rename olb016b fri_contact_phone
rename olb016c fri_contact_write
rename olb015b fri_rely
rename olb015c fri_open
rename olb015a fri_understand
rename olb015d fri_demand
rename olb015e fri_critic
rename olb015f fri_letudown
rename olb015g fri_nerves
// Create wave and study variables
gen str6 wave = "12"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave meeting_soc meeting_other neigh_contact neigh_contact_per religious_attend volunteer fam_understand fam_rely fam_open fam_demand fam_critic fam_letudown fam_nerves child_contact_inperson child_contact_phone child_contact_write child_open child_rely child_understand child_demand child_critic child_letudown child_nerves cohabitating sppn_rel_close sppn_open sppn_rely sppn_understand sppn_demand sppn_critic sppn_letudown sppn_nerves fri_yesno fri_contact_inperson fri_contact_phone fri_contact_write fri_rely fri_open fri_understand fri_demand fri_critic fri_letudown fri_nerves
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var meeting_soc "Frequency attend sport/social meetings"
la var meeting_other "Frequency attend other group meetings"
la var neigh_contact "Frequency of contact with neighbors"
la var neigh_contact_per "Frequency of contact per time"
la var religious_attend "Frequency attend religious services"
la var volunteer "Volunteer: yes or no"
la var fam_understand "Family understands you"
la var fam_rely "Can rely on your family"
la var fam_open "Open up to your family"
la var fam_demand "Family members make too many demands"
la var fam_critic "Family members criticize you"
la var fam_letudown "Family members let you down"
la var fam_nerves "Family gets on your nerves"
la var child_contact_inperson "Contact with children in -person"
la var child_contact_phone "Contact with children on the phone"
la var child_contact_write "Contact with children in writing or email"
la var child_open "Open up to children in need to talk"
la var child_rely "Can rely on your children"
la var child_understand "Your children understand the way you feel"
la var child_demand "Your children make too many demands"
la var child_critic "Your children are critical of you"
la var child_letudown "Your children let you down"
la var child_nerves "Your children get on your nerves"
la var cohabitating "Cohabitating with spouse or partner"
la var sppn_rel_close "Closeness of relationship with spouse or partner"
la var sppn_open "Open up to your spouse/partner"
la var sppn_rely "Can rely on your spouse/partner"
la var sppn_understand "Spouse/partner understands you"
la var sppn_demand "Spouse/partner make too many demands"
la var sppn_critic "Spouse/partner criticize you"
la var sppn_letudown "Spouse/partner let you down"
la var sppn_nerves "Spouse/partner get on your nerves"
la var fri_yesno "Have friends"
la var fri_contact_inperson "Contact with friends in -person"
la var fri_contact_phone "Contact with friends on the phone"
la var fri_contact_write "Contact with friends in writing or email"
la var fri_rely "Can rely on your friends"
la var fri_open "Can open up to your friends"
la var fri_understand "Friends understands you"
la var fri_demand "Friends make too many demands"
la var fri_critic "Friends criticize you"
la var fri_letudown "Friends let you down"
la var fri_nerves "Friends get on your nerves"
// Save as a temp file
tempfile _SR_fatfile_2014
save `_SR_fatfile_2014'

****************************************

// RAND HRS FAT FILE 2016
use "$hrsf\\$fhrsff16", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id plb001f plb001g pf176 pf177 pb082 pg086 plb011a plb011b plb011c ///
	plb011d plb011e plb011f plb011g plb008a plb008b plb008c plb007c plb007b ///
	plb007a plb007d plb007e plb007f plb007g plb003 plb005 plb004c plb004b ///
	plb004a plb004d plb004e plb004f plb004g plb014 plb016a plb016b plb016c ///
	plb015b plb015c plb015a plb015d plb015e plb015f plb015g
// Rename variables
rename plb001f meeting_soc
rename plb001g meeting_other
rename pf176 neigh_contact
rename pf177 neigh_contact_per
rename pb082 religious_attend
rename pg086 volunteer
rename plb011a fam_understand
rename plb011b fam_rely
rename plb011c fam_open
rename plb011d fam_demand
rename plb011e fam_critic
rename plb011f fam_letudown
rename plb011g fam_nerves
rename plb008a child_contact_inperson
rename plb008b child_contact_phone
rename plb008c child_contact_write
rename plb007c child_open
rename plb007b child_rely
rename plb007a child_understand
rename plb007d child_demand
rename plb007e child_critic
rename plb007f child_letudown
rename plb007g child_nerves
rename plb003 cohabitating
rename plb005 sppn_rel_close
rename plb004c sppn_open
rename plb004b sppn_rely
rename plb004a sppn_understand
rename plb004d sppn_demand
rename plb004e sppn_critic
rename plb004f sppn_letudown
rename plb004g sppn_nerves
rename plb014 fri_yesno
rename plb016a fri_contact_inperson
rename plb016b fri_contact_phone
rename plb016c fri_contact_write
rename plb015b fri_rely
rename plb015c fri_open
rename plb015a fri_understand
rename plb015d fri_demand
rename plb015e fri_critic
rename plb015f fri_letudown
rename plb015g fri_nerves
// Create wave and study variables
gen str6 wave = "13"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave meeting_soc meeting_other neigh_contact neigh_contact_per ///
	religious_attend volunteer fam_understand fam_rely fam_open fam_demand ///
	fam_critic fam_letudown fam_nerves child_contact_inperson ///
	child_contact_phone child_contact_write child_open child_rely ///
	child_understand child_demand child_critic child_letudown child_nerves ///
	cohabitating sppn_rel_close sppn_open sppn_rely sppn_understand ///
	sppn_demand sppn_critic sppn_letudown sppn_nerves fri_yesno ///
	fri_contact_inperson fri_contact_phone fri_contact_write fri_rely ///
	fri_open fri_understand fri_demand fri_critic fri_letudown fri_nerves
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var meeting_soc "Frequency attend sport/social meetings"
la var meeting_other "Frequency attend other group meetings"
la var neigh_contact "Frequency of contact with neighbors"
la var neigh_contact_per "Frequency of contact per time"
la var religious_attend "Frequency attend religious services"
la var volunteer "Volunteer: yes or no"
la var fam_understand "Family understands you"
la var fam_rely "Can rely on your family"
la var fam_open "Open up to your family"
la var fam_demand "Family members make too many demands"
la var fam_critic "Family members criticize you"
la var fam_letudown "Family members let you down"
la var fam_nerves "Family gets on your nerves"
la var child_contact_inperson "Contact with children in -person"
la var child_contact_phone "Contact with children on the phone"
la var child_contact_write "Contact with children in writing or email"
la var child_open "Open up to children in need to talk"
la var child_rely "Can rely on your children"
la var child_understand "Your children understand the way you feel"
la var child_demand "Your children make too many demands"
la var child_critic "Your children are critical of you"
la var child_letudown "Your children let you down"
la var child_nerves "Your children get on your nerves"
la var cohabitating "Cohabitating with spouse or partner"
la var sppn_rel_close "Closeness of relationship with spouse or partner"
la var sppn_open "Open up to your spouse/partner"
la var sppn_rely "Can rely on your spouse/partner"
la var sppn_understand "Spouse/partner understands you"
la var sppn_demand "Spouse/partner make too many demands"
la var sppn_critic "Spouse/partner criticize you"
la var sppn_letudown "Spouse/partner let you down"
la var sppn_nerves "Spouse/partner get on your nerves"
la var fri_yesno "Have friends"
la var fri_contact_inperson "Contact with friends in -person"
la var fri_contact_phone "Contact with friends on the phone"
la var fri_contact_write "Contact with friends in writing or email"
la var fri_rely "Can rely on your friends"
la var fri_open "Can open up to your friends"
la var fri_understand "Friends understands you"
la var fri_demand "Friends make too many demands"
la var fri_critic "Friends criticize you"
la var fri_letudown "Friends let you down"
la var fri_nerves "Friends get on your nerves"
// Save as a temp file
tempfile _SR_fatfile_2016
save `_SR_fatfile_2016'

****************************************

// RAND HRS LONGITUDINAL FILE 1992-2018 VERSION 2
use "$hrsr\\$fhrsrlf", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h3child r3livpar r3mstat h4child r4livpar r4mstat h5child r5livpar ///
	r5mstat h6child r6livpar r6mstat h7child r7livpar r7mstat h8child ///
	r8livpar r8mstat h9child r9livpar r9mstat h10child r10livpar r10mstat ///
	h11child r11livpar r11mstat h12child r12livpar r12mstat h13child r13mstat
// Rename variables
rename h3child child_num_3
rename r3livpar par_alive_3
rename r3mstat marital_status_3
rename h4child child_num_4
rename r4livpar par_alive_4
rename r4mstat marital_status_4
rename h5child child_num_5
rename r5livpar par_alive_5
rename r5mstat marital_status_5
rename h6child child_num_6
rename r6livpar par_alive_6
rename r6mstat marital_status_6
rename h7child child_num_7
rename r7livpar par_alive_7
rename r7mstat marital_status_7
rename h8child child_num_8
rename r8livpar par_alive_8
rename r8mstat marital_status_8
rename h9child child_num_9
rename r9livpar par_alive_9
rename r9mstat marital_status_9
rename h10child child_num_10
rename r10livpar par_alive_10
rename r10mstat marital_status_10
rename h11child child_num_11
rename r11livpar par_alive_11
rename r11mstat marital_status_11
rename h12child child_num_12
rename r12livpar par_alive_12
rename r12mstat marital_status_12
rename h13child child_num_13
rename r13mstat marital_status_13
// Reshape long
reshape long child_num_ par_alive_ marital_status_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave child_num par_alive marital_status
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var child_num "Number of children"
la var par_alive "Number of living parents"
la var marital_status "Current marital status"
// Save as a temp file
tempfile _SR_92_16
save `_SR_92_16'

****************************************

// RAND HRS FAMILY DATA 2014 VERSION 1
use "$hrsr\\$fhrsrfam", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id h3resdkn r3mcontmo r3fcontmo r3mlivwho r3flivwho h4resdkn r4mcontmo ///
	r4fcontmo r4mlivwho r4flivwho h5resdkn r5mcontmo r5fcontmo r5mlivwho ///
	r5flivwho h6resdkn r6mcontmo r6fcontmo r6mlivwho r6flivwho h7resdkn ///
	r7mcontmo r7fcontmo r7mlivwho r7flivwho h8resdkn r8mcontmo r8fcontmo ///
	r8mlivwho r8flivwho h9resdkn r9mcontmo r9fcontmo r8mlivwho r9flivwho ///
	h10resdkn r10mcontmo r10fcontmo r10mlivwho r10flivwho h11resdkn ///
	r11mcontmo r11fcontmo r11mlivwho r11flivwho h12resdkn r12mcontmo ///
	r12fcontmo r12mlivwho r12flivwho
// Rename variables
rename h3resdkn child_res_3
rename r3mcontmo mom_contact_3
rename r3fcontmo dad_contact_3
rename r3mlivwho mom_res_3
rename r3flivwho dad_res_3
rename h4resdkn child_res_4
rename r4mcontmo mom_contact_4
rename r4fcontmo dad_contact_4
rename r4mlivwho mom_res_4
rename r4flivwho dad_res_4
rename h5resdkn child_res_5
rename r5mcontmo mom_contact_5
rename r5fcontmo dad_contact_5
rename r5mlivwho mom_res_5
rename r5flivwho dad_res_5
rename h6resdkn child_res_6
rename r6mcontmo mom_contact_6
rename r6fcontmo dad_contact_6
rename r6mlivwho mom_res_6
rename r6flivwho dad_res_6
rename h7resdkn child_res_7
rename r7mcontmo mom_contact_7
rename r7fcontmo dad_contact_7
rename r7mlivwho mom_res_7
rename r7flivwho dad_res_7
rename h8resdkn child_res_8
rename r8mcontmo mom_contact_8
rename r8fcontmo dad_contact_8
rename r8mlivwho mom_res_9
rename r8flivwho dad_res_8
rename h9resdkn child_res_9
rename r9mcontmo mom_contact_9
rename r9fcontmo dad_contact_9
rename r9flivwho dad_res_9
rename h10resdkn child_res_10
rename r10mcontmo mom_contact_10
rename r10fcontmo dad_contact_10
rename r10mlivwho mom_res_10
rename r10flivwho dad_res_10
rename h11resdkn child_res_11
rename r11mcontmo mom_contact_11
rename r11fcontmo dad_contact_11
rename r11mlivwho mom_res_11
rename r11flivwho dad_res_11
rename h12resdkn child_res_12
rename r12mcontmo mom_contact_12
rename r12fcontmo dad_contact_12
rename r12mlivwho mom_res_12
rename r12flivwho dad_res_12
// Reshape long
reshape long child_res_ mom_contact_ dad_contact_ mom_res_ dad_res_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave child_res mom_contact dad_contact mom_res dad_res
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var child_res "Living with children"
la var mom_contact "Contact with mother"
la var dad_contact "Contact with father"
la var mom_res "Who does you mother live with"
la var dad_res "Who does you father live with"
// Save as a temp file
tempfile _SR_hrsfamr92_14
save `_SR_hrsfamr92_14'

***********************************************************
**                      BIOMARKERS                       **
***********************************************************
// 2006 BIOMARKER DATA
import sas using "$hrsb\\$fhrsb06", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
gen id = hhid + pn
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id ka1c_adj ktc_adj khdl_adj kcrp_adj kcysc_adj
// Rename variables
rename ka1c_adj hba1c
rename ktc_adj totchol
rename khdl_adj hdlchol
rename kcrp_adj crp
rename kcysc_adj cystatinc
// Create wave and study variables
gen str6 wave = "8"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave hba1c totchol hdlchol crp cystatinc
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hba1c "Hemoglobin A1c (%)"
la var totchol "Total Cholesterol, mg/dL"
la var hdlchol "HDL Cholesterol, mg/dL"
la var crp "C-reactive protein (mg/l)"
la var cystatinc "cystatin c, mg/L"
// Save as a temp file
tempfile _Bio_biomk06bl_r
save `_Bio_biomk06bl_r'

****************************************

// 2008 BIOMARKER DATA
import sas using "$hrsb\\$fhrsb08", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
gen id = hhid + pn
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id la1c_adj ltc_adj lhdl_adj lcrp_adj lcysc_adj
// Rename variables
rename la1c_adj hba1c
rename ltc_adj totchol
rename lhdl_adj hdlchol
rename lcrp_adj crp
rename lcysc_adj cystatinc
// Create wave and study variables
gen str6 wave = "9"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave hba1c totchol hdlchol crp cystatinc
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hba1c "Hemoglobin A1c (%)"
la var totchol "Total Cholesterol, mg/dL"
la var hdlchol "HDL Cholesterol, mg/dL"
la var crp "C-reactive protein (mg/l)"
la var cystatinc "cystatin c, mg/L"
// Save as a temp file
tempfile _Bio_biomk08bl_r
save `_Bio_biomk08bl_r'

****************************************

// 2010 BIOMARKER DATA
import sas using "$hrsb\\$fhrsb10", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
gen id = hhid + pn
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id ma1c_adj mtc_adj mhdl_adj mcrp_adj mcysc_adj
// Rename variables
rename ma1c_adj hba1c
rename mtc_adj totchol
rename mhdl_adj hdlchol
rename mcrp_adj crp
rename mcysc_adj cystatinc
// Create wave and study variables
gen str6 wave = "10"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave hba1c totchol hdlchol crp cystatinc
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hba1c "Hemoglobin A1c (%)"
la var totchol "Total Cholesterol, mg/dL"
la var hdlchol "HDL Cholesterol, mg/dL"
la var crp "C-reactive protein (mg/l)"
la var cystatinc "cystatin c, mg/L"
// Save as a temp file
tempfile _Bio_biomk10bl_r
save `_Bio_biomk10bl_r'

****************************************

// 2012 BIOMARKER DATA
import sas using "$hrsb\\$fhrsb12", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
gen id = hhid + pn
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id na1c_adj ntc_adj nhdl_adj ncrp_adj ncysc_adj
// Rename variables
rename na1c_adj hba1c
rename ntc_adj totchol
rename nhdl_adj hdlchol
rename ncrp_adj crp
rename ncysc_adj cystatinc
// Create wave and study variables
gen str6 wave = "11"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave hba1c totchol hdlchol crp cystatinc
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hba1c "Hemoglobin A1c (%)"
la var totchol "Total Cholesterol, mg/dL"
la var hdlchol "HDL Cholesterol, mg/dL"
la var crp "C-reactive protein (mg/l)"
la var cystatinc "cystatin c, mg/L"
// Save as a temp file
tempfile _Bio_biomk12bl_r
save `_Bio_biomk12bl_r'

****************************************

// 2014 BIOMARKER DATA
import sas using "$hrsb\\$fhrsb14", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
gen id = hhid + pn
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id oa1c_adj otc_adj ohdl_adj ocrp_adj ocysc_adj
// Rename variables
rename oa1c_adj hba1c
rename otc_adj totchol
rename ohdl_adj hdlchol
rename ocrp_adj crp
rename ocysc_adj cystatinc
// Create wave and study variables
gen str6 wave = "12"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave hba1c totchol hdlchol crp cystatinc
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hba1c "Hemoglobin A1c (%)"
la var totchol "Total Cholesterol, mg/dL"
la var hdlchol "HDL Cholesterol, mg/dL"
la var crp "C-reactive protein (mg/l)"
la var cystatinc "cystatin c, mg/L"
// Save as a temp file
tempfile _Bio_biomk14bl
save `_Bio_biomk14bl'

****************************************

// 2016 BIOMARKER DATA
import sas using "$hrsb\\$fhrsb16", clear
// Rename variables to lower case for consistency
renvars *, lower
// Generate the ID variable and convert to string if numeric
gen id = hhid + pn
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id pa1c_adj
// Rename variable
rename pa1c_adj hba1c
// Create wave and study variables
gen str6 wave = "13"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave hba1c
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hba1c "Hemoglobin A1c (%)"
// Save as a temp file
tempfile _Bio_biomk16bl_r
save `_Bio_biomk16bl_r'

****************************************

// 2016 VENOUS BLOOD STUDY
import sas using "$hrsb\\$fhrsv16", clear
// Rename variables to lower case for consistency
renvars *, lower
// Generate the ID variable and convert to string if numeric
gen id = hhid + pn
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id pchol phdld pldlc ptgf pcrp pcysc
// Rename variables
rename pchol totchol
rename phdld hdlchol
rename pldlc ldlchol
rename ptgf triglyceride
rename pcrp crp
rename pcysc cystatinc
// Rename variables
gen str6 wave = "13"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave totchol hdlchol ldlchol triglyceride crp cystatinc
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var totchol "Total Cholesterol, mg/dL"
la var hdlchol "HDL Cholesterol, mg/dL"
la var ldlchol "LDL Cholesterol, mg/dL"
la var triglyceride "Triglycerides (mg/dL)"
la var crp "C-reactive protein (mg/l)"
la var cystatinc "cystatin c, mg/L"
// Save as a temp file
tempfile _Bio_hrs2016vbs
save `_Bio_hrs2016vbs'

****************************************

// RAND HRS LONGITUDINAL FILE 1992-2018 VERSION 2
use "$hrsr\\$fhrsrlf", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id r1height r2height r3height r4height r5height r6height r7height ///
	r8height r9height r10height r11height r12height r13height r1weight ///
	r2weight r3weight r4weight r5weight r6weight r7weight r8weight r9weight ///
	r10weight r11weight r12weight r13weight r1bmi r2bmi r3bmi r4bmi r5bmi ///
	r6bmi r7bmi r8bmi r9bmi r10bmi r11bmi r12bmi r13bmi r8pmwaist r9pmwaist ///
	r10pmwaist r11pmwaist r12pmwaist r13pmwaist r8bpdia r9bpdia r10bpdia ///
	r11bpdia r12bpdia r13bpdia r8bpsys r9bpsys r10bpsys r11bpsys r12bpsys ///
	r13bpsys r8bppuls r9bppuls r10bppuls r11bppuls r12bppuls r13bppuls r1hibp ///
	r2hibp r3hibp r4hibp r5hibp r6hibp r7hibp r8hibp r9hibp r10hibp r11hibp ///
	r12hibp r13hibp r1diab r2diab r3diab r4diab r5diab r6diab r7diab r8diab ///
	r9diab r10diab r11diab r12diab r13diab
// Rename existing or construct new variables
rename r1height height_1
rename r2height height_2
rename r3height height_3
rename r4height height_4
rename r5height height_5
rename r6height height_6
rename r7height height_7
rename r8height height_8
rename r9height height_9
rename r10height height_10
rename r11height height_11
rename r12height height_12
rename r13height height_13
rename r1weight weight_1
rename r2weight weight_2
rename r3weight weight_3
rename r4weight weight_4
rename r5weight weight_5
rename r6weight weight_6
rename r7weight weight_7
rename r8weight weight_8
rename r9weight weight_9
rename r10weight weight_10
rename r11weight weight_11
rename r12weight weight_12
rename r13weight weight_13
rename r1bmi bmi_1
rename r2bmi bmi_2
rename r3bmi bmi_3
rename r4bmi bmi_4
rename r5bmi bmi_5
rename r6bmi bmi_6
rename r7bmi bmi_7
rename r8bmi bmi_8
rename r9bmi bmi_9
rename r10bmi bmi_10
rename r11bmi bmi_11
rename r12bmi bmi_12
rename r13bmi bmi_13
gen wc_8 = r8pmwaist * 2.54
gen wc_9 = r9pmwaist * 2.54
gen wc_10 = r10pmwaist * 2.54
gen wc_11 = r11pmwaist * 2.54
gen wc_12 = r12pmwaist * 2.54
gen wc_13 = r13pmwaist * 2.54
rename r8bpdia diastolicbp_8
rename r9bpdia diastolicbp_9
rename r10bpdia diastolicbp_10
rename r11bpdia diastolicbp_11
rename r12bpdia diastolicbp_12
rename r13bpdia diastolicbp_13
rename r8bpsys systolicbp_8
rename r9bpsys systolicbp_9
rename r10bpsys systolicbp_10
rename r11bpsys systolicbp_11
rename r12bpsys systolicbp_12
rename r13bpsys systolicbp_13
rename r8bppuls pulse_8
rename r9bppuls pulse_9
rename r10bppuls pulse_10
rename r11bppuls pulse_11
rename r12bppuls pulse_12
rename r13bppuls pulse_13
rename r1hibp hypertension_1
rename r2hibp hypertension_2
rename r3hibp hypertension_3
rename r4hibp hypertension_4
rename r5hibp hypertension_5
rename r6hibp hypertension_6
rename r7hibp hypertension_7
rename r8hibp hypertension_8
rename r9hibp hypertension_9
rename r10hibp hypertension_10
rename r11hibp hypertension_11
rename r12hibp hypertension_12
rename r13hibp hypertension_13
rename r1diab diabetes_1
rename r2diab diabetes_2
rename r3diab diabetes_3
rename r4diab diabetes_4
rename r5diab diabetes_5
rename r6diab diabetes_6
rename r7diab diabetes_7
rename r8diab diabetes_8
rename r9diab diabetes_9
rename r10diab diabetes_10
rename r11diab diabetes_11
rename r12diab diabetes_12
rename r13diab diabetes_13
// Reshape long
reshape long height_ weight_ bmi_ wc_ diastolicbp_ systolicbp_ pulse_ ///
	hypertension_ diabetes_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave height weight bmi wc diastolicbp systolicbp pulse ///
	hypertension diabetes
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var height "Height (m)"
la var weight "Weight (kg)"
la var bmi "Body mass index (kg/m2)"
la var wc "Waist circumference (cm)"
la var diastolicbp "Diastolic BP, mm/Hg"
la var systolicbp "Systolic BP, mm/Hg"
la var pulse "Pulse, beats/minute"
la var hypertension "dichtomous measure for evidence of hypertension"
la var diabetes "dichtomous measure for evidence of diabetes"
// Save as a temp file
tempfile _Bio_92_16
save `_Bio_92_16'

***********************************************************
**                       COGNITION                       **
***********************************************************
// RAND HRS LONGITUDINAL FILE 1992-2018 VERSION 2
use "$hrsr\\$fhrsrlf", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id r3imrc r4imrc r5imrc r6imrc r7imrc r8imrc r9imrc r10imrc r11imrc ///
	r12imrc r13imrc r14imrc r3dlrc r4dlrc r5dlrc r6dlrc r7dlrc r8dlrc r9dlrc ///
	r10dlrc r11dlrc r12dlrc r13dlrc r14dlrc r3ser7 r4ser7 r5ser7 r6ser7 ///
	r7ser7 r8ser7 r9ser7 r10ser7 r11ser7 r12ser7 r13ser7 r14ser7 r3bwc20 ///
	r4bwc20 r5bwc20 r6bwc20 r7bwc20 r8bwc20 r9bwc20 r10bwc20 r11bwc20 ///
	r12bwc20 r13bwc20 r14bwc20 r3mo r4mo r5mo r6mo r7mo r8mo r9mo r10mo r11mo ///
	r12mo r13mo r14mo r3dy r4dy r5dy r6dy r7dy r8dy r9dy r10dy r11dy r12dy ///
	r13dy r14dy r3yr r4yr r5yr r6yr r7yr r8yr r9yr r10yr r11yr r12yr r13yr ///
	r14yr r3dw r4dw r5dw r6dw r7dw r8dw r9dw r10dw r11dw r12dw r13dw r14dw ///
	r3scis r4scis r5scis r6scis r7scis r8scis r9scis r10scis r11scis r12scis ///
	r13scis r14scis r3cact r4cact r5cact r6cact r7cact r8cact r9cact r10cact ///
	r11cact r12cact r13cact r14cact r3pres r4pres r5pres r6pres r7pres r8pres ///
	r9pres r10pres r11pres r12pres r13pres r14pres r3vp r4vp r5vp r6vp r7vp ///
	r8vp r9vp r10vp r11vp r12vp r13vp r14vp r3vocab r4vocab r5vocab r6vocab ///
	r7vocab r8vocab r9vocab r10vocab r11vocab r12vocab r13vocab r14vocab ///
	r3cogtot r4cogtot r5cogtot r6cogtot r7cogtot r8cogtot r9cogtot r10cogtot ///
	r11cogtot r12cogtot r13cogtot r14cogtot
// Rename variables
rename r3imrc immedrecall_3
rename r4imrc immedrecall_4
rename r5imrc immedrecall_5
rename r6imrc immedrecall_6
rename r7imrc immedrecall_7
rename r8imrc immedrecall_8
rename r9imrc immedrecall_9
rename r10imrc immedrecall_10
rename r11imrc immedrecall_11
rename r12imrc immedrecall_12
rename r13imrc immedrecall_13
rename r14imrc immedrecall_14
rename r3dlrc delayrecall_3
rename r4dlrc delayrecall_4
rename r5dlrc delayrecall_5
rename r6dlrc delayrecall_6
rename r7dlrc delayrecall_7
rename r8dlrc delayrecall_8
rename r9dlrc delayrecall_9
rename r10dlrc delayrecall_10
rename r11dlrc delayrecall_11
rename r12dlrc delayrecall_12
rename r13dlrc delayrecall_13
rename r14dlrc delayrecall_14
rename r3ser7 serial7_3
rename r4ser7 serial7_4
rename r5ser7 serial7_5
rename r6ser7 serial7_6
rename r7ser7 serial7_7
rename r8ser7 serial7_8
rename r9ser7 serial7_9
rename r10ser7 serial7_10
rename r11ser7 serial7_11
rename r12ser7 serial7_12
rename r13ser7 serial7_13
rename r14ser7 serial7_14
rename r3bwc20 backcount_3
rename r4bwc20 backcount_4
rename r5bwc20 backcount_5
rename r6bwc20 backcount_6
rename r7bwc20 backcount_7
rename r8bwc20 backcount_8
rename r9bwc20 backcount_9
rename r10bwc20 backcount_10
rename r11bwc20 backcount_11
rename r12bwc20 backcount_12
rename r13bwc20 backcount_13
rename r14bwc20 backcount_14
rename r3mo datename_mo_3
rename r4mo datename_mo_4
rename r5mo datename_mo_5
rename r6mo datename_mo_6
rename r7mo datename_mo_7
rename r8mo datename_mo_8
rename r9mo datename_mo_9
rename r10mo datename_mo_10
rename r11mo datename_mo_11
rename r12mo datename_mo_12
rename r13mo datename_mo_13
rename r14mo datename_mo_14
rename r3dy datename_daymo_3
rename r4dy datename_daymo_4
rename r5dy datename_daymo_5
rename r6dy datename_daymo_6
rename r7dy datename_daymo_7
rename r8dy datename_daymo_8
rename r9dy datename_daymo_9
rename r10dy datename_daymo_10
rename r11dy datename_daymo_11
rename r12dy datename_daymo_12
rename r13dy datename_daymo_13
rename r14dy datename_daymo_14
rename r3yr datename_year_3
rename r4yr datename_year_4
rename r5yr datename_year_5
rename r6yr datename_year_6
rename r7yr datename_year_7
rename r8yr datename_year_8
rename r9yr datename_year_9
rename r10yr datename_year_10
rename r11yr datename_year_11
rename r12yr datename_year_12
rename r13yr datename_year_13
rename r14yr datename_year_14
rename r3dw datename_daywk_3
rename r4dw datename_daywk_4
rename r5dw datename_daywk_5
rename r6dw datename_daywk_6
rename r7dw datename_daywk_7
rename r8dw datename_daywk_8
rename r9dw datename_daywk_9
rename r10dw datename_daywk_10
rename r11dw datename_daywk_11
rename r12dw datename_daywk_12
rename r13dw datename_daywk_13
rename r14dw datename_daywk_14
rename r3scis objname_scis_3
rename r4scis objname_scis_4
rename r5scis objname_scis_5
rename r6scis objname_scis_6
rename r7scis objname_scis_7
rename r8scis objname_scis_8
rename r9scis objname_scis_9
rename r10scis objname_scis_10
rename r11scis objname_scis_11
rename r12scis objname_scis_12
rename r13scis objname_scis_13
rename r14scis objname_scis_14
rename r3cact objname_cact_3
rename r4cact objname_cact_4
rename r5cact objname_cact_5
rename r6cact objname_cact_6
rename r7cact objname_cact_7
rename r8cact objname_cact_8
rename r9cact objname_cact_9
rename r10cact objname_cact_10
rename r11cact objname_cact_11
rename r12cact objname_cact_12
rename r13cact objname_cact_13
rename r14cact objname_cact_14
rename r3pres presname_3
rename r4pres presname_4
rename r5pres presname_5
rename r6pres presname_6
rename r7pres presname_7
rename r8pres presname_8
rename r9pres presname_9
rename r10pres presname_10
rename r11pres presname_11
rename r12pres presname_12
rename r13pres presname_13
rename r14pres presname_14
rename r3vp vpname_3
rename r4vp vpname_4
rename r5vp vpname_5
rename r6vp vpname_6
rename r7vp vpname_7
rename r8vp vpname_8
rename r9vp vpname_9
rename r10vp vpname_10
rename r11vp vpname_11
rename r12vp vpname_12
rename r13vp vpname_13
rename r14vp vpname_14
rename r3vocab vocab_3
rename r4vocab vocab_4
rename r5vocab vocab_5
rename r6vocab vocab_6
rename r7vocab vocab_7
rename r8vocab vocab_8
rename r9vocab vocab_9
rename r10vocab vocab_10
rename r11vocab vocab_11
rename r12vocab vocab_12
rename r13vocab vocab_13
rename r14vocab vocab_14
rename r3cogtot cogtot_3
rename r4cogtot cogtot_4
rename r5cogtot cogtot_5
rename r6cogtot cogtot_6
rename r7cogtot cogtot_7
rename r8cogtot cogtot_8
rename r9cogtot cogtot_9
rename r10cogtot cogtot_10
rename r11cogtot cogtot_11
rename r12cogtot cogtot_12
rename r13cogtot cogtot_13
rename r14cogtot cogtot_14
// Reshape long
reshape long immedrecall_ delayrecall_ serial7_ backcount_ datename_mo_ ///
	datename_daymo_ datename_year_ datename_daywk_ objname_scis_ ///
	objname_cact_ presname_ vpname_ vocab_ cogtot_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave immedrecall delayrecall serial7 backcount datename_mo ///
	datename_daymo datename_year datename_daywk objname_scis objname_cact ///
	presname vpname vocab cogtot
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var immedrecall "immediate recall - total # of words"
la var delayrecall "delayed recall - total # of words"
la var serial7 "serial 7s - # correct substractions"
la var backcount "backwards counting - # counted"
la var datename_mo "Date naming - month"
la var datename_daymo "Date naming - day of month"
la var datename_year "Date naming - year"
la var datename_daywk "Date naming - day of the week"
la var objname_scis "Object naming - scissors"
la var objname_cact "Object naming - cactus"
la var presname "president naming"
la var vpname "vice-president naming"
la var vocab "vocabulary - sum score"
la var cogtot "total cognition summary score"
// Save as a temp file
tempfile _Cog_92_16
save `_Cog_92_16'

***********************************************************
**                 COVARIATES: ATTRITION                 **
***********************************************************
// RAND HRS LONGITUDINAL FILE 1992-2018 VERSION 2
use "$hrsr\\$fhrsrlf", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id radyear radmonth raddate radsrc radtimtdth
// Rename variables
rename radyear year_died
rename radmonth month_died
rename raddate date_died
rename radsrc death_source
rename radtimtdth death2intvw_months
// Create wave and study variables
gen str6 wave = "14"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave year_died month_died date_died death_source death2intvw_months
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var year_died "Year of death"
la var month_died "Month of death"
la var date_died "Date of death"
la var death_source "Death date source"
la var death2intvw_months "Number of months from last Core interview to death date"
// Save as a temp file
tempfile _Cov_Attrition_92_16
save `_Cov_Attrition_92_16'

***********************************************************
**                 COVARIATES: BEHAVIORS                 **
***********************************************************
// RAND HRS LONGITUDINAL FILE 1992-2018 VERSION 2
use "$hrsr\\$fhrsrlf", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id r1ltactf r7ltactx r8ltactx r9ltactx r10ltactx r11ltactx r12ltactx ///
	r13ltactx r7mdactx r8mdactx r9mdactx r10mdactx r11mdactx r12mdactx ///
	r13mdactx r1vigact r7vgactx r8vgactx r9vgactx r10vgactx r11vgactx ///
	r12vgactx r13vgactx r1lhtact r2lhtact r1vigact r2vigact r3vigact ///
	r4vigact r5vigact r6vigact r3drink r4drink r5drink r6drink r7drink ///
	r8drink r9drink r10drink r11drink r12drink r13drink r3drinkd r4drinkd ///
	r5drinkd r6drinkd r7drinkd r8drinkd r9drinkd r10drinkd r11drinkd ///
	r12drinkd r13drinkd r3drinkn r4drinkn r5drinkn r6drinkn r7drinkn ///
	r8drinkn r9drinkn r10drinkn r11drinkn r12drinkn r13drinkn r1smoken ///
	r2smoken r3smoken r4smoken r5smoken r6smoken r7smoken r8smoken r9smoken ///
	r10smoken r11smoken r12smoken r13smoken
// Rename variables
rename r1ltactf pa_light_1
rename r7ltactx pa_light_7
rename r8ltactx pa_light_8
rename r9ltactx pa_light_9
rename r10ltactx pa_light_10
rename r11ltactx pa_light_11
rename r12ltactx pa_light_12
rename r13ltactx pa_light_13
rename r7mdactx pa_mod_7
rename r8mdactx pa_mod_8
rename r9mdactx pa_mod_9
rename r10mdactx pa_mod_10
rename r11mdactx pa_mod_11
rename r12mdactx pa_mod_12
rename r13mdactx pa_mod_13
rename r1vigact pa_vig3xwk_1
rename r7vgactx pa_vig_7
rename r8vgactx pa_vig_8
rename r9vgactx pa_vig_9
rename r10vgactx pa_vig_10
rename r11vgactx pa_vig_11
rename r12vgactx pa_vig_12
rename r13vgactx pa_vig_13
rename r1lhtact pa_light3xwk_1
rename r2lhtact pa_light3xwk_2
rename r2vigact pa_vig3xwk_2
rename r3vigact pa_vig3xwk_3
rename r4vigact pa_vig3xwk_4
rename r5vigact pa_vig3xwk_5
rename r6vigact pa_vig3xwk_6
rename r3drink everdrink_3
rename r4drink everdrink_4
rename r5drink everdrink_5
rename r6drink everdrink_6
rename r7drink everdrink_7
rename r8drink everdrink_8
rename r9drink everdrink_9
rename r10drink everdrink_10
rename r11drink everdrink_11
rename r12drink everdrink_12
rename r13drink everdrink_13
rename r3drinkd alc_drinkfreqweek_3
rename r4drinkd alc_drinkfreqweek_4
rename r5drinkd alc_drinkfreqweek_5
rename r6drinkd alc_drinkfreqweek_6
rename r7drinkd alc_drinkfreqweek_7
rename r8drinkd alc_drinkfreqweek_8
rename r9drinkd alc_drinkfreqweek_9
rename r10drinkd alc_drinkfreqweek_10
rename r11drinkd alc_drinkfreqweek_11
rename r12drinkd alc_drinkfreqweek_12
rename r13drinkd alc_drinkfreqweek_13
rename r3drinkn drinksperday_3
rename r4drinkn drinksperday_4
rename r5drinkn drinksperday_5
rename r6drinkn drinksperday_6
rename r7drinkn drinksperday_7
rename r8drinkn drinksperday_8
rename r9drinkn drinksperday_9
rename r10drinkn drinksperday_10
rename r11drinkn drinksperday_11
rename r12drinkn drinksperday_12
rename r13drinkn drinksperday_13
rename r1smoken smoker_1
rename r2smoken smoker_2
rename r3smoken smoker_3
rename r4smoken smoker_4
rename r5smoken smoker_5
rename r6smoken smoker_6
rename r7smoken smoker_7
rename r8smoken smoker_8
rename r9smoken smoker_9
rename r10smoken smoker_10
rename r11smoken smoker_11
rename r12smoken smoker_12
rename r13smoken smoker_13
// Reshape long
reshape long pa_light_ pa_mod_ pa_vig_ pa_light3xwk_ pa_vig3xwk_ everdrink_ ///
	alc_drinkfreqweek_ drinksperday_ smoker_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave pa_light pa_mod pa_vig pa_light3xwk pa_vig3xwk everdrink alc_drinkfreqweek drinksperday smoker
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var pa_light "frequency of light physical activity"
la var pa_mod "frequency of moderately active sports or activities"
la var pa_vig "frequency of vigorous/active sports or exercise"
la var pa_light3xwk "yes/no: engage in light physical activity 3+ times a week"
la var pa_vig3xwk "binary: engage in vigorous/active sports or exercise average 3+ times a week"
la var everdrink "Drink alcohol ever in past year - yes or no"
la var alc_drinkfreqweek "Number of drinks per week"
la var drinksperday "Number of drinks per day when drank"
la var smoker "Current smoker - yes or no"
// Save as a temp file
tempfile _Cov_Behav_92_16
save `_Cov_Behav_92_16'

***********************************************************
**                COVARIATES: DEMOGRAPHIC                **
***********************************************************
// RAND HRS LONGITUDINAL FILE 1992-2018 VERSION 2
use "$hrsr\\$fhrsrlf", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id r1agey_m r2agey_m r3agey_m r4agey_m r5agey_m r6agey_m r7agey_m ///
	r8agey_m r9agey_m r10agey_m r11agey_m r12agey_m r13agey_m r14agey_m ///
	rabyear racohbyr ragender raracem rahispan rabplace rarelig rabplace ///
	r3proxy r4proxy r5proxy r6proxy r7proxy r8proxy r9proxy r10proxy ///
	r11proxy r12proxy r13proxy r14proxy
// Rename existing or construct new variables
rename r1agey_m age_1
rename r2agey_m age_2
rename r3agey_m age_3
rename r4agey_m age_4
rename r5agey_m age_5
rename r6agey_m age_6
rename r7agey_m age_7
rename r8agey_m age_8
rename r9agey_m age_9
rename r10agey_m age_10
rename r11agey_m age_11
rename r12agey_m age_12
rename r13agey_m age_13
rename r14agey_m age_14
gen birthyear_1 = rabyear
gen birthyear_2 = rabyear
gen birthyear_3 = rabyear
gen birthyear_4 = rabyear
gen birthyear_5 = rabyear
gen birthyear_6 = rabyear
gen birthyear_7 = rabyear
gen birthyear_8 = rabyear
gen birthyear_9 = rabyear
gen birthyear_10 = rabyear
gen birthyear_11 = rabyear
gen birthyear_12 = rabyear
gen birthyear_13 = rabyear
gen birthyear_14 = rabyear
drop rabyear
gen hrscohort_1 = racohbyr
gen hrscohort_2 = racohbyr
gen hrscohort_3 = racohbyr
gen hrscohort_4 = racohbyr
gen hrscohort_5 = racohbyr
gen hrscohort_6 = racohbyr
gen hrscohort_7 = racohbyr
gen hrscohort_8 = racohbyr
gen hrscohort_9 = racohbyr
gen hrscohort_10 = racohbyr
gen hrscohort_11 = racohbyr
gen hrscohort_12 = racohbyr
gen hrscohort_13 = racohbyr
gen hrscohort_14 = racohbyr
drop racohbyr
gen female_1 = ragender
gen female_2 = ragender
gen female_3 = ragender
gen female_4 = ragender
gen female_5 = ragender
gen female_6 = ragender
gen female_7 = ragender
gen female_8 = ragender
gen female_9 = ragender
gen female_10 = ragender
gen female_11 = ragender
gen female_12 = ragender
gen female_13 = ragender
gen female_14 = ragender
drop ragender
gen race_1 = raracem
gen race_2 = raracem
gen race_3 = raracem
gen race_4 = raracem
gen race_5 = raracem
gen race_6 = raracem
gen race_7 = raracem
gen race_8 = raracem
gen race_9 = raracem
gen race_10 = raracem
gen race_11 = raracem
gen race_12 = raracem
gen race_13 = raracem
gen race_14 = raracem
drop raracem
gen hispanic_1 = rahispan
gen hispanic_2 = rahispan
gen hispanic_3 = rahispan
gen hispanic_4 = rahispan
gen hispanic_5 = rahispan
gen hispanic_6 = rahispan
gen hispanic_7 = rahispan
gen hispanic_8 = rahispan
gen hispanic_9 = rahispan
gen hispanic_10 = rahispan
gen hispanic_11 = rahispan
gen hispanic_12 = rahispan
gen hispanic_13 = rahispan
gen hispanic_14 = rahispan
drop rahispan
gen region_1 = rabplace
gen region_2 = rabplace
gen region_3 = rabplace
gen region_4 = rabplace
gen region_5 = rabplace
gen region_6 = rabplace
gen region_7 = rabplace
gen region_8 = rabplace
gen region_9 = rabplace
gen region_10 = rabplace
gen region_11 = rabplace
gen region_12 = rabplace
gen region_13 = rabplace
gen region_14 = rabplace
gen immigrant_1 = rabplace
gen immigrant_2 = rabplace
gen immigrant_3 = rabplace
gen immigrant_4 = rabplace
gen immigrant_5 = rabplace
gen immigrant_6 = rabplace
gen immigrant_7 = rabplace
gen immigrant_8 = rabplace
gen immigrant_9 = rabplace
gen immigrant_10 = rabplace
gen immigrant_11 = rabplace
gen immigrant_12 = rabplace
gen immigrant_13 = rabplace
gen immigrant_14 = rabplace
drop rabplace
gen religion_1 = rarelig
gen religion_2 = rarelig
gen religion_3 = rarelig
gen religion_4 = rarelig
gen religion_5 = rarelig
gen religion_6 = rarelig
gen religion_7 = rarelig
gen religion_8 = rarelig
gen religion_9 = rarelig
gen religion_10 = rarelig
gen religion_11 = rarelig
gen religion_12 = rarelig
gen religion_13 = rarelig
gen religion_14 = rarelig
drop rarelig
rename r3proxy proxy_3
rename r4proxy proxy_4
rename r5proxy proxy_5
rename r6proxy proxy_6
rename r7proxy proxy_7
rename r8proxy proxy_8
rename r9proxy proxy_9
rename r10proxy proxy_10
rename r11proxy proxy_11
rename r12proxy proxy_12
rename r13proxy proxy_13
rename r14proxy proxy_14
// Reshape long
reshape long age_ birthyear_ hrscohort_ female_ race_ hispanic_ immigrant_ ///
	religion_ region_ proxy_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave age birthyear hrscohort female race hispanic immigrant ///
	religion region proxy
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var age "respondent age"
la var birthyear "respondent birth year"
la var hrscohort "respondent HRS study birth cohort"
la var female "respondent gender"
la var race "respondent gender"
la var hispanic "respondent race/ethnicity"
la var immigrant "immigrant status"
la var religion "respondent religion"
la var region "respondent geographic census region"
la var proxy "whether proxy interview"
// Save as a temp file
tempfile _Cov_Demog_92_16
save `_Cov_Demog_92_16'

***********************************************************
**                COVARIATES: INTELLIGENCE               **
***********************************************************
// !!! NO INTELLIGENCE VARIABLES FOR HRS !!!

***********************************************************
**               COVARIATES: LB ELIGIBILITY              **
***********************************************************
// RAND HRS FAT FILE 2006
use "$hrsf\\$fhrsff06", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id klbelig
// Rename variable
rename klbelig lbelig
// Create wave and study variables
gen str6 wave = "8"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave lbelig
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var lbelig "leave behind eligibility"
// Save as a temp file
tempfile _Cov_LBElig_06
save `_Cov_LBElig_06'

****************************************

// RAND HRS FAT FILE 2008
use "$hrsf\\$fhrsff08", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id llbelig
// Rename variable
rename llbelig lbelig
// Create wave and study variables
gen str6 wave = "9"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave lbelig
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var lbelig "leave behind eligibility"
// Save as a temp file
tempfile _Cov_LBElig_08
save `_Cov_LBElig_08'

****************************************

// RAND HRS FAT FILE 2010
use "$hrsf\\$fhrsff10", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id mlbelig
// Rename variable
rename mlbelig lbelig
// Create wave and study variables
gen str6 wave = "10"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave lbelig
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var lbelig "leave behind eligibility"
// Save as a temp file
tempfile _Cov_LBElig_10
save `_Cov_LBElig_10'

****************************************

// RAND HRS FAT FILE 2012
use "$hrsf\\$fhrsff12", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id nlbelig
// Rename variable
rename nlbelig lbelig
// Create wave and study variables
gen str6 wave = "11"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave lbelig
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var lbelig "leave behind eligibility"
// Save as a temp file
tempfile _Cov_LBElig_12
save `_Cov_LBElig_12'

****************************************

// RAND HRS FAT FILE 2014
use "$hrsf\\$fhrsff14", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id olbelig
// Rename variable
rename olbelig lbelig
// Create wave and study variables
gen str6 wave = "12"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave lbelig
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var lbelig "leave behind eligibility"
// Save as a temp file
tempfile _Cov_LBElig_14
save `_Cov_LBElig_14'

****************************************

// RAND HRS FAT FILE 2016
use "$hrsf\\$fhrsff16", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id plbelig
// Rename variable
rename plbelig lbelig
// Create wave and study variables
gen str6 wave = "13"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave lbelig
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var lbelig "leave behind eligibility"
// Save as a temp file
tempfile _Cov_LBElig_16
save `_Cov_LBElig_16'

****************************************

// RAND HRS FAT FILE 2018
use "$hrsf\\$fhrsff18", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id qlbelig
// Rename variable
rename qlbelig lbelig
// Create wave and study variables
gen str6 wave = "14"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave lbelig
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var lbelig "leave behind eligibility"
// Save as a temp file
tempfile _Cov_LBElig_18
save `_Cov_LBElig_18'

***********************************************************
**                   COVARIATES: MEDS                    **
***********************************************************
// RAND HRS FAT FILE 2006
use "$hrsf\\$fhrsff06", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id kc006 kc011 kc012 kn360 kn361 kn362
// Rename existing or construct new variables
rename kc006 hyperten_med
gen diab_med = kc011 == 1 | kc012 == 1
rename kn360 lipid_med
gen inflam_med = kn361 == 1 | kn362 == 1 
// Create wave and study variables
gen str6 wave = "8"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave hyperten_med diab_med lipid_med inflam_med
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hyperten_med "anti-hypertensive medication use"
la var diab_med "anti-diabetic medication use"
la var lipid_med "anti-hyperlipidemic medication use"
la var inflam_med "anti-inflammatory medication use"
// Save as a temp file
tempfile _Cov_Meds_fatfile_2006
save `_Cov_Meds_fatfile_2006'

****************************************

// RAND HRS FAT FILE 2008
use "$hrsf\\$fhrsff08", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id lc006 lc011 lc012 ln360 ln361 ln362
// Rename existing or construct new variables
rename lc006 hyperten_med
gen diab_med = lc011 == 1 | lc012 == 1
rename ln360 lipid_med
gen inflam_med = ln361 == 1 | ln362 == 1 
// Create wave and study variables
gen str6 wave = "9"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave hyperten_med diab_med lipid_med inflam_med
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hyperten_med "anti-hypertensive medication use"
la var diab_med "anti-diabetic medication use"
la var lipid_med "anti-hyperlipidemic medication use"
la var inflam_med "anti-inflammatory medication use"
// Save as a temp file
tempfile _Cov_Meds_fatfile_2008
save `_Cov_Meds_fatfile_2008'

****************************************

// RAND HRS FAT FILE 2010
use "$hrsf\\$fhrsff10", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id mc006 mc011 mc012 mn360 mn361 mn362
// Rename existing or construct new variables
rename mc006 hyperten_med
gen diab_med = mc011 == 1 | mc012 == 1
rename mn360 lipid_med
gen inflam_med = mn361 == 1 | mn362 == 1 
// Create wave and study variables
gen str6 wave = "10"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave hyperten_med diab_med lipid_med inflam_med
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hyperten_med "anti-hypertensive medication use"
la var diab_med "anti-diabetic medication use"
la var lipid_med "anti-hyperlipidemic medication use"
la var inflam_med "anti-inflammatory medication use"
// Save as a temp file
tempfile _Cov_Meds_fatfile_2010
save `_Cov_Meds_fatfile_2010'

****************************************

// RAND HRS FAT FILE 2012
use "$hrsf\\$fhrsff12", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id nc006 nc011 nc012 nn360 nn361 nn362
// Rename existing or construct new variables
rename nc006 hyperten_med
gen diab_med = nc011 == 1 | nc012 == 1
rename nn360 lipid_med
gen inflam_med = nn361 == 1 | nn362 == 1 
// Create wave and study variables
gen str6 wave = "11"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave hyperten_med diab_med lipid_med inflam_med
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hyperten_med "anti-hypertensive medication use"
la var diab_med "anti-diabetic medication use"
la var lipid_med "anti-hyperlipidemic medication use"
la var inflam_med "anti-inflammatory medication use"
// Save as a temp file
tempfile _Cov_Meds_fatfile_2012
save `_Cov_Meds_fatfile_2012'

****************************************

// RAND HRS FAT FILE 2014
use "$hrsf\\$fhrsff14", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id oc006 oc011 oc012 on360 on361 on362
// Rename existing or construct new variables
rename oc006 hyperten_med
gen diab_med = oc011 == 1 | oc012 == 1
rename on360 lipid_med
gen inflam_med = on361 == 1 | on362 == 1 
// Create wave and study variables
gen str6 wave = "12"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave hyperten_med diab_med lipid_med inflam_med
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hyperten_med "anti-hypertensive medication use"
la var diab_med "anti-diabetic medication use"
la var lipid_med "anti-hyperlipidemic medication use"
la var inflam_med "anti-inflammatory medication use"
// Save as a temp file
tempfile _Cov_Meds_fatfile_2014
save `_Cov_Meds_fatfile_2014'

****************************************

// RAND HRS FAT FILE 2016
use "$hrsf\\$fhrsff16", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id pc006 pc011 pc012 pn360 pn361 pn362
// Rename existing or construct new variables
rename pc006 hyperten_med
gen diab_med = pc011 == 1 | pc012 == 1
rename pn360 lipid_med
gen inflam_med = pn361 == 1 | pn362 == 1 
// Create wave and study variables
gen str6 wave = "13"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave hyperten_med diab_med lipid_med inflam_med
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hyperten_med "anti-hypertensive medication use"
la var diab_med "anti-diabetic medication use"
la var lipid_med "anti-hyperlipidemic medication use"
la var inflam_med "anti-inflammatory medication use"
// Save as a temp file
tempfile _Cov_Meds_fatfile_2016
save `_Cov_Meds_fatfile_2016'

***********************************************************
**              COVARIATES: PHYSICAL HEALTH              **
***********************************************************
// RAND HRS LONGITUDINAL FILE 1992-2018 VERSION 2
use "$hrsr\\$fhrsrlf", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
// keep id r3adla r4adla r5adla r6adla r7adla r8adla r9adla r10adla r11adla ///
// 	r12adla r13adla r3iadla r4iadla r5iadla r6iadla r7iadla r8iadla r9iadla ///
// 	r10iadla r11iadla r12iadla r13iadla r3conde r4conde r5conde r6conde ///
// 	r7conde r8conde r9conde r10conde r11conde r12conde r13conde
keep id r3adl5a r4adl5a r5adl5a r6adl5a r7adl5a r8adl5a r9adl5a r10adl5a r11adl5a ///
	r12adl5a r13adl5a r3iadl5a r4iadl5a r5iadl5a r6iadl5a r7iadl5a r8iadl5a r9iadl5a ///
	r10iadl5a r11iadl5a r12iadl5a r13iadl5a r3conde r4conde r5conde r6conde ///
	r7conde r8conde r9conde r10conde r11conde r12conde r13conde
// Rename variables
rename r3adl5a adl_3
rename r4adl5a adl_4
rename r5adl5a adl_5
rename r6adl5a adl_6
rename r7adl5a adl_7
rename r8adl5a adl_8
rename r9adl5a adl_9
rename r10adl5a adl_10
rename r11adl5a adl_11
rename r12adl5a adl_12
rename r13adl5a adl_13
rename r3iadl5a iadl_3
rename r4iadl5a iadl_4
rename r5iadl5a iadl_5
rename r6iadl5a iadl_6
rename r7iadl5a iadl_7
rename r8iadl5a iadl_8
rename r9iadl5a iadl_9
rename r10iadl5a iadl_10
rename r11iadl5a iadl_11
rename r12iadl5a iadl_12
rename r13iadl5a iadl_13
rename r3conde comorbidities_3
rename r4conde comorbidities_4
rename r5conde comorbidities_5
rename r6conde comorbidities_6
rename r7conde comorbidities_7
rename r8conde comorbidities_8
rename r9conde comorbidities_9
rename r10conde comorbidities_10
rename r11conde comorbidities_11
rename r12conde comorbidities_12
rename r13conde comorbidities_13
// Reshape long
reshape long adl_ iadl_ comorbidities_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave adl iadl comorbidities
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var adl "Sum of ADLs"
la var iadl "Sum of IADLs"
la var comorbidities "Sum of comorbidites"
// Save as a temp file
tempfile _Cov_PhysH_92_16
save `_Cov_PhysH_92_16'

***********************************************************
**            COVARIATES: PSYCHOSOCIAL HEALTH            **
***********************************************************
// RAND HRS FAT FILE 1998
use "$hrsf\\$fhrsff98", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id f992
// Rename variable
rename f992 child_srh
// Create wave and study variables
gen str6 wave = "4"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave child_srh
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var child_srh "childhood self-rated health"
// Save as a temp file
tempfile _Cov_PsychH_fatfile_1998
save `_Cov_PsychH_fatfile_1998'

****************************************

// RAND HRS FAT FILE 2000
use "$hrsf\\$fhrsff00", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id g1079
// Rename variable
rename g1079 child_srh
// Create wave and study variables
gen str6 wave = "5"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave child_srh
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var child_srh "childhood self-rated health"
// Save as a temp file
tempfile _Cov_PsychH_fatfile_2000
save `_Cov_PsychH_fatfile_2000'

****************************************

// RAND HRS FAT FILE 2002
use "$hrsf\\$fhrsff02", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id hb019
// Rename variable
rename hb019 child_srh
// Create wave and study variables
gen str6 wave = "6"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave child_srh
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var child_srh "childhood self-rated health"
// Save as a temp file
tempfile _Cov_PsychH_fatfile_2002
save `_Cov_PsychH_fatfile_2002'

****************************************

// RAND HRS FAT FILE 2004
use "$hrsf\\$fhrsff04", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id jb019
// Rename variable
rename jb019 child_srh
// Create wave and study variables
gen str6 wave = "7"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave child_srh
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var child_srh "childhood self-rated health"
// Save as a temp file
tempfile _Cov_PsychH_fatfile_2004
save `_Cov_PsychH_fatfile_2004'

****************************************

// RAND HRS FAT FILE 2006
use "$hrsf\\$fhrsff06", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id kb019
// Rename variable
rename kb019 child_srh
// Create wave and study variables
gen str6 wave = "8"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave child_srh
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var child_srh "childhood self-rated health"
// Save as a temp file
tempfile _Cov_PsychH_fatfile_2006
save `_Cov_PsychH_fatfile_2006'

****************************************

// RAND HRS FAT FILE 2008
use "$hrsf\\$fhrsff08", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id lb019
// Rename variable
rename lb019 child_srh
// Create wave and study variables
gen str6 wave = "9"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave child_srh
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var child_srh "childhood self-rated health"
// Save as a temp file
tempfile _Cov_PsychH_fatfile_2008
save `_Cov_PsychH_fatfile_2008'

****************************************

// RAND HRS FAT FILE 2010
use "$hrsf\\$fhrsff10", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id mb019
// Rename variable
rename mb019 child_srh
// Create wave and study variables
gen str6 wave = "10"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave child_srh
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var child_srh "childhood self-rated health"
// Save as a temp file
tempfile _Cov_PsychH_fatfile_2010
save `_Cov_PsychH_fatfile_2010'

****************************************

// RAND HRS FAT FILE 2012
use "$hrsf\\$fhrsff12", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id nb019
// Rename variable
rename nb019 child_srh
// Create wave and study variables
gen str6 wave = "11"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave child_srh
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var child_srh "childhood self-rated health"
// Save as a temp file
tempfile _Cov_PsychH_fatfile_2012
save `_Cov_PsychH_fatfile_2012'

****************************************

// RAND HRS FAT FILE 2014
use "$hrsf\\$fhrsff14", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id ob019
// Rename variable
rename ob019 child_srh
// Create wave and study variables
gen str6 wave = "12"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave child_srh
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var child_srh "childhood self-rated health"
// Save as a temp file
tempfile _Cov_PsychH_fatfile_2014
save `_Cov_PsychH_fatfile_2014'

****************************************

// RAND HRS FAT FILE 2016
use "$hrsf\\$fhrsff16", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id pb019
// Rename variable
rename pb019 child_srh
// Create wave and study variables
gen str6 wave = "13"
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave child_srh
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var child_srh "childhood self-rated health"
// Save as a temp file
tempfile _Cov_PsychH_fatfile_2016
save `_Cov_PsychH_fatfile_2016'

****************************************

// RAND HRS LONGITUDINAL FILE 1992-2018 VERSION 2
use "$hrsr\\$fhrsrlf", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id r1shlt r2shlt r3shlt r4shlt r5shlt r6shlt r7shlt r8shlt r9shlt ///
	r10shlt r11shlt r12shlt r13shlt r1deprex r2depres r3depres r4depres ///
	r5depres r6depres r7depres r8depres r9depres r10depres r11depres ///
	r12depres r13depres r1jstres r2jstres r3jstres r4jstres r5jstres ///
	r6jstres r7jstres r8jstres r9jstres r10jstres r11jstres r12jstres ///
	r13jstres r1covr r2covr r3covr r4covr r5covr r6covr r7covr r8covr ///
	r9covr r10covr r11covr r12covr r13covr r1higov r2higov r3higov r4higov ///
	r5higov r6higov r7higov r8higov r9higov r10higov r11higov r12higov r13higov
// Rename variables
rename r1shlt adult_srh_1
rename r2shlt adult_srh_2
rename r3shlt adult_srh_3
rename r4shlt adult_srh_4
rename r5shlt adult_srh_5
rename r6shlt adult_srh_6
rename r7shlt adult_srh_7
rename r8shlt adult_srh_8
rename r9shlt adult_srh_9
rename r10shlt adult_srh_10
rename r11shlt adult_srh_11
rename r12shlt adult_srh_12
rename r13shlt adult_srh_13
rename r1deprex depressed_cesd_1
rename r2depres depressed_cesd_2
rename r3depres depressed_cesd_3
rename r4depres depressed_cesd_4
rename r5depres depressed_cesd_5
rename r6depres depressed_cesd_6
rename r7depres depressed_cesd_7
rename r8depres depressed_cesd_8
rename r9depres depressed_cesd_9
rename r10depres depressed_cesd_10
rename r11depres depressed_cesd_11
rename r12depres depressed_cesd_12
rename r13depres depressed_cesd_13
rename r1jstres jobstress_1
rename r2jstres jobstress_2
rename r3jstres jobstress_3
rename r4jstres jobstress_4
rename r5jstres jobstress_5
rename r6jstres jobstress_6
rename r7jstres jobstress_7
rename r8jstres jobstress_8
rename r9jstres jobstress_9
rename r10jstres jobstress_10
rename r11jstres jobstress_11
rename r12jstres jobstress_12
rename r13jstres jobstress_13
rename r1covr employhealthins_1
rename r2covr employhealthins_2
rename r3covr employhealthins_3
rename r4covr employhealthins_4
rename r5covr employhealthins_5
rename r6covr employhealthins_6
rename r7covr employhealthins_7
rename r8covr employhealthins_8
rename r9covr employhealthins_9
rename r10covr employhealthins_10
rename r11covr employhealthins_11
rename r12covr employhealthins_12
rename r13covr employhealthins_13
rename r1higov govhealthins_1
rename r2higov govhealthins_2
rename r3higov govhealthins_3
rename r4higov govhealthins_4
rename r5higov govhealthins_5
rename r6higov govhealthins_6
rename r7higov govhealthins_7
rename r8higov govhealthins_8
rename r9higov govhealthins_9
rename r10higov govhealthins_10
rename r11higov govhealthins_11
rename r12higov govhealthins_12
rename r13higov govhealthins_13
// Reshape long
reshape long adult_srh_ depressed_cesd_ jobstress_ employhealthins_ ///
	govhealthins_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave adult_srh depressed_cesd jobstress employhealthins ///
	govhealthins
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var adult_srh "respondent self-rated health"
la var depressed_cesd "self-reported depression; CES-D"
la var jobstress "self-reported stress due to job"
la var employhealthins "respondent employer health insurance"
la var govhealthins "respondent government health insurance"
// Save as a temp file
tempfile _Cov_PsychH_92_16
save `_Cov_PsychH_92_16'

***********************************************************
**                  COVARIATES: WEIGHTS                  **
***********************************************************
// RAND HRS LONGITUDINAL FILE 1992-2018 VERSION 2
use "$hrsr\\$fhrsrlf", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename hhidpn id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id rawtsamp raestrat r1wtresp r2wtresp r3wtresp r4wtresp r5wtresp ///
	r6wtresp r7wtresp r8wtresp r9wtresp r10wtresp r11wtresp r12wtresp ///
	r13wtresp r14wtresp
// Rename existing or construct new variables
gen hrs_sampleweight_1 = rawtsamp
gen hrs_sampleweight_2 = rawtsamp
gen hrs_sampleweight_3 = rawtsamp
gen hrs_sampleweight_4 = rawtsamp
gen hrs_sampleweight_5 = rawtsamp
gen hrs_sampleweight_6 = rawtsamp
gen hrs_sampleweight_7 = rawtsamp
gen hrs_sampleweight_8 = rawtsamp
gen hrs_sampleweight_9 = rawtsamp
gen hrs_sampleweight_10 = rawtsamp
gen hrs_sampleweight_11 = rawtsamp
gen hrs_sampleweight_12 = rawtsamp
gen hrs_sampleweight_13 = rawtsamp
gen hrs_sampleweight_14 = rawtsamp
drop rawtsamp
gen hrs_strataweight_1 = raestrat
gen hrs_strataweight_2 = raestrat
gen hrs_strataweight_3 = raestrat
gen hrs_strataweight_4 = raestrat
gen hrs_strataweight_5 = raestrat
gen hrs_strataweight_6 = raestrat
gen hrs_strataweight_7 = raestrat
gen hrs_strataweight_8 = raestrat
gen hrs_strataweight_9 = raestrat
gen hrs_strataweight_10 = raestrat
gen hrs_strataweight_11 = raestrat
gen hrs_strataweight_12 = raestrat
gen hrs_strataweight_13 = raestrat
gen hrs_strataweight_14 = raestrat
drop raestrat
rename r1wtresp hrs_respondentweight_1
rename r2wtresp hrs_respondentweight_2
rename r3wtresp hrs_respondentweight_3
rename r4wtresp hrs_respondentweight_4
rename r5wtresp hrs_respondentweight_5
rename r6wtresp hrs_respondentweight_6
rename r7wtresp hrs_respondentweight_7
rename r8wtresp hrs_respondentweight_8
rename r9wtresp hrs_respondentweight_9
rename r10wtresp hrs_respondentweight_10
rename r11wtresp hrs_respondentweight_11
rename r12wtresp hrs_respondentweight_12
rename r13wtresp hrs_respondentweight_13
rename r14wtresp hrs_respondentweight_14
// Reshape long
reshape long hrs_sampleweight_ hrs_strataweight_ hrs_respondentweight_, ///
	i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "HRS"
// Reduce variable set further
keep id study wave hrs_sampleweight hrs_strataweight hrs_respondentweight
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hrs_sampleweight "HRS sampling weight"
la var hrs_strataweight "HRS stratum weight"
la var hrs_respondentweight "HRS cross-section weight"
// Save as a temp file
tempfile _Cov_Wts_92_16
save `_Cov_Wts_92_16'

***********************************************************
**          COMBINE INTO SINGLE PROJECT DATASET          **
***********************************************************

// Survey and Cognition
use `_SR_92_16', clear
destring id, replace
tempfile HRS_hrs1992_2016
save `HRS_hrs1992_2016'

use `_SR_hrsfamr92_14', clear
destring id, replace
tempfile HRS_hrsfamr92_14
save `HRS_hrsfamr92_14'

use `_SES_fatfile_1998', clear
destring id, replace
tempfile HRS_fatfile_1998
save `HRS_fatfile_1998'

use `_SES_92_18v1', clear
destring id, replace
tempfile HRS_hrs1992_2018v1
save `HRS_hrs1992_2018v1'

use `_SES_cses_measures', clear
destring id, replace
tempfile HRS_cses_measures
save `HRS_cses_measures'

use `_Cog_92_16', clear
destring id, replace
tempfile HRS_cognition
save `HRS_cognition'

use `_SR_fatfile_1996', clear
foreach y in 1998 2000 2002 2004 2006 2008 2010 2012 2014 2016 {
    append using `_SR_fatfile_`y''
}
destring id, replace

merge 1:1 id study wave using `HRS_hrs1992_2016'
drop _merge
merge 1:1 id study wave using `HRS_hrsfamr92_14'
drop _merge
merge 1:1 id study wave using `HRS_fatfile_1998'
drop _merge
merge 1:1 id study wave using `HRS_hrs1992_2018v1'
drop _merge
merge 1:1 id study wave using `HRS_cses_measures'
drop _merge
merge 1:1 id study wave using `HRS_cognition'
drop _merge
sort id wave
tempfile hrs_survey
save `hrs_survey'

// Bio - Biomarkers
use `_Bio_biomk08bl_r', clear
destring id, replace
tempfile biomk08bl
save `biomk08bl'
use `_Bio_biomk10bl_r', clear
destring id, replace
tempfile biomk10bl
save `biomk10bl'
use `_Bio_biomk12bl_r', clear
destring id, replace
tempfile biomk12bl
save `biomk12bl'
use `_Bio_biomk14bl', clear
destring id, replace
tempfile biomk14bl
save `biomk14bl'
use `_Bio_hrs2016vbs', clear
destring id, replace
tempfile HRS_hrs2016vbs
save `HRS_hrs2016vbs'
use `_Bio_92_16', clear
destring id, replace
tempfile bio_92_16
save `bio_92_16'

use `_Bio_biomk16bl_r', clear
destring id, replace
merge 1:1 id study wave using `HRS_hrs2016vbs'
drop _merge
tempfile hrs_biom_2016
save `hrs_biom_2016'

use `_Bio_biomk06bl_r', clear
destring id, replace
append using `biomk08bl'
append using `biomk10bl'
append using `biomk12bl'
append using `biomk14bl'
append using `hrs_biom_2016'
format %12.0g id
sort id wave
merge 1:1 id study wave using `bio_92_16'
drop _merge
tempfile hrs_biom
save `hrs_biom'

// Covariates
use `_Cov_Behav_92_16', clear
destring id, replace
tempfile HRS_cov_behav
save `HRS_cov_behav'

use `_Cov_Attrition_92_16', clear
destring id, replace
tempfile HRS_cov_attrition
save `HRS_cov_attrition'

use `_Cov_Demog_92_16', clear
destring id, replace
tempfile HRS_cov_demog
save `HRS_cov_demog'

foreach y in 2006 2008 2010 2012 2014 2016 {
    use `_Cov_Meds_fatfile_`y''
	destring id, replace
	tempfile meds_ff_`y'
	save `meds_ff_`y''
}
use `meds_ff_2006'
foreach yy in 2008 2010 2012 2014 2016 {
    append using `meds_ff_`yy''
}
tempfile HRS_cov_meds
save `HRS_cov_meds'

use `_Cov_LBElig_06'
foreach yy in 08 10 12 14 16 18 {
    append using `_Cov_LBElig_`yy''
}
destring id, replace
tempfile HRS_cov_lbelig
save `HRS_cov_lbelig'

use `_Cov_PhysH_92_16', clear
destring id, replace
tempfile HRS_cov_physh
save `HRS_cov_physh'

use `_Cov_PsychH_92_16', clear
destring id, replace
tempfile HRS_cov_psychh_92_16
save `HRS_cov_psychh_92_16'

use `_Cov_PsychH_fatfile_1998'
foreach yy in 00 02 04 06 08 10 12 14 16 {
    append using `_Cov_PsychH_fatfile_20`yy''
}
destring id, replace
merge 1:1 id study wave using `HRS_cov_psychh_92_16'
drop _merge
tempfile HRS_cov_psychh
save `HRS_cov_psychh'

use `_Cov_Wts_92_16', clear
destring id, replace
tempfile HRS_cov_weights
save `HRS_cov_weights'

use `HRS_cov_attrition', clear
merge 1:1 id study wave using `HRS_cov_behav'
drop _merge
merge 1:1 id study wave using `HRS_cov_demog'
drop _merge
merge 1:1 id study wave using `HRS_cov_lbelig'
drop _merge
merge 1:1 id study wave using `HRS_cov_meds'
drop _merge
merge 1:1 id study wave using `HRS_cov_physh'
drop _merge
merge 1:1 id study wave using `HRS_cov_psychh'
drop _merge
merge 1:1 id study wave using `HRS_cov_weights'
drop _merge
tempfile hrs_covariates
save `hrs_covariates'

// Merge them all together
use `hrs_survey', clear
merge 1:1 id study wave using `hrs_biom'
drop _merge
merge 1:1 id study wave using `hrs_covariates'
drop _merge
sort id wave
format %12.0g id

quietly: desc, s
local numvars `r(k)' - 3
ds, has(type numeric)
egen missingvars = rowmiss(`r(varlist)')
sort id wave
// Finish processing
drop missingvars
destring id wave, replace
sort id wave
tostring id wave, replace

***********************************************************
**             FINAL INTERIM DATASET CLEANUP             **
***********************************************************

// Convert wave to numeric
destring wave, replace

// Destring the ID variable and sort the data by study, ID and wave
destring id, replace
format %12.0g id
sort id wave

// Remove value labels
ds, has(type numeric)
la val `r(varlist)' .

// Rename the cross-sectional weight variable to be consistent across studies
rename hrs_respondentweight xsectionweight
la var xsectionweight "Study-specific cross-section weights"

// Compress
compress

// Update formats
ds, has(type byte)
format %8.0g `r(varlist)'

ds, has(type int)
format %8.0g `r(varlist)'

ds, has(type float)
format %12.2g `r(varlist)'

// Reorder the variables
order id study wave ///
	year_died month_died date_died death_source death2intvw_months ///--ATTRITION
	p_empl_ft p1_educ p2_educ childses rassets_total reduc_year ///----------SES
	reduc_cat rincome_hh rincome_wages ///
	meeting_all religious_attend child_demand child_critic mom_contact ///----SR
	dad_contact marital_status sppn_demand sppn_critic child_num fam_understand ///
	volunteer fam_rely fam_open child_open child_rely sppn_open sppn_rely ///
	fri_rely fri_open neigh_contact_per child_res mom_res dad_res par_alive ///
	fam_demand fam_critic fam_letudown fam_nerves child_contact_inperson ///
	child_contact_phone child_contact_write child_understand child_letudown ///
	child_nerves cohabitating sppn_rel_close sppn_understand sppn_letudown ///
	sppn_nerves fri_yesno fri_contact_inperson fri_contact_phone ///
	fri_contact_write fri_understand fri_demand fri_critic fri_letudown ///
	fri_nerves meeting_soc meeting_other neigh_contact ///
	height weight bmi wc systolicbp diastolicbp hypertension ///------BIOMARKERS
	totchol hdlchol ldlchol diabetes hba1c pulse crp cystatinc triglyceride ///
	inflam_med lipid_med diab_med hyperten_med ///-------------------MEDICATIONS
	immedrecall delayrecall serial7 backcount datename_mo ///----------COGNITION
	datename_daymo datename_year datename_daywk objname_scis objname_cact ///
	presname vpname vocab cogtot ///
	pa_light pa_light3xwk pa_mod pa_vig pa_vig3xwk everdrink ///-------BEHAVIORS
	alc_drinkfreqweek drinksperday smoker ///
	age birthyear hrscohort female race hispanic immigrant ///------DEMOGRAPHICS
	religion region proxy ///
	adult_srh child_srh depressed_cesd jobstress ///---------PSYCHOSOCIAL HEALTH
	employhealthins govhealthins ///
	adl iadl comorbidities ///-----------------------------------PHYSICAL HEALTH
	lbelig ///--------------------------------------HRS LEAVE BEHIND ELIGIBILITY
	xsectionweight hrs_sampleweight hrs_strataweight //------------------WEIGHTS

// Save
save "$tmpd\ida_study_vars_hrs.dta", replace

