// MIDUS
// IDA_Secondary_Study_Variables_MIDUS.do
// This Do file must be called from the Primary Do File (IDA_Primary_Control_Script.do)

clear
set more off
set maxvar 20000

// Master dataset variables are pulled from multiple datasets

***********************************************************
**                          SES                          **
***********************************************************
// MIDUS 1 MAIN
use "$mds1\\$fmds1", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id a1ptseim a1poccd a1ptseid a1poccm a1pc2 a1pc8 a1sj14 a1sj15 a1pmqb1 ///
	r_ged a1pb1 a1sj8m a1ptsei
// Rename variables
rename a1ptseim f_sei
rename a1poccd fempl
rename a1ptseid m_sei
rename a1poccm mempl
rename a1pc2 p1_educ
rename a1pc8 p2_educ
rename a1sj14 rassets_status
rename a1sj15 rassets_total
rename a1pmqb1 reduc_cat
rename r_ged reduc_GED
rename a1pb1 reduc_year
rename a1sj8m rincome_wages
rename a1ptsei rses_4cat
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave f_sei fempl m_sei mempl p1_educ p2_educ rassets_status ///
	rassets_total reduc_cat reduc_GED reduc_year rincome_wages rses_4cat
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var f_sei "Father/Male head-of-house SEI"
la var fempl "Father works outside the home"
la var m_sei "Mother/female head-of-house SEI"
la var mempl "Mother works outside the home"
la var p1_educ "Parent 1's education"
la var p2_educ "Parent 2's education"
la var rassets_status "Respondent - debts, even, or assets if liquirified"
la var rassets_total "Respondent - total assets"
la var reduc_cat "Respondent: Educational attainment category"
la var reduc_GED "Respondent Education - GED"
la var reduc_year "Respondent: Highest year of education"
la var rincome_wages "Respondent earnings"
la var rses_4cat "4-category SES"
// Save as a temp file
tempfile _SES_w1_main
save `_SES_w1_main'

****************************************

// MIDUS 2 MAIN
use "$mds2\\$fmds2", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id b1sg23 b1sg24a b1pb1 b1srinc1 b1sg8a b1ptsei
// Rename variables
rename b1sg23 rassets_status
rename b1sg24a rassets_total
rename b1pb1 reduc_year
rename b1srinc1 rincome_total
rename b1sg8a rincome_wages
rename b1ptsei rses_4cat
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave rassets_status rassets_total reduc_year rincome_total ///
	rincome_wages rses_4cat
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var rassets_status "Respondent - debts, even, or assets if liquirified"
la var rassets_total "Respondent - total assets"
la var reduc_year "Respondent: Highest year of education"
la var rincome_total "Respondent income - total (wages + other)"
la var rincome_wages "Respondent earnings"
la var rses_4cat "4-category SES"
// Save as a temp file
tempfile _SES_w2_main
save `_SES_w2_main'

****************************************

// MIDUS 3 MAIN
use "$mds3\\$fmds3", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id c1sg59 c1sg59a c1sg59b c1pb1 c1srinc c1sg11a
// Rename variables
rename c1sg59 rassets_status
rename c1sg59a rassets_owe
rename c1sg59b rassets_total
rename c1pb1 reduc_year
rename c1srinc rincome_total
rename c1sg11a rincome_wages
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave rassets_status rassets_owe rassets_total reduc_year ///
	rincome_total rincome_wages
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var rassets_status "Respondent - debts, even, or assets if liquirified"
la var rassets_owe "Respondent - amount owed if liquified"
la var rassets_total "Respondent - total assets"
la var reduc_year "Respondent: Highest year of education"
la var rincome_total "Respondent income - total (wages + other)"
la var rincome_wages "Respondent earnings"
// Save as a temp file
tempfile _SES_w3_main
save `_SES_w3_main'

***********************************************************
**                 SOCIAL RELATIONSHIPS                  **
***********************************************************
// MIDUS 1 MAIN
use "$mds1\\$fmds1", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id a1sk9d a1sk9c a1sk9e a1sl1 a1sl2 a1sr4 a1sk8a a1sk8b a1sk8c a1sk8d ///
	a1sm1 a1sm3 a1sm4 a1sm5 a1sm2 a1sm6 a1sm7 a1sm8 a1sm9 a1pb35 a1pb37 ///
	a1pb17 a1pb24 a1sp15 a1sp14 a1sp12 a1sp11 a1sp13 a1sp16 a1sp17 a1sp20 ///
	a1sp21 a1sp22 a1sp18 a1sp19 a1sm10 a1sm13 a1sm14 a1sm11 a1sm12 a1sm15 ///
	a1sm16 a1sm17 a1sm18
// Rename variables
rename a1sk9d meeting_soc
rename a1sk9c meeting_prof
rename a1sk9e meeting_other
rename a1sl1 neigh_contact_any
rename a1sl2 neigh_contact
rename a1sr4 religious_attend
rename a1sk8a volunteerhrs_hos
rename a1sk8b volunteerhrs_edu
rename a1sk8c volunteerhrs_politics
rename a1sk8d volunteerhrs_other
rename a1sm1 fam_contact
rename a1sm3 fam_understand
rename a1sm4 fam_rely
rename a1sm5 fam_open
rename a1sm2 fam_care
rename a1sm6 fam_demand
rename a1sm7 fam_critic
rename a1sm8 fam_letudown
rename a1sm9 fam_nerves
rename a1pb35 child_bio_num
rename a1pb37 child_nonbio_num
rename a1pb17 marital_status
rename a1pb24 cohabitation
rename a1sp15 sppn_open
rename a1sp14 sppn_rely
rename a1sp12 sppn_understand
rename a1sp11 sppn_care
rename a1sp13 sppn_appreciates
rename a1sp16 sppn_be_yourself
rename a1sp17 sppn_demand
rename a1sp20 sppn_critic
rename a1sp21 sppn_letudown
rename a1sp22 sppn_nerves
rename a1sp18 sppn_tense
rename a1sp19 sppn_argue
rename a1sm10 fri_contact
rename a1sm13 fri_rely
rename a1sm14 fri_open
rename a1sm11 fri_care
rename a1sm12 fri_understand
rename a1sm15 fri_demand
rename a1sm16 fri_critic
rename a1sm17 fri_letudown
rename a1sm18 fri_nerves
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave meeting_soc meeting_prof meeting_other neigh_contact_any ///
	neigh_contact religious_attend volunteerhrs_hos volunteerhrs_edu ///
	volunteerhrs_politics volunteerhrs_other fam_contact fam_understand ///
	fam_rely fam_open fam_care fam_demand fam_critic fam_letudown fam_nerves ///
	child_bio_num child_nonbio_num marital_status cohabitation sppn_open ///
	sppn_rely sppn_understand sppn_care sppn_appreciates sppn_be_yourself ///
	sppn_demand sppn_critic sppn_letudown sppn_nerves sppn_tense sppn_argue ///
	fri_contact fri_rely fri_open fri_care fri_understand fri_demand ///
	fri_critic fri_letudown fri_nerves
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var meeting_soc "Frequency attend sport/social meetings"
la var meeting_prof "Frequency attend professional meetings"
la var meeting_other "Frequency attend other group meetings"
la var neigh_contact_any "Frequency of contact with neighbors"
la var neigh_contact "Frequency get together with neighbors"
la var religious_attend "Frequency attend religious services"
la var volunteerhrs_hos "Volunteer hours for hospitals"
la var volunteerhrs_edu "Volunteer hours for an educational organization"
la var volunteerhrs_politics "Volunteer hours for political organizations"
la var volunteerhrs_other "Volunteer hours for other organizations"
la var fam_contact "Contact with family members"
la var fam_understand "Family understands you"
la var fam_rely "Can rely on your family"
la var fam_open "Open up to your family"
la var fam_care "Family members care about you"
la var fam_demand "Family members make too many demands"
la var fam_critic "Family members criticize you"
la var fam_letudown "Family members let you down"
la var fam_nerves "Family gets on your nerves"
la var child_bio_num "Number of biological children"
la var child_nonbio_num "Number of non-biological children"
la var marital_status "Current marital status"
la var cohabitation "Cohabitating with partner"
la var sppn_open "Open up to your spouse/partner"
la var sppn_rely "Can rely on your spouse/partner"
la var sppn_understand "Spouse/partner understands you"
la var sppn_care "Spouse/partner cares about you"
la var sppn_appreciates "Spouse/partner appreciates you"
la var sppn_be_yourself "Can you be yourself around them"
la var sppn_demand "Spouse/partner make too many demands"
la var sppn_critic "Spouse/partner criticize you"
la var sppn_letudown "Spouse/partner let you down"
la var sppn_nerves "Spouse/partner get on your nerves"
la var sppn_tense "Spouse/partner makes you feel tense"
la var sppn_argue "Spouse/partner argues with you"
la var fri_contact "Frequency of contact with friends"
la var fri_rely "Can rely on your friends"
la var fri_open "Can open up to your friends"
la var fri_care "Friends care about you"
la var fri_understand "Friends understands you"
la var fri_demand "Friends make too many demands"
la var fri_critic "Friends criticize you"
la var fri_letudown "Friends let you down"
la var fri_nerves "Friends get on your nerves"
// Save as a temp file
tempfile _SR_w1_main
save `_SR_w1_main'

****************************************

// MIDUS 2 MAIN
use "$mds2\\$fmds2", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id b1sh8b b1sh8a b1sh8c b1si1 b1si2 b1sn3d b1sh7a b1sh7b b1sh7c b1sh7d ///
	b1sj1 b1sj2b b1sj2c b1sj2d b1sj2a b1sj2g b1sj2h b1sj2i b1sj2j b1pc2 ///
	b1pb19 b1pb30 b1sl11e b1sl11d b1sl11b b1sl11a b1sl11c b1sl11f b1sl11g ///
	b1sl11j b1sl11k b1sl11l b1sl11h b1sl11i b1sj3 b1sj4c b1sj4d b1sj4a ///
	b1sj4b b1sj4e b1sj4f b1sj4g b1sj4h
// Rename variables
rename b1sh8b meeting_soc
rename b1sh8a meeting_prof
rename b1sh8c meeting_other
rename b1si1 neigh_contact_any
rename b1si2 neigh_contact
rename b1sn3d religious_attend
rename b1sh7a volunteerhrs_hos
rename b1sh7b volunteerhrs_edu
rename b1sh7c volunteerhrs_politics
rename b1sh7d volunteerhrs_other
rename b1sj1 fam_contact
rename b1sj2b fam_understand
rename b1sj2c fam_rely
rename b1sj2d fam_open
rename b1sj2a fam_care
rename b1sj2g fam_demand
rename b1sj2h fam_critic
rename b1sj2i fam_letudown
rename b1sj2j fam_nerves
rename b1pc2 child_num
rename b1pb19 marital_status
rename b1pb30 cohabitation
rename b1sl11e sppn_open
rename b1sl11d sppn_rely
rename b1sl11b sppn_understand
rename b1sl11a sppn_care
rename b1sl11c sppn_appreciates
rename b1sl11f sppn_be_yourself
rename b1sl11g sppn_demand
rename b1sl11j sppn_critic
rename b1sl11k sppn_letudown
rename b1sl11l sppn_nerves
rename b1sl11h sppn_tense
rename b1sl11i sppn_argue
rename b1sj3 fri_contact
rename b1sj4c fri_rely
rename b1sj4d fri_open
rename b1sj4a fri_care
rename b1sj4b fri_understand
rename b1sj4e fri_demand
rename b1sj4f fri_critic
rename b1sj4g fri_letudown
rename b1sj4h fri_nerves
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave meeting_soc meeting_prof meeting_other neigh_contact_any ///
	neigh_contact religious_attend volunteerhrs_hos volunteerhrs_edu ///
	volunteerhrs_politics volunteerhrs_other fam_contact fam_understand ///
	fam_rely fam_open fam_care fam_demand fam_critic fam_letudown fam_nerves ///
	child_num marital_status cohabitation sppn_open sppn_rely sppn_understand ///
	sppn_care sppn_appreciates sppn_be_yourself sppn_demand sppn_critic ///
	sppn_letudown sppn_nerves sppn_tense sppn_argue fri_contact fri_rely ///
	fri_open fri_care fri_understand fri_demand fri_critic fri_letudown ///
	fri_nerves
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var meeting_soc "Frequency attend sport/social meetings"
la var meeting_prof "Frequency attend professional meetings"
la var meeting_other "Frequency attend other group meetings"
la var neigh_contact_any "Frequency of contact with neighbors"
la var neigh_contact "Frequency get together with neighbors"
la var religious_attend "Frequency attend religious services"
la var volunteerhrs_hos "Volunteer hours for hospitals"
la var volunteerhrs_edu "Volunteer hours for an educational organization"
la var volunteerhrs_politics "Volunteer hours for political organizations"
la var volunteerhrs_other "Volunteer hours for other organizations"
la var fam_contact "Contact with family members"
la var fam_understand "Family understands you"
la var fam_rely "Can rely on your family"
la var fam_open "Open up to your family"
la var fam_care "Family members care about you"
la var fam_demand "Family members make too many demands"
la var fam_critic "Family members criticize you"
la var fam_letudown "Family members let you down"
la var fam_nerves "Family gets on your nerves"
la var child_num "Number of children"
la var marital_status "Current marital status"
la var cohabitation "Cohabitating with partner"
la var sppn_open "Open up to your spouse/partner"
la var sppn_rely "Can rely on your spouse/partner"
la var sppn_understand "Spouse/partner understands you"
la var sppn_care "Spouse/partner cares about you"
la var sppn_appreciates "Spouse/partner appreciates you"
la var sppn_be_yourself "Can you be yourself around them"
la var sppn_demand "Spouse/partner make too many demands"
la var sppn_critic "Spouse/partner criticize you"
la var sppn_letudown "Spouse/partner let you down"
la var sppn_nerves "Spouse/partner get on your nerves"
la var sppn_tense "Spouse/partner makes you feel tense"
la var sppn_argue "Spouse/partner argues with you"
la var fri_contact "Frequency of contact with friends"
la var fri_rely "Can rely on your friends"
la var fri_open "Can open up to your friends"
la var fri_care "Friends care about you"
la var fri_understand "Friends understands you"
la var fri_demand "Friends make too many demands"
la var fri_critic "Friends criticize you"
la var fri_letudown "Friends let you down"
la var fri_nerves "Friends get on your nerves"
// Save as a temp file
tempfile _SR_w2_main
save `_SR_w2_main'

****************************************

// MIDUS 3 MAIN
use "$mds3\\$fmds3", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id c1sh8b c1sh8a c1sh8c c1si1 c1si2 c1sn3d c1sh7a c1sh7b c1sh7c c1sh7d ///
	c1sj1 c1sj4b c1sj4c c1sj4d c1sj4a c1sj4g c1sj4h c1sj4i c1sj4j c1pc2 ///
	c1pb19 c1pb30 c1ppartn c1sl12e c1sl12d c1sl12b c1sl12a c1sl12c c1sl12f ///
	c1sl12g c1sl12j c1sl12k c1sl12l c1sl12h c1sl12i c1sj5 c1sj8c c1sj8d ///
	c1sj8a c1sj8b c1sj8e c1sj8f c1sj8g c1sj8h
// Rename variables
rename c1sh8b meeting_soc
rename c1sh8a meeting_prof
rename c1sh8c meeting_other
rename c1si1 neigh_contact_any
rename c1si2 neigh_contact
rename c1sn3d religious_attend
rename c1sh7a volunteerhrs_hos
rename c1sh7b volunteerhrs_edu
rename c1sh7c volunteerhrs_politics
rename c1sh7d volunteerhrs_other
rename c1sj1 fam_contact
rename c1sj4b fam_understand
rename c1sj4c fam_rely
rename c1sj4d fam_open
rename c1sj4a fam_care
rename c1sj4g fam_demand
rename c1sj4h fam_critic
rename c1sj4i fam_letudown
rename c1sj4j fam_nerves
rename c1pc2 child_num
rename c1pb19 marital_status
rename c1pb30 cohabitation
rename c1ppartn married_cohab
rename c1sl12e sppn_open
rename c1sl12d sppn_rely
rename c1sl12b sppn_understand
rename c1sl12a sppn_care
rename c1sl12c sppn_appreciates
rename c1sl12f sppn_be_yourself
rename c1sl12g sppn_demand
rename c1sl12j sppn_critic
rename c1sl12k sppn_letudown
rename c1sl12l sppn_nerves
rename c1sl12h sppn_tense
rename c1sl12i sppn_argue
rename c1sj5 fri_contact
rename c1sj8c fri_rely
rename c1sj8d fri_open
rename c1sj8a fri_care
rename c1sj8b fri_understand
rename c1sj8e fri_demand
rename c1sj8f fri_critic
rename c1sj8g fri_letudown
rename c1sj8h fri_nerves
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave meeting_soc meeting_prof meeting_other neigh_contact_any ///
	neigh_contact religious_attend volunteerhrs_hos volunteerhrs_edu ///
	volunteerhrs_politics volunteerhrs_other fam_contact fam_understand ///
	fam_rely fam_open fam_care fam_demand fam_critic fam_letudown fam_nerves ///
	child_num marital_status cohabitation married_cohab sppn_open sppn_rely ///
	sppn_understand sppn_care sppn_appreciates sppn_be_yourself sppn_demand ///
	sppn_critic sppn_letudown sppn_nerves sppn_tense sppn_argue fri_contact ///
	fri_rely fri_open fri_care fri_understand fri_demand fri_critic ///
	fri_letudown fri_nerves
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var meeting_soc "Frequency attend sport/social meetings"
la var meeting_prof "Frequency attend professional meetings"
la var meeting_other "Frequency attend other group meetings"
la var neigh_contact_any "Frequency of contact with neighbors"
la var neigh_contact "Frequency get together with neighbors"
la var religious_attend "Frequency attend religious services"
la var volunteerhrs_hos "Volunteer hours for hospitals"
la var volunteerhrs_edu "Volunteer hours for an educational organization"
la var volunteerhrs_politics "Volunteer hours for political organizations"
la var volunteerhrs_other "Volunteer hours for other organizations"
la var fam_contact "Contact with family members"
la var fam_understand "Family understands you"
la var fam_rely "Can rely on your family"
la var fam_open "Open up to your family"
la var fam_care "Family members care about you"
la var fam_demand "Family members make too many demands"
la var fam_critic "Family members criticize you"
la var fam_letudown "Family members let you down"
la var fam_nerves "Family gets on your nerves"
la var child_num "Number of children"
la var marital_status "Current marital status"
la var cohabitation "Cohabitating with partner"
la var married_cohab "Married or cohabitating"
la var sppn_open "Open up to your spouse/partner"
la var sppn_rely "Can rely on your spouse/partner"
la var sppn_understand "Spouse/partner understands you"
la var sppn_care "Spouse/partner cares about you"
la var sppn_appreciates "Spouse/partner appreciates you"
la var sppn_be_yourself "Can you be yourself around them"
la var sppn_demand "Spouse/partner make too many demands"
la var sppn_critic "Spouse/partner criticize you"
la var sppn_letudown "Spouse/partner let you down"
la var sppn_nerves "Spouse/partner get on your nerves"
la var sppn_tense "Spouse/partner makes you feel tense"
la var sppn_argue "Spouse/partner argues with you"
la var fri_contact "Frequency of contact with friends"
la var fri_rely "Can rely on your friends"
la var fri_open "Can open up to your friends"
la var fri_care "Friends care about you"
la var fri_understand "Friends understands you"
la var fri_demand "Friends make too many demands"
la var fri_critic "Friends criticize you"
la var fri_letudown "Friends let you down"
la var fri_nerves "Friends get on your nerves"
// Save as a temp file
tempfile _SR_w3_main
save `_SR_w3_main'

***********************************************************
**                      BIOMARKERS                       **
***********************************************************
// MIDUS 2 BIOMARKERS
use "$mds2\\$fmds2bio", clear
// Rename variables to lower case for consistency
renvars *, lower
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
keep id b4pbmi b4p2a b4p1gd b4p1gs b4p1d b4h1b b4bha1c b4h1i b4bchol b4bldl b4bhdl b4btrigl b4h1h b4p1a b4p1b b4bgluc b4h45ar b4bcrp
rename b4pbmi bmi
rename b4p2a wc
rename b4p1gd diastolicbp
rename b4p1gs systolicbp
rename b4p1d pulse
rename b4h1b hypertension
rename b4bha1c hba1c
rename b4h1i diabetes
rename b4bchol totchol
rename b4bldl ldlchol
rename b4bhdl hdlchol
rename b4btrigl triglyceride
rename b4h1h highchol
gen height = b4p1a * 0.01
rename b4p1b weight
rename b4bgluc fastgluc
rename b4h45ar ldl_class
rename b4bcrp crp
gen str6 wave = "2"
gen str12 study = "MIDUS"
keep id study wave bmi wc diastolicbp systolicbp pulse hypertension hba1c diabetes totchol ldlchol hdlchol triglyceride highchol height weight fastgluc ldl_class crp
order study wave bmi wc diastolicbp systolicbp pulse hypertension hba1c diabetes totchol ldlchol hdlchol triglyceride highchol height weight fastgluc ldl_class crp, after(id)
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var bmi "Body mass index (kg/m2)"
la var wc "Waist circumference (cm)"
la var diastolicbp "Diastolic BP, mm/Hg"
la var systolicbp "Systolic BP, mm/Hg"
la var pulse "Pulse, beats/minute"
la var hypertension "dichtomous measure for evidence of high blood pressure or hypertension"
la var hba1c "Hemoglobin A1c (%)"
la var diabetes "dichtomous measure for evidence of diabetes"
la var totchol "Total Cholesterol, mg/dL"
la var ldlchol "LDL Cholesterol, mg/dL"
la var hdlchol "HDL Cholesterol, mg/dL"
la var triglyceride "Triglycerides"
la var highchol "dichtomous measure for evidence of high cholesterol"
la var height "Height (m)"
la var weight "Weight (kg)"
la var fastgluc "Fasting glucose (mg/dL)"
la var ldl_class "ldl risk classification"
la var crp "C-reactive protein (mg/l)"
// Save as a temp file
tempfile _Bio_w2_biomrkrs
save `_Bio_w2_biomrkrs'

****************************************

// MIDUS 1 MAIN
use "$mds1\\$fmds1", clear
// Rename variables to lower case for consistency
renvars *, lower
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
keep id a1sa25 a1sa27 a1sbmi a1sa23
gen height = a1sa25 * 0.0254
gen weight = a1sa27 * 0.454
rename a1sbmi bmi
gen wc = a1sa23 * 2.54
gen str6 wave = "1"
gen str12 study = "MIDUS"
keep id study wave height weight bmi wc
order study wave height weight bmi wc, after(id)
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var height "Height (m)"
la var weight "Weight (kg)"
la var bmi "Body mass index (kg/m2)"
la var wc "Waist circumference (cm)"
// Save as a temp file
tempfile _Bio_w1_main
save `_Bio_w1_main'

***********************************************************
**                       COGNITION                       **
***********************************************************
// MIDUS 2 COGNITION
use "$mds2\\$fmds2cog", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id b3twlitu b3twldtu b3tnstot b3tctflu b3tdbs b3tstn b3tstxbb ///
	b3tbktot b3tcompz1
// Rename variables
rename b3twlitu immedrecall
rename b3twldtu delayrecall
rename b3tnstot numseries
rename b3tctflu catflu
rename b3tdbs digbackwards
rename b3tstn sgstsingle
rename b3tstxbb sgstswitch
rename b3tbktot backcount
rename b3tcompz1 btact
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave immedrecall delayrecall numseries catflu digbackwards ///
	sgstsingle sgstswitch backcount btact
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var immedrecall "immediate recall - total # of words"
la var delayrecall "delayed recall - total # of words"
la var numseries "number series - # items correct"
la var catflu "category fluency - total # unique"
la var digbackwards "digits backwards - total score"
la var sgstsingle "stop and go single - # correct"
la var sgstswitch "stop and go switch - # correct"
la var backcount "backwards counting - # counted"
la var btact "Zscore BTACT Composite Score"
// Save as a temp file
tempfile _Cog_w2_cognition
save `_Cog_w2_cognition'

****************************************

// MIDUS 3 COGNITION
use "$mds3\\$fmds3cog", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id c3twlitu c3twldtu c3tnstot c3tctflu c3tdbs c3tstn c3tstxbb ///
	c3tbktot c3tcomp
// Rename variables
rename c3twlitu immedrecall
rename c3twldtu delayrecall
rename c3tnstot numseries
rename c3tctflu catflu
rename c3tdbs digbackwards
rename c3tstn sgstsingle
rename c3tstxbb sgstswitch
rename c3tbktot backcount
rename c3tcomp btact
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave immedrecall delayrecall numseries catflu digbackwards ///
	sgstsingle sgstswitch backcount btact
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var immedrecall "immediate recall - total # of words"
la var delayrecall "delayed recall - total # of words"
la var numseries "number series - # items correct"
la var catflu "category fluency - total # unique"
la var digbackwards "digits backwards - total score"
la var sgstsingle "stop and go single - # correct"
la var sgstswitch "stop and go switch - # correct"
la var backcount "backwards counting - # counted"
la var btact "Zscore BTACT Composite Score"
// Save as a temp file
tempfile _Cog_w3_cognition
save `_Cog_w3_cognition'

***********************************************************
**                 COVARIATES: ATTRITION                 **
***********************************************************
// MIDUS CORE SAMPLE MORTALITY
use "$mdsmort\\$fmdsmort", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id deceased dod_y
// Construct new variables
gen died_2 = deceased
gen died_3 = deceased
drop deceased
gen year_died_2 = dod_y
gen year_died_3 = dod_y
drop dod_y
// Reshape long
reshape long died_ year_died_, i(id) j(wave)
// Convert wave to string
tostring wave, replace
recast str6 wave
// Reduce variable set further
keep id wave *_
// Drop underscore from last character of variable names
renvars *_, postdrop(1)
// Create study variable
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave died year_died
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var died "participant mortality status"
la var year_died "Year of death"
// Save as a temp file
tempfile _Cov_Attrition_died_yrdied
save `_Cov_Attrition_died_yrdied'

// MIDUS 2 DISPOSITION CODES
use "$mds2\\$fmds2dsp", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id m2p1_dis
// Rename variable
rename m2p1_dis attrition
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave attrition
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var attrition "participant attrition status"
// Save as a temp file
tempfile _Cov_Attrition_attrition2
save `_Cov_Attrition_attrition2'

// MIDUS 3 DISPOSITION CODES
use "$mds3\\$fmds3dsp", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id m3p1_dis
// Rename variable
rename m3p1_dis attrition
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave attrition
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var attrition "participant attrition status"
// Save as a temp file
tempfile _Cov_Attrition_attrition3
save `_Cov_Attrition_attrition3'

// Append the two disposition datasets together, then merge on died and yr_died
use `_Cov_Attrition_attrition2', clear
append using `_Cov_Attrition_attrition3'
merge 1:1 id study wave using `_Cov_Attrition_died_yrdied'
drop _merge
// Save as a temp file
tempfile _Cov_Attrition_disp_mort
save `_Cov_Attrition_disp_mort'

***********************************************************
**                 COVARIATES: BEHAVIORS                 **
***********************************************************
// MIDUS 1 MAIN
use "$mds1\\$fmds1", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id a1smoder a1svigor a1sa20 a1sa21 a1sa18 a1sa19 a1pa43
// Rename variables
rename a1smoder pa_mod
rename a1svigor pa_vig
rename a1sa20 summerpa_mod
rename a1sa21 winterpa_mod
rename a1sa18 summerpa_vig
rename a1sa19 winterpa_vig
rename a1pa43 smoker
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave pa_mod pa_vig summerpa_mod winterpa_mod summerpa_vig ///
	winterpa_vig smoker
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var pa_mod "monthly frequency of moderately active sports or activities"
la var pa_vig "monthly frequency of vigorous/active sports or exercise"
la var summerpa_mod "in the summer: frequency of moderately active sports or activities"
la var winterpa_mod "in the winter: frequency of moderately active sports or activities"
la var summerpa_vig "in the summer: frequency of vigorous/active sports or exercise"
la var winterpa_vig "in the winter: frequency of vigorous/active sports or exercise"
la var smoker "Current smoker - yes or no"
// Save as a temp file
tempfile _Cov_Behav_w1_main
save `_Cov_Behav_w1_main'

****************************************

// MIDUS 2 MAIN
use "$mds2\\$fmds2", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id b1sa30e b1sa30f b1sa30c b1sa30d b1sa32e b1sa32f b1sa31c b1sa31d ///
	b1sa31e b1sa31f b1sa32c b1sa32d b1pa50 b1pa51 b1pa52 b1pa53
// Rename variables
rename b1sa30e summerleisure_vig
rename b1sa30f winterleisure_vig
rename b1sa30c summerchore_vig
rename b1sa30d winterchore_vig
rename b1sa32e summerleisure_light
rename b1sa32f winterleisure_light
rename b1sa31c summerchore_mod
rename b1sa31d winterchore_mod
rename b1sa31e summerleisure_mod
rename b1sa31f winterleisure_mod
rename b1sa32c summerchore_light
rename b1sa32d winterchore_light
rename b1pa50 everdrink
rename b1pa51 daysdrinkpermonth
rename b1pa52 num_drinksday
rename b1pa53 bingedrinking
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave summerleisure_vig winterleisure_vig summerchore_vig ///
	winterchore_vig summerleisure_light winterleisure_light summerchore_mod winterchore_mod summerleisure_mod winterleisure_mod summerchore_light winterchore_light everdrink daysdrinkpermonth num_drinksday bingedrinking
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var summerleisure_vig "in the summer: frequency of vigorous leisure activities"
la var winterleisure_vig "in the winter: frequency of vigorous leisure activities"
la var summerchore_vig "in the summer: frequency of vigorous chore activities"
la var winterchore_vig "in the winter: frequency of vigorous chore activities"
la var summerleisure_light "in the summer: frequency of light leisure activities"
la var winterleisure_light "in the winter: frequency of light leisure activities"
la var summerchore_mod "in the summer: frequency of moderate chore activities"
la var winterchore_mod "in the winter: frequency of moderate chore activities"
la var summerleisure_mod "in the summer: frequency of moderate leisure activities"
la var winterleisure_mod "in the winter: frequency of moderate leisure activities"
la var summerchore_light "in the summer: frequency of light chore activities"
la var winterchore_light "in the winter: frequency of light chore activities"
la var everdrink "Drink alcohol ever in past year - yes or no"
la var daysdrinkpermonth "Number of days drank alcohol in past month"
la var num_drinksday "Number of drinks consumed per occassion/days when drink"
la var bingedrinking "Times had 5+ drinks in the same occasion (past month)"
// Save as a temp file
tempfile _Cov_Behav_w2_main
save `_Cov_Behav_w2_main'

****************************************

// MIDUS 2 BIOMARKERS
use "$mds2\\$fmds2bio", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id b4h26a
// Rename variable
rename b4h26a smoker
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave smoker
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var smoker "Current smoker - yes or no"
// Save as a temp file
tempfile _Cov_Behav_w2_midus123
save `_Cov_Behav_w2_midus123'

****************************************

// MIDUS 3 MAIN
use "$mds3\\$fmds3", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id c1pa50 c1pa51 c1pa52 c1pa53
// Rename variables
rename c1pa50 everdrink
rename c1pa51 daysdrinkpermonth
rename c1pa52 num_drinksday
rename c1pa53 bingedrinking
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave everdrink daysdrinkpermonth num_drinksday bingedrinking
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var everdrink "Drink alcohol ever in past year - yes or no"
la var daysdrinkpermonth "Number of days drank alcohol in past month"
la var num_drinksday "Number of drinks consumed per occassion/days when drink"
la var bingedrinking "Times had 5+ drinks in the same occasion"
// Save as a temp file
tempfile _Cov_Behav_w3_main
save `_Cov_Behav_w3_main'

***********************************************************
**                COVARIATES: DEMOGRAPHIC                **
***********************************************************
// MIDUS 1 MAIN
use "$mds1\\$fmds1", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id a1pi_yr a1pbyear a1pbyear a1prsex a1ss7 a1se2 a1sr1 a1se5
// Rename existing or construct new variables
gen age = a1pi_yr-a1pbyear if a1pbyear < 2000
rename a1pbyear birthyear
rename a1prsex female
rename a1ss7 race
rename a1se2 immigrant
rename a1sr1 religion
rename a1se5 language
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave age birthyear female race immigrant religion language
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var age "respondent age: computed by subtracing DOB from W1 survey date"
la var birthyear "respondent birth year"
la var female "respondent gender"
la var race "respondent race/ethnicity"
la var immigrant "immigrant status"
la var religion "respondent religion"
la var language "respondent primary language"
// Save as a temp file
tempfile _Cov_Demog_w1_main
save `_Cov_Demog_w1_main'

****************************************

// MIDUS 2 MAIN
use "$mds2\\$fmds2", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
// keep id b1pidate b1pbyear b1pbyear b1prsex b1pf7a b1pf1 b1sn1a
keep id b1prage_2019 b1pbyear b1pbyear b1prsex b1pf7a b1pf1 b1sn1a
// Rename existing or construct new variables
// gen age = real(substr(b1pidate, -4, .)) - b1pbyear if b1pbyear < 2000
rename b1prage_2019 age
rename b1pbyear birthyear
rename b1prsex female
rename b1pf7a race
rename b1pf1 hispanic
rename b1sn1a religion
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave age birthyear female race hispanic religion
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var age "respondent age: computed by subtracing DOB from W1 survey date"
la var birthyear "respondent birth year"
la var female "respondent gender"
la var race "respondent race/ethnicity"
la var hispanic "respondent Hispanic ethnicity"
la var religion "respondent religion"
// Save as a temp file
tempfile _Cov_Demog_w2_main
save `_Cov_Demog_w2_main'

****************************************

// MIDUS 3 MAIN
use "$mds3\\$fmds3", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id c1prage c1pbyear c1prsex c1pf7a c1pf1 c1sn1a
// Rename variables
rename c1prage age
rename c1pbyear birthyear
rename c1prsex female
rename c1pf7a race
rename c1pf1 hispanic
rename c1sn1a religion
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave age birthyear female race hispanic religion
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var age "respondent age"
la var birthyear "respondent birth year"
la var female "respondent gender"
la var race "respondent race/ethnicity"
la var hispanic "respondent Hispanic ethnicity"
la var religion "respondent religion"
// Save as a temp file
tempfile _Cov_Demog_w3_main
save `_Cov_Demog_w3_main'

***********************************************************
**                COVARIATES: INTELLIGENCE               **
***********************************************************
// !!! NO INTELLIGENCE VARIABLES FOR MIDUS !!!

***********************************************************
**                   COVARIATES: MEDS                    **
***********************************************************
// MIDUS 2 BIOMARKERS
use "$mds2\\$fmds2bio", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id b4xtcs_55 b4xpc_1156 b4xtcs_99 b4xtcs_19 b4xpc_1602 b4xpc_1603
// Rename existing or construct new variables
gen hyperten_med = b4xtcs_55 == 1 | b4xpc_1156 == 1
rename b4xtcs_99 diab_med
rename b4xtcs_19 lipid_med
gen inflam_med = b4xpc_1602 == 1 | b4xpc_1603 == 1
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave hyperten_med diab_med lipid_med inflam_med
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var hyperten_med "anti-hypertensive medication use"
la var diab_med "anti-diabetic medication use"
la var lipid_med "anti-hyperlipidemic medication use"
la var inflam_med "anti-inflammatory medication use"
// Save as a temp file
tempfile _Cov_Meds_w2_biomrkrs
save `_Cov_Meds_w2_biomrkrs'

***********************************************************
**              COVARIATES: PHYSICAL HEALTH              **
***********************************************************
// MIDUS 1 MAIN
use "$mds1\\$fmds1", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id a1sa17a a1sa17b a1sa17c a1sa17d a1sa17e a1sa17f a1sa17g a1sa17h ///
	a1sa17i a1schron
// Rename variables
rename a1sa17a limit_groceries
rename a1sa17b limit_bath_dress
rename a1sa17c limit_sev_stairs
rename a1sa17d limit_bending
rename a1sa17e limit_walk_mile
rename a1sa17f limit_walk_block
rename a1sa17g limit_walk_one_block
rename a1sa17h limit_vig_act
rename a1sa17i limit_mod_act
rename a1schron comorbidities
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave limit_groceries limit_bath_dress limit_sev_stairs ///
	limit_bending limit_walk_mile limit_walk_block limit_walk_one_block ///
	limit_vig_act limit_mod_act comorbidities
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var limit_groceries "Health limits lifting/carrying groceries"
la var limit_bath_dress "Health limits bathing/dressing self"
la var limit_sev_stairs "Health limits climbing serveral flights of stairs"
la var limit_bending "Health limits bending/kneeling/stooping"
la var limit_walk_mile "Health limits walking more than a mile"
la var limit_walk_block "Health limits walking several blocks"
la var limit_walk_one_block "Health limits walking one block"
la var limit_vig_act "Health limits vigorous activity"
la var limit_mod_act "Health limits moderate activities"
la var comorbidities "Sum of comorbidites"
// Save as a temp file
tempfile _Cov_PhysH_w1_main
save `_Cov_PhysH_w1_main'

****************************************

// MIDUS 2 MAIN
use "$mds2\\$fmds2", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id b1sa28a b1sa28b b1sa28c b1sa28d b1sa28e b1sa28f b1sa28g b1sa28h ///
	b1sa28i b1sa28j b1schron
// Rename variables
rename b1sa28a limit_groceries
rename b1sa28b limit_bath_dress
rename b1sa28c limit_sev_stairs
rename b1sa28d limit_flight_stairs
rename b1sa28e limit_bending
rename b1sa28f limit_walk_mile
rename b1sa28g limit_walk_block
rename b1sa28h limit_walk_one_block
rename b1sa28i limit_vig_act
rename b1sa28j limit_mod_act
rename b1schron comorbidities
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave limit_groceries limit_bath_dress limit_sev_stairs ///
	limit_flight_stairs limit_bending limit_walk_mile limit_walk_block ///
	limit_walk_one_block limit_vig_act limit_mod_act comorbidities
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var limit_groceries "Health limits lifting/carrying groceries"
la var limit_bath_dress "Health limits bathing/dressing self"
la var limit_sev_stairs "Health limits climbing serveral flights of stairs"
la var limit_flight_stairs "Health limits climbing one flight of stairs"
la var limit_bending "Health limits bending/kneeling/stooping"
la var limit_walk_mile "Health limits walking more than a mile"
la var limit_walk_block "Health limits walking several blocks"
la var limit_walk_one_block "Health limits walking one block"
la var limit_vig_act "Health limits vigorous activity"
la var limit_mod_act "Health limits moderate activities"
la var comorbidities "Sum of comorbidites"
// Save as a temp file
tempfile _Cov_PhysH_w2_main
save `_Cov_PhysH_w2_main'

****************************************

// MIDUS 3 MAIN
use "$mds3\\$fmds3", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id c1sa24a c1sa24b c1sa24c c1sa24d c1sa24e c1sa24f c1sa24g c1sa24h ///
	c1sa24i c1sa24j c1schron
// Rename variables
rename c1sa24a limit_groceries
rename c1sa24b limit_bath_dress
rename c1sa24c limit_sev_stairs
rename c1sa24d limit_flight_stairs
rename c1sa24e limit_bending
rename c1sa24f limit_walk_mile
rename c1sa24g limit_walk_block
rename c1sa24h limit_walk_one_block
rename c1sa24i limit_vig_act
rename c1sa24j limit_mod_act
rename c1schron comorbidities
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave limit_groceries limit_bath_dress limit_sev_stairs ///
	limit_flight_stairs limit_bending limit_walk_mile limit_walk_block ///
	limit_walk_one_block limit_vig_act limit_mod_act comorbidities
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var limit_groceries "Health limits lifting/carrying groceries"
la var limit_bath_dress "Health limits bathing/dressing self"
la var limit_sev_stairs "Health limits climbing serveral flights of stairs"
la var limit_flight_stairs "Health limits climbing one flight of stairs"
la var limit_bending "Health limits bending/kneeling/stooping"
la var limit_walk_mile "Health limits walking more than a mile"
la var limit_walk_block "Health limits walking several blocks"
la var limit_walk_one_block "Health limits walking one block"
la var limit_vig_act "Health limits vigorous activity"
la var limit_mod_act "Health limits moderate activities"
la var comorbidities "Sum of comorbidites"
// Save as a temp file
tempfile _Cov_PhysH_w3_main
save `_Cov_PhysH_w3_main'

***********************************************************
**            COVARIATES: PSYCHOSOCIAL HEALTH            **
***********************************************************
// MIDUS 1 MAIN
use "$mds1\\$fmds1", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id a1pa4 a1pa8 a1pa57 a1sa9t a1pa9
// Rename variables
rename a1pa4 adult_srh
rename a1pa8 misswork_healthprob
rename a1pa57 depressed_cesd
rename a1sa9t anxiety_depression
rename a1pa9 child_srh
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave adult_srh misswork_healthprob depressed_cesd ///
	anxiety_depression child_srh
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var adult_srh "respondent self-rated health"
la var misswork_healthprob "health caused missed work/school in last month"
la var depressed_cesd "self-reported depression; CES-D"
la var anxiety_depression "anxiety and/or depression"
la var child_srh "childhood self-rated health"
// Save as a temp file
tempfile _Cov_PsychH_w1_main
save `_Cov_PsychH_w1_main'

****************************************

// MIDUS 2 MAIN
use "$mds2\\$fmds2", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id b1pa1 b1pa4 b1pa60 b1sc1 b1sa11t
// Rename variables
rename b1pa1 adult_srh
rename b1pa4 misswork_healthprob
rename b1pa60 depressed_cesd
rename b1sc1 healthins
rename b1sa11t anxiety_depression
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave adult_srh misswork_healthprob depressed_cesd healthins ///
	anxiety_depression
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var adult_srh "respondent self-rated health"
la var misswork_healthprob "health caused missed work/school in last month"
la var depressed_cesd "self-reported depression; CES-D"
la var healthins "current health insurance status"
la var anxiety_depression "anxiety and/or depression"
// Save as a temp file
tempfile _Cov_PsychH_w2_main
save `_Cov_PsychH_w2_main'

****************************************

// MIDUS 3 MAIN
use "$mds3\\$fmds3", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id c1pa1 c1pa4 c1pa60 c1sc1 c1sa11t
// Rename variables
rename c1pa1 adult_srh
rename c1pa4 misswork_healthprob
rename c1pa60 depressed_cesd
rename c1sc1 healthins
rename c1sa11t anxiety_depression
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave adult_srh misswork_healthprob depressed_cesd healthins ///
	anxiety_depression
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var adult_srh "respondent self-rated health"
la var misswork_healthprob "health caused missed work/school in last month"
la var depressed_cesd "self-reported depression; CES-D"
la var healthins "current health insurance status"
la var anxiety_depression "anxiety and/or depression"
// Save as a temp file
tempfile _Cov_PsychH_w3_main
save `_Cov_PsychH_w3_main'

***********************************************************
**                  COVARIATES: WEIGHTS                  **
***********************************************************
// MIDUS 2 MAIN
use "$mds2\\$fmds2", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id b1pwght9
// Rename variable
rename b1pwght9 midus_stratweight
// Create wave and study variables
gen str6 wave = "2"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave midus_stratweight
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var midus_stratweight "MIDUS post-stratification weight"
// Save as a temp file
tempfile _Cov_Wts_wts_Full
save `_Cov_Wts_wts_Full'

****************************************

// MIDUS 1 MAIN
use "$mds1\\$fmds1", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id a1pwght1
// Rename variable
rename a1pwght1 midus_stratweight
// Create wave and study variables
gen str6 wave = "1"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave midus_stratweight
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var midus_stratweight "MIDUS post-stratification weight"
// Save as a temp file
tempfile _Cov_Wts_w1_main
save `_Cov_Wts_w1_main'

****************************************

// MIDUS 3 MAIN
use "$mds3\\$fmds3", clear
// Rename variables to lower case for consistency
renvars *, lower
// Rename the ID variable and convert to string if numeric
rename m2id id
capture confirm string var id
if _rc != 0 {
    la val id .
    tostring id, replace
}
// Keep only necessary variables
keep id c1pwght10
// Rename variable
rename c1pwght10 midus_stratweight
// Create wave and study variables
gen str6 wave = "3"
gen str12 study = "MIDUS"
// Reduce variable set further
keep id study wave midus_stratweight
// Label variables
la var id "Participant Identifier"
la var study "Study"
la var wave "Study wave"
la var midus_stratweight "MIDUS post-stratification weight"
// Save as a temp file
tempfile _Cov_Wts_w3_main
save `_Cov_Wts_w3_main'

***********************************************************
**          COMBINE INTO SINGLE PROJECT DATASET          **
***********************************************************
// Wave 1
use `_SR_w1_main', clear
merge 1:1 id study wave using `_SES_w1_main'
drop _merge
merge 1:1 id study wave using `_Bio_w1_main'
drop _merge
merge 1:1 id study wave using `_Cov_Attrition_disp_mort'
keep if wave == "1"
drop _merge
merge 1:1 id study wave using `_Cov_Behav_w1_main'
drop _merge
merge 1:1 id study wave using `_Cov_Demog_w1_main'
drop _merge
merge 1:1 id study wave using `_Cov_PhysH_w1_main'
drop _merge
merge 1:1 id study wave using `_Cov_PsychH_w1_main'
drop _merge
merge 1:1 id study wave using `_Cov_Wts_w1_main'
drop _merge
tempfile midus_w1
save `midus_w1'

// Wave 2
use `_SR_w2_main', clear
merge 1:1 id study wave using `_SES_w2_main'
drop _merge
merge 1:1 id study wave using `_Bio_w2_biomrkrs'
drop _merge
merge 1:1 id study wave using `_Cog_w2_cognition'
drop _merge
merge 1:1 id study wave using `_Cov_Attrition_disp_mort'
keep if wave == "2"
drop _merge
merge 1:1 id study wave using `_Cov_Behav_w2_main'
drop _merge
merge 1:1 id study wave using `_Cov_Behav_w2_midus123'
drop _merge
merge 1:1 id study wave using `_Cov_Demog_w2_main'
drop _merge
merge 1:1 id study wave using `_Cov_Meds_w2_biomrkrs'
drop _merge
merge 1:1 id study wave using `_Cov_PhysH_w2_main'
drop _merge
merge 1:1 id study wave using `_Cov_PsychH_w2_main'
drop _merge
merge 1:1 id study wave using `_Cov_Wts_wts_Full'
drop _merge
tempfile midus_w2
save `midus_w2'

// Wave 3
use `_SR_w3_main', clear
merge 1:1 id study wave using `_SES_w3_main'
drop _merge
merge 1:1 id study wave using `_Cog_w3_cognition'
drop _merge
merge 1:1 id study wave using `_Cov_Attrition_disp_mort'
keep if wave == "3"
drop _merge
merge 1:1 id study wave using `_Cov_Behav_w3_main'
drop _merge
merge 1:1 id study wave using `_Cov_Demog_w3_main'
drop _merge
merge 1:1 id study wave using `_Cov_PhysH_w3_main'
drop _merge
merge 1:1 id study wave using `_Cov_PsychH_w3_main'
drop _merge
merge 1:1 id study wave using `_Cov_Wts_w3_main'
drop _merge
tempfile midus_w3
save `midus_w3'

// Append all waves together
use `midus_w1'
append using `midus_w2'
append using `midus_w3'
sort id wave

quietly: desc, s
local numvars `r(k)' - 3
ds, has(type numeric)
egen missingvars = rowmiss(`r(varlist)')
// Remove the respondents that are missing all variables
drop if missingvars == `numvars'
drop missingvars

// Finish processing
destring id wave, replace
sort id wave
tostring id wave, replace

***********************************************************
**             FINAL INTERIM DATASET CLEANUP             **
***********************************************************

// Convert wave to numeric
destring wave, replace

// Destring the ID variable and sort the data by study, ID and wave
destring id, replace
format %12.0g id
sort id wave

// Remove value labels
ds, has(type numeric)
la val `r(varlist)' .

// Rename the cross-sectional weight variable to be consistent across studies
rename midus_stratweight xsectionweight
la var xsectionweight "Study-specific cross-section weights"

// Compress
compress

// Update formats
ds, has(type byte)
format %8.0g `r(varlist)'

ds, has(type int)
format %8.0g `r(varlist)'

ds, has(type float)
format %12.2g `r(varlist)'

// Reorder the variables
order id study wave ///
	attrition died year_died ///---------------------------------------ATTRITION
	f_sei m_sei fempl mempl p1_educ p2_educ rassets_total ///----------------SES
	rassets_status rassets_owe reduc_year reduc_cat reduc_GED rincome_total ///
	rincome_wages rses_4cat ///
	religious_attend marital_status sppn_demand sppn_critic child_num ///-----SR
	fam_understand fri_contact fri_care fam_rely fam_open child_bio_num ///
	child_nonbio_num sppn_open sppn_rely fri_rely fri_open fam_demand ///
	fam_critic fam_letudown fam_nerves cohabitation sppn_understand ///
	sppn_letudown sppn_nerves fri_understand fri_demand fri_critic ///
	fri_letudown fri_nerves meeting_soc meeting_other meeting_prof ///
	neigh_contact_any neigh_contact volunteerhrs_hos volunteerhrs_edu ///
	volunteerhrs_politics volunteerhrs_other fam_contact fam_care sppn_care ///
	sppn_appreciates sppn_be_yourself sppn_tense sppn_argue married_cohab ///
	height weight bmi wc systolicbp diastolicbp hypertension ///------BIOMARKERS
	totchol highchol hdlchol ldlchol ldl_class diabetes fastgluc hba1c pulse ///
	crp triglyceride ///
	inflam_med lipid_med diab_med hyperten_med ///-------------------MEDICATIONS
	immedrecall delayrecall digbackwards backcount numseries ///-------COGNITION
	catflu sgstsingle sgstswitch btact ///
	pa_mod pa_vig summerpa_mod summerpa_vig winterpa_mod ///-----------BEHAVIORS
	winterpa_vig summerleisure_light summerleisure_mod summerleisure_vig ///
	winterleisure_light winterleisure_mod winterleisure_vig summerchore_light ///
	summerchore_mod summerchore_vig winterchore_light winterchore_mod ///
	winterchore_vig everdrink num_drinksday bingedrinking daysdrinkpermonth smoker ///
	age birthyear female race hispanic immigrant religion ///-------DEMOGRAPHICS
	language ///
	adult_srh child_srh healthins depressed_cesd ///---------PSYCHOSOCIAL HEALTH
	anxiety_depression misswork_healthprob ///
	comorbidities limit_mod_act limit_vig_act ///----------------PHYSICAL HEALTH
	limit_sev_stairs limit_flight_stairs limit_bending limit_groceries ///
	limit_bath_dress limit_walk_one_block limit_walk_block limit_walk_mile ///
	xsectionweight //----------------------------------------------------WEIGHTS

// Save
save "$tmpd\ida_study_vars_midus.dta", replace
